/*=====================================================================
    Advertisement Manager Script (CORE) | /js/adMan.js
=====================================================================*/

//  Advertisement Manager Object
function adManager() {
    this.ads = [];
    this.content = [];
    this.disabled = false;
    this.brandedChannelEnabled = false;
    this.sessionCampaignId = null;

    try {
        this.init();
    } catch (e) {
        popError(e);
        this.disabled = true;
    }
}

adManager.prototype.init = function adManagerInit() {
    this.buildAdList();
    this.loadAdContent();
    this.loadNoUserAds(null);
   
};

adManager.prototype.resetAdData = function adManagerResetAdData() {
    this.content = [];
    this.loadAdContent();
};

// Create array of ads supported by client
adManager.prototype.buildAdList = function adManagerBuildAdList() {
    this.ads = {
        //  Attract view
        active_billboard: new staticAd("active_billboard", this),
        sunburst: new staticAd("sunburst", this),

        //  Pop-up Interstitial
        startup_video: new startupVideoAd("startup_video", this, "#startupVideoContainer"),
        startup_bg: new staticAd("startup_bg", this, "#startupVideo_bg"),

        //  Main Menu page
        sliding_promo_banner: new slidingInterstitialAd("sliding_promo_banner", this),
        mmbtn_music: new staticAd("mmbtn_music", this),
        mm_300x250: new staticAd("mm_300x250", this),
        
        //  Landing Page
        landing_featured: new staticAd("landing_featured", this),
        landing_video: new startupVideoAd("landing_video", this),

        //  TV page
        tv_banner: new timedInterstitialAd("tv_banner", this),
        tv_box: new staticAd("tv_box", this, "#persistentBox"),

        //  On demand page
        ondemand_featured: new staticAd("ondemand_featured", this),
        ondemand_btn_branded: new staticAd("ondemand_btn_branded", this),
        ondemand_banner: new timedInterstitialAd("ondemand_banner", this),
        ondemand_box: new staticAd("ondemand_box", this, "#persistentBox"),
        ondemand_preroll_video: new prerollVideoAd("ondemand_preroll_video", this, "#videoContainer"),

        //  Music page
        music_bg: new staticAd("music_bg", this),
        music_featured: new staticAd("music_featured", this),
        music_banner: new timedInterstitialAd("music_banner", this),
        music_preroll_video: new prerollVideoAd("music_preroll_video", this, "#videoContainer"),

        //  Personal News page
        //news_banner: new bannerAd("news_banner", this),
        //news_sky: new bannerAd("news_sky", this),

        //  iPod page
        ipod_banner: new bannerAd("ipod_banner", this),
        //ipod_buffering_video: new ad("ipod_buffering_video", "mixed", true),

        //  History page
        history_banner: new bannerAd("history_banner", this),
        history_sky: new bannerAd("history_sky", this),

        //  Custom Playlist page
        playlist_banner: new timedInterstitialAd("playlist_banner", this),
        
        //  Virtual Active page
        virtualactive_banner: new timedInterstitialAd("virtualactive_banner", this),
        virtualactive_box: new staticAd("virtualactive_box", this, "#persistentBox"),

        //  End of Workout page
        end_of_workout: new staticAd("end_of_workout", this, "#eow_ad"),

        //  Popup video
        popup_video_bkgnd: new staticAd("popup_video_bkgnd", this, "#popupVideo"),
        popup_video: new ad("popup_video", "video", this, "#adVideoPlayer"),

        //  Branded channel
        mmbtn_branded: new staticAd("mmbtn_branded", this, "button#buttonFeatured1"),
        branded_bg: new staticAd("branded_bg", this),
        branded_carousel: new videoCarouselAd("branded_carousel", this)
    };
};

//  If media.xml exists, load ad creative from <allads> section
adManager.prototype.loadAdContent = function adManagerLoadAdContent() {
    var _this = this;

    // If no media.xml, disable adman
    if (!media_xml_exists) {
        this.disabled = true;
        writeLog("error", "Failed to find create ad list! > Couldn't find media.xml file.");
    } else {
        _this.buildContentList(mediaXML.$data);
        writeLog("info", "adMan successfully loaded mediaxml object: ");
    }
};

// Attach adManagerBuildContentList to adManager prototype as buildContentList.
adManager.prototype.buildContentList = function adManagerBuildContentList(c) {
// Load the main list of ad content.
    var d = this;
    c.find("allads").each(function() {
        $(this).find("content").each(function() {
            var a = $(this);
            var b = a.find("mfile");
            var e = a.attr("type");
            var f = b.attr("name");
            var g = MEDIA_DIR + a.find("ifile").attr("name");
            var l = MEDIA_DIR + f;
            if ("gateway" == e.toLowerCase() && "video" == b.attr("mtype")) {
                l = "rtsp://" + systemObj.getGatewayIPAddress() + "/" + f;
            }
            d.content.push({
                id          : a.attr("id"),
                advertiser  : a.attr("info2"),
                name        : a.attr("title"),
                created     : a.attr("created"),
                playlists   : a.attr("playlists"),
                fileType    : b.attr("mtype"),
                type        : e,
                thumbnail   : g,
                location    : l
            });
        });
    });
};

adManager.prototype.parseAdXML = function adManagerParseAdXML(xml) {
    var _this = this, logStr = "ADUNITS:";
    writeLog("info", "Parsing ad response xml...");

    try {
        // Go through each ad unit in the response
        $(xml).find("adunit").each(function adManagerParseAdXMLAdUnit() {
            var adUnitCode = $(this).attr("code");
            if (_this.ads[adUnitCode] != undefined) {
                logStr += "\nadUnit: " + _this.ads[adUnitCode].code + ":";
    
                // Set the period
                _this.ads[adUnitCode].period = parseInt($(this).attr("period"));
                logStr += " per: " + _this.ads[adUnitCode].period + " ";
    
                // Reset content array for this ad unit
                _this.ads[adUnitCode].content = [];
    
                $(this).find("content").each(function adManagerParseAdXmlContent() {
                    // If busted don't deal with this content item
                    if (!($(this).attr("id"))) {
                        return;
                    }
    
                    var percentage = (($(this).attr("pct")) ? parseInt($(this).attr("pct")) : 0),
                        campaignId = (($(this).attr("campaign")) ? $(this).attr("campaign") : 0),
                        thisBehavior = (($(this).attr("beh")) ? $(this).attr("beh") : false),
                        behaviorParams = null,
                        isAdDefault = (($(this).is('[default]')) ? $(this).attr("default") : false);

                    if (thisBehavior) {
                        var behaviorArray = thisBehavior.split("str=");
                        if (1 < behaviorArray.length) {
                            try {
                                behaviorParams = evalJSON(decodeUTF8(behaviorArray[1]));
                            } catch (e) { popError(e); }
                        }
                    }
    
                    _this.ads[adUnitCode].content.push({
                        id            : $(this).attr("id"),
                        pct           : percentage,
                        campaign      : campaignId,
                        isDefault     : isAdDefault,
                        showOnDefault : $(this).attr("show"),
                        behavior      : thisBehavior,
                        vars          : behaviorParams
                    });

                    logStr += "[ cId: " + $(this).attr("id") + ", isDef: " + isAdDefault + ", show: " + $(this).attr("show") + ", beh: " + thisBehavior + " ]";
                });
    
                //  Set up hideOnDefault attribute
                if (_this.ads[adUnitCode].content.length == 1 && _this.ads[adUnitCode].content[0].showOnDefault == "false") {
                    _this.ads[adUnitCode].hideOnDefault = true;
                }
                else{
                    _this.ads[adUnitCode].hideOnDefault = false;
                }
    
                // Special case for Branded Content button, since it replaces the Personal News button
                if (adUnitCode == "mmbtn_branded" && _this.ads[adUnitCode].content[0].isDefault != "true") {
                    _this.brandedChannelEnabled = true;
                }
            }
        });
    
        writeLog("info", logStr);
        writeLog("info", "Finished parsing ad response xml.");
    } catch (e) { popError(e); }
};

//  Parse list of no-user ads.
adManager.prototype.setUpNoUserAds = function(xml) {
    this.parseAdXML(xml);
};

//  Get non-user ads.
adManager.prototype.loadNoUserAds = function adManagerLoadNoUserAds(callBack) {
    var _this = this;
    var urlString = ((machineObj.getMachineDemoNetwork())
        ? "file:///netpulse/www/demo/ads.xml"
        : machineObj.getServerLocation() + "n5iads.jsp?machine_id=" + configObj.getMid());

    dirtyHarry(
        urlString,
        function loadNoUserAdsSuccess(data, textStatus, jqXHR) { _this.setUpNoUserAds(data); if (typeof(callBack) === 'function') { callBack(); } },
        function loadNoUserAdsError(data, jqXHR, textStatus, errorThrown) {showAds(); if(textStatus == "timeout"){_this.disabled = false;}else{_this.disabled = true;} if (typeof(callBack) === 'function') { callBack(); }},
        null,
        10000,
        "GET",
        "xml",
        false,
        5
    );
};

//  Set up targeted ads via login xml response
adManager.prototype.setUpTargetedAds = function adManagerSetUpTargetedAds(xml) {
    this.parseAdXML(xml);
    // Enable adman
    this.disabled = false;
};

// Set up nontargetted ads
adManager.prototype.setUpNonTargetedAds = function adManagerSetUpNonTargetedAds(xml) {
    this.parseAdXML(xml);
    // Enable adman
    this.disabled = false;
};

// Show the given ad
adManager.prototype.showAd = function adManagerShowAd(which) {
    if (this.disabled) {
        return(false);
    } else if (this.ads[which] != undefined) {
        return(this.ads[which].show());
    }
    return(false);
};

//  Hide the given ad
adManager.prototype.hideAd = function adManagerHideAd(which) {
    if(this.disabled)
        return;

    if (this.ads[which] != undefined)
        this.ads[which].hide();
};

//  Set the periodTicker of the given ad unit to zero
adManager.prototype.resetPeriodCount = function adManagerResetPeriodCount(which) {
    if(this.disabled)
        return;

    if (this.ads[which] != undefined)
        this.ads[which].periodTicker = 0;
};

//  Show login prompt if user is not signed in
adManager.prototype.loginPrompt = function adManagerLoginPrompt() {
    if($("#loginModal").exists())
        return;

    var me = this;

    var str = "<div id='adLoginModal'><div>"+
        "<h2>You must be logged in to proceed.</h2>" +
        "<div class='modalBtns'><button id='loginGoBtn' class='login button'>Login</button><button id='loginCancelBtn' class='login button'>Cancel</button></div>"+
    "</div></div>";


    pauseResumeObj.hideVLCObjects();

    if(viewManager.currentView.name == "tv")
        silenceAudio();

    $("body").prepend(str);

    $("#loginGoBtn").bind("mousedown", function() { me.hideLoginPrompt(); viewManager.nextView = viewManager.activeObject.name; viewManager.show("login"); });
    $("#loginCancelBtn").bind("mousedown", function() { me.hideLoginPrompt(); });
};

//  Hide login prompt
adManager.prototype.hideLoginPrompt = function() {
    $("#adLoginModal").remove();

    pauseResumeObj.showVLCObjects();
};

//  Hide success prompt
adManager.prototype.hideSuccessPrompt = function() {
    $("#adSuccessModal").remove();

    startVideoPlayer("videoPlayerObject");
    startVideoPlayer("customContentPlayer");
    startVideoPlayer("id_onDemandVideoPlayerObject");
};

//  Do "subscribe" functionality for the given campaign id
adManager.prototype.subscribe = function(contentId, adUnit, campaignId,rollValue, adId, isText) {
    var me = this;
    console.log(this.content);
    var urlString = machineObj.getServerLocation()
        + "n5isubscribe.jsp?uid=" + athleteObj.get_user_id()
        + "&mid=" + configObj.getMid()
        + "&campaign=" + campaignId;
    var successCallback = function subscribeSuccessCallback(data, status, xhr) {
        me.subscribeSuccess(contentId, adUnit, campaignId, rollValue, adId, isText);
    };
    var errorCallback = function subscribeErrorCallback() {
        me.subscribeError();
    };
    dirtyHarry(urlString,successCallback, errorCallback);
    writeLog('info', 'Sent click-to-email request to ' + urlString);

};

//  Successful subscription
adManager.prototype.subscribeSuccess = function(contentId, adUnit, campaignId, rollValue, adId, isText){
    if ($("#loginModal").exists()) 
        return;

    this.ads[adUnit].insertSucessContent(contentId, adId, isText);
    this.ads[adUnit].content.splice(rollValue,1);
};

ad.prototype.insertSucessContent = function(contentId, adId, isText) {
        
        var imageLocation = null;
        console.log(contentId);
        console.log(isText);
        for( var i=0, ilen=this.manager.content.length; i<ilen; i++ ) {
            if (adId == this.manager.content[i].id) {
                imageLocation = this.manager.content[i].location;
            }
        }
        if(isText == true){
           var adHTML = "<div style='background:url(" + imageLocation + ") center top no-repeat; text-align:center;'><span class='clicked'><p><strong>"+contentId+"</strong></p></span></div>"; 
        }else{
            adHTML = "<div width:100%; height:100%; style='background:url(" + imageLocation + ") no-repeat;'></div>";
        }
        
        $('#featuredTitle').hide();
        $('#watchNow').hide();
        $(this.domElement).html(adHTML).fadeIn(100).unbind();
};

//  Failed subscription
adManager.prototype.subscribeError = function(e) {
    writeLog("info", "Error while subscribing!");
};


function killVideoPlayer(playerId) {}
function startVideoPlayer(playerId) {}

// Show popup static image
adManager.prototype.showPopupImage = function (adId) {  
    var imageLocation = null;
    pauseResumeObj.hideVLCObjects();
 
    for(var i =0; i<adMan.content.length; i++){
        if (adId == adMan.content[i].id) {
            imageLocation = adMan.content[i].location;
            console.log(imageLocation);
            $("body").append('<img id="popupAdImage" style="display:none;" src="'+imageLocation+'" />');
        }    
    }

    $('#popupAdImage').load(function(){

        str = "<div id='popUpAd'><div id='popupImage'><button id='closePop'></button><img src='"+imageLocation+"' /></div></div>";

        $("body").append(str);

        var imgWidth = $('#popupAdImage').width();
        var imgHeight = $('#popupAdImage').height();
        var buttonPlace = imgWidth - 30;

        $('#popupImage').css('width', imgWidth);
        $('#popupImage').css('height', imgHeight);
        $('#closePop').css('margin-left', buttonPlace+"px");

        $('#closePop').mousedown(function(){
            $('#popupAdImage').remove();
            $('#popUpAd').remove();
            pauseResumeObj.showVLCObjects();
        });

    });    
}

//  Show popup video
adManager.prototype.showPopupVideo = function(adId) {
    if($("#popUpAd").exists())
        return;

    pauseResumeObj.hideVLCObjects();
    for(var i =0; i<adMan.content.length; i++){
        if (adId == adMan.content[i].id) {
            var me = this;
            var whichVideo = adMan.content[i].location;
            console.log(adId);
            console.log(whichVideo);
            var str = "<div id='popUpAd'>"+
                '<div id="popupVideoModal">'+
                "<button id='closeVideoPop'></button>"+
                '<object type="video/mpeg" vout="yes" id="popVideoPlayer" data="'+whichVideo+'">' +
                    '<param name="fullscreen_support" value="no" />'+                  
                    '<param name="wmode" value="transparent" />' +
                    '<param name="data_type" value="ondemand" />' +
                '</object>'+
                "<button id='popupVideoCloseBtn'></button>"+
                "</div>"+
            "</div>";

            $("body").append(str);

        }
    }

    $("#closeVideoPop").bind("mousedown", function() { 
         if(!$("#popUpAd").exists())
        return;

        $("#popUpAd").remove();
        pauseResumeObj.showVLCObjects();

     });
};


adManager.prototype.findContentId = function adManagerFindContentId(content) {
    if (!content) {
        throw("noContent");
    }
    var j = -1;
    for (var i=0, ilen=this.content.length; i<ilen; i++) {
        if (this.content[i].id == content.id){
            j = i;
            break;
        }
    }
    if(j >= 0)
        return j;
    else
        throw("contentIdNotFound");//  If content id didn't match main ad content list, bail.
};

//  Find this content item in ad manager content list and add a new impression
adManager.prototype.addImpression = function(content, code, timestamp) {
    var tmp = this.findContentId(content);
    var impression = new adImpression(content.id, code, parseInt(content.campaign));
    impressions.addImpression(impression);

    return tmp;
};

adManager.prototype.addImpressionCarousel = function(content, code, timestamp, playTime) {
    var tmp = this.findContentId(content);
    var impression = new adImpression(content.id, code, parseInt(content.campaign), playTime);
    impressions.addImpression(impression);
    this.ads[code].logAddImpression(content, code, playTime);
    
    return tmp;
};

//  Find this content item in ad manager content list and add a new impression
adManager.prototype.addClickImpression = function(content, code, timestamp) {
    var playTime = 0, tmp = this.findContentId(content);
    var impression = new adImpression(content.id, code, parseInt(content.campaign), playTime, content.behavior.split("(")[0].split("&str")[0]);
    impressions.addImpression(impression);
    this.ads[code].logAddImpression(content, code, null);
};

/*---------------------------------------------------------------*/

//  Basic Advertisement Object
function ad(code, type, manager, domElement) {
    this.code = code;
    this.type = type;
    this.domElement = (domElement) ? domElement : "#"+code;
    this.manager = manager;
    this.content = [];
    this.periodTicker = -1;
    this.period = (type == "video") ? 8 : 0;    //  Default period for video ads is 8 (bug #2938)
    this.disabled = false;
    this.periodTimeout = null;
    this.hideOnDefault = false;
}

//  Fill the given ad unit with a randomly-chosen content item from its content array, and record the impression.
ad.prototype.show = function adShow() {
    var found = null, rollValue = null, timestamp = null, randomizedArray;
    try {
    //  Check to make sure this ad is enabled and has content
    this.checkIfActive();

    //  If we only have the default item, fill the randomized array with all zeroes
    randomizedArray = this.fillRandomizedArray();

    //  Construct timestamp
    timestamp = this.constructTimestamp();

    //  Roll dice and return chosen content index
    rollValue = this.rollDice(randomizedArray);

    //  Add impression for this ad unit / content pair and return index of the content
    found = this.manager.addImpression(this.content[rollValue], this.code, timestamp);

    //  Draw the ad to the page
    this.insertContent(found,rollValue);

    //  Log success
    this.success(found,timestamp,rollValue);

    return true;
    } catch(e) { this.handleShowError(e,found,rollValue,timestamp); return false; }
};

//  Go through and make sure there is at least one content item in this ads array that is not a default item.
ad.prototype.onlyDefault = function() {
    var onlyDefault = true;
    for( var i=0, ilen=this.content.length; i<ilen; i++ ) {
        if(!(this.content[i].isDefault == "true"))
            onlyDefault = false;
    }
    return(onlyDefault);
};

//  Fill this ad unit with content and show it
ad.prototype.insertContent = function(found) {};

//  Add a tick to this ad unit's counter
ad.prototype.tick = function adTick() {
    this.periodTicker--;
};

//  If enough cycles have gone by, show this ad.
ad.prototype.periodExpired = function() {
    return(parseInt(this.periodTicker) == 0);
};

//  Start ticker at the top
ad.prototype.resetTicker = function() {
    this.periodTicker = this.period - 1;
};

//  Hide the related dom element and clear period timeout for this ad unit
ad.prototype.hide = function adHide() {
    clearTimeout(this.periodTimeout);
    this.periodTimeout = null;
    $(this.domElement).hide().unbind();
    this.manager.sessionCampaignId = null;
};

//  Return randomized array - all zeroes if only default
ad.prototype.fillRandomizedArray = function() {
    var returnArr = [];
    if(this.onlyDefault()) {
        for( var i=0; i<100; i++ )
            returnArr.push(0);
    }
    //  Otherwise do the usual randomized array
    else
        returnArr = this.getRandomizedArray();

    //  If zero length, bail.
    if(returnArr.length == 0)
        throw("zeroLength");

    return returnArr;
};

// Return a 100 item long array of content ids, to determine which items to show for a given ad unit.
ad.prototype.getRandomizedArray = function adGetRandomizedArray() {
    var randomizedArray = [],
        currentContentId = (Math.floor(Math.random() * (this.content.length - 1) + 1) - 1);
    for (var contentIndex = 0, contentLength = this.content.length; contentIndex < contentLength; contentIndex++) {
        // Ignore defaults.
        if (!eval(this.content[contentIndex].isDefault)) {
            // Let's not show items from a different campaign.
            if (!(this.manager.sessionCampaignId && this.content[contentIndex].campaign != this.manager.sessionCampaignId)) {
                // Add content based on the pct/percent/% sent from n5iAds.jsp.
                for (var pctIndex = 0, pctLength = this.content[currentContentId].pct; pctIndex < pctLength; pctIndex++) {
                    randomizedArray.push(currentContentId);
                }
            }
            // Get the next content id to process.
            currentContentId = ((currentContentId == (this.content.length - 1)) ? 0 : (currentContentId + 1));
        }
    }
    // Adjust array size to 101.
    if (101 != randomizedArray.length) {
        while (101 < randomizedArray.length) {
            randomizedArray.pop();
        }
        while (101 > randomizedArray.length) {
            randomizedArray.push(randomizedArray[(randomizedArray.length - 1)]);
        }
    }
    return randomizedArray;
};

//  Check if the period counter for this ad has run out
ad.prototype.checkPeriodCounter = function() {
    var me = this;

    //  If we haven't hit our period counter yet, come back in one second (aka timer).
    if(!this.periodExpired()) {
        if(this.period > 1)
            this.periodTimeout = setTimeout(function() { me.show(true); }, 1*1000);

        return false;
    }
    return true;
};

//  Check if selected content exists
ad.prototype.contentExists = function adContentExists(found) {

    var filename = media_dir_cleanup(this.manager.content[found].location);
    return(file_exists(filename) == "1");
};

ad.prototype.doHideDefault = function() {
    return(this.hideOnDefault && this.onlyDefault());
};

//  Handle errors thrown by this.show()
ad.prototype.handleShowError = function adHandleShowError(e, found, rollValue, timestamp) {
    var errorStr = "";

    switch(e) {
/*
        case "disabled":
            errorStr = "Ad unit "+this.code+" is disabled.";
            break;
        case "noContent":
            errorStr = "Ad unit "+this.code+" has no associated content.";
            break;
        case "zeroLength":
            errorStr = "Ad content percentages added up to ZERO for ad unit "+this.code+". No ad will be shown.";
            break;
        case "diceMissed":
            errorStr = "Dice missed for ad unit "+this.code+". Trying again.";
            break;
        case "contentIdNotFound":
            errorStr = "Content lists don't match for ad unit "+this.code+".";
            break;
        case "fileNotFound":
            errorStr = "Ad creative not found for ad unit "+this.code+".";
            break;
        case "insertFailed":
            errorStr = "Error while inserting ad html for ad unit "+this.code+".";
            break;
*/
        case "hidingDefaultAd":
            //writeLog("debug", "Ad Impression Recorded (BUT HIDDEN BY DEFAULT): contentId: "+this.manager.content[found].id+", adUnit: "+this.code+", timeStamp: "+timestamp+", campaign: "+this.content[rollValue].campaign);
            return;
        default:
            errorStr = e;
            break;
    }

    writeLog("debug", "Failed to recored ad impression for "+this.code+" > "+errorStr);

    if(e == "diceMissed")
        this.show(true);
};

ad.prototype.success = function adSuccess(found,timestamp,rollValue) {
    writeLog("info", "AdImp: camp: " + this.content[rollValue].campaign + ", unit: " + this.code + ", cId: " + this.manager.content[found].id + ", time: " + timestamp);
};

ad.prototype.logAddImpression = function logAddImpression(content, code, playTime){

    var logMsg = "AdImp: ",
        logMsg2 = "camp: " + parseInt(content.campaign) + ", unit: " + code + ", cId: " + content.id;

    if(!isNaN(parseInt(playTime)))
        logMsg = "videoImp " + logMsg2 + ", playTime: " + playTime;
    
    else
        logMsg += "clickImp " + logMsg2 + ", behavior: " + content.behavior;
    
    
    writeLog("info", logMsg);

};

ad.prototype.constructTimestamp = function adConstructTimestamp() {
    var now = new Date();
    var year = now.getFullYear();
    var month = parseInt(now.getMonth() + 1);
    if(String(month).length == 1)
        month = "0"+month;
    var day = now.getDate();
    if(String(day).length == 1)
        day = "0"+day;
    var hours = now.getHours();
    if(String(hours).length == 1)
        hours = "0"+hours;
    var minutes = now.getMinutes();
    if(String(minutes).length == 1)
        minutes = "0"+minutes;
    var seconds = now.getSeconds();
    if(String(seconds).length == 1)
        seconds = "0"+seconds;

    return (year+"-"+month+"-"+day+" "+hours+":"+minutes+":"+seconds);
};

//  Check if this ad is active
ad.prototype.checkIfActive = function adCheckIfActive() {
    // Don't show disabled ads
    if (this.disabled)
        throw ("disabled");

    // If no content for this ad unit, bail.
    if (this.content.length == 0)
        throw ("noContent");
};

// Get random number to choose content for ad insertion
ad.prototype.rollDice = function adRollDice(randomizedArray) {
    var diceRoll = Math.floor(Math.random()*100+1);

    //  If the dice roll hits a number that doesn't exist in the randomizedArray[], try again.
    if(diceRoll > (randomizedArray.length - 1))
        throw("diceMissed");

    return randomizedArray[diceRoll];
};

// If this content item has a behavior bound to it, set it up
ad.prototype.bindBehavior = function adBindBehavior(rollValue) {
    var me = this, thisAd = me.content[rollValue];

    if (thisAd.behavior) {
        $(this.domElement).unbind().bind("mousedown." + this.name,
            function adBindBehaviorMouseDown() {
                me.manager.addClickImpression(thisAd, me.code, me.constructTimestamp());
                var string = thisAd.behavior.split("?");

                switch (string[0]) {
                    case "ad_clickSubscribe":
                        ad_clickSubscribe(string[1].split(/=|&/)[1], me.code, thisAd.campaign, rollValue, thisAd.id);
                        break;                        
                    case "ad_clickToSubscribe":
                        ad_clickToSubscribe(string[1].split(/=|&/)[1], me.code, thisAd.campaign, rollValue, thisAd.id); 
                        break;
                    case "ad_clickToShowImage":
                         adMan.showPopupImage(string[1].split(/=|&/)[1]);
                         break;
                    case "ad_clickToPopupVideo":
                        adMan.showPopupVideo(string[1].split(/=|&/)[1]);
                        break;

                    case "ad_clickToPage":
                    case "ad_clickToPageData":
                        ad_clickToPage(string[1].split(/=|&/)[1], me.code, thisAd.campaign, rollValue);
                        break;
                }
            });
        // Set params related to the ad from n5iads.jsp.
        if (thisAd.vars && 'object' == typeof thisAd.vars) {
            try {
                var vars = thisAd.vars;
                switch(vars.id){
                    case "showHideRotate":
                        // Set time to show ad.
                        try {
                            if (vars.show) {
                                me.period = (100 * vars.show);
                            }
                        } catch (e) {
                            popError(e);
                        }
                        // Set timeout to hide ad.
                        try {
                            if (vars.hide) {
                                me.periodTimeout = (100 * vars.hide);
                            }
                        } catch (e) {
                            popError(e);
                        }
                        break;
                    
                    case "avoidImageShowText":
                        // Replace Image with text.
                        try {
                            if (vars.text) {
                                $(me.domElement).html("<span>" + decodeURI(vars.text) + "</span>").show();
                            }
                        } catch (e) {
                            popError(e);
                        }
                        break;
                    case "canSkip":
                        //enable/disable nextChannel and backChannel button
                        try{
                            if($("#channel #nextButton").length && $("#channel #backButton").length){
                                if(eval(vars.value)){
                                    $("#channel #nextButton").removeClass("disabled");
                                    $("#channel #backButton").removeClass("disabled");
                                }
                                else if(!eval(vars.value)){
                                    $("#channel #nextButton").addClass("disabled");
                                    $("#channel #backButton").addClass("disabled");
                                }
                            }
                            
                        }
                        catch(e){
                            popError("Error in processing canSkip server driven behavior:" + e);
                        }
                        break;
                }
            } catch (e) {
                popError(e);
            }
        }
    }
};

/*---------------------------------------------------------------*/

//  Banner ad object - inherits from basic ad()
function bannerAd(code, manager, domElement) {
    this.code = code;
    this.type = "banner";
    this.manager = manager;
    this.domElement = (domElement) ? domElement : "#"+code;
    this.content = [];
    this.periodTicker = -1;
    this.period = 0;
    this.disabled = false;
    this.periodTimeout = null;
    this.hideOnDefault = false;
}

bannerAd.prototype = new ad;

//  Fill this ad unit with content and show it - banner ads always have images (for now - TODO)
bannerAd.prototype.insertContent = function(found,rollValue) {
    //  If this ad unit is set to hide on default, and all we have is the defaultbind, don't show an ad
    if(this.doHideDefault())
        throw("hidingDefaultAd");

    //  Check to make sure this content exists
    if(!this.contentExists(found))
        throw("fileNotFound");

    try {
    var me = this;

    var adHTML = "<div style='width:100%;height:100%;background:url(" + this.manager.content[found].location + ") no-repeat;'></div>";
    $(this.domElement).html(adHTML).fadeIn(700);

    //  Bind behavior
    this.bindBehavior(rollValue);

    clearTimeout(this.periodTimeout);
    this.periodTimeout = setTimeout(function() { me.hide(true); }, this.period*1000);
    } catch(e) { throw("insertFailed"); }
};

//  Fade out the related dom element and clear period timeout for this ad unit
bannerAd.prototype.hide = function bannerAdHide(looping) {
    var me = this;

    clearTimeout(this.periodTimeout);
    $(this.domElement).fadeOut(1000).unbind();

    //  If this is a part of the normal banner loop, show again in this.period seconds
    if(looping)
        this.periodTimeout = setTimeout(function() { me.show(); }, this.period*1000);
    
    this.manager.sessionCampaignId = null;
};

/*---------------------------------------------------------------*/

//  Static ad object - inherits from basic ad()
function staticAd(code, manager, domElement) {
    this.code = code;
    this.type = "static";
    this.manager = manager;
    this.domElement = (domElement) ? domElement : "#"+code;
    this.content = [];
    this.periodTicker = -1;
    this.period = 1;
    this.disabled = false;
    this.periodTimeout = null;
    this.hideOnDefault = false;
}

staticAd.prototype = new ad;

staticAd.prototype.show = function staticAdShow() {
    var found = null, rollValue = null, timestamp = null, randomizedArray;
    try {
        //  Check to make sure this ad is enabled and has content
        this.checkIfActive();
        
        //  Make sure static ads only display once every x page view
        if (!this.periodExpired()) {
            return false;
        }

        //  If we only have the default item, fill the randomized array with all zeroes
        randomizedArray = this.fillRandomizedArray();

        //  Construct timestamp
        timestamp = this.constructTimestamp();

        //  Roll dice and return chosen content index
        rollValue = this.rollDice(randomizedArray);

        //  Add impression for this ad unit / content pair and return index of the content
        found = this.manager.addImpression(this.content[rollValue], this.code, timestamp);

        //  Draw the ad to the page
        this.insertContent(found,rollValue);

        //  Log success
        this.success(found,timestamp,rollValue);

        return true;
    } catch(e) { this.handleShowError(e,found,rollValue,timestamp); return false; }
}

//  Fill this ad unit with content and show it - static ads always have images (for now - TODO)
staticAd.prototype.insertContent = function staticAdInsertContent(found,rollValue) {
    var $domElement = $(this.domElement);
    
    //  If this ad unit is set to hide on default, and all we have is the default, don't show an ad
    if(this.doHideDefault())
        throw("hidingDefaultAd");

    //  Check to make sure this content exists
    if(!this.contentExists(found))
        throw("fileNotFound");

    try {
        if (this.domElement == "#persistentBox") {
            $domElement.parent().addClass("boxAdEnabled");
        }
        var adHTML = "<div style='background-image:url(" + this.manager.content[found].location + ");'></div>";
        $domElement.addClass("ad").html(adHTML).show();
        //  Bind behavior
        this.bindBehavior(rollValue);
    } catch(e) {
        popError(e);
        throw("insertFailed");
    }
};

//  Hide the related dom element and clear period timeout for this ad unit
staticAd.prototype.hide = function staticAdHide() {
    $(this.domElement).removeClass("ad").hide().empty().unbind();
    this.manager.sessionCampaignId = null;
};

//  If enough cycles have gone by, show this ad.
staticAd.prototype.periodExpired = function staticAdPeriodExpired() {
  var pageViews = (0 + viewManager.activeObject.views);
  var returnValue = (((this.period == 1) || isNaN(pageViews) || (pageViews % this.period == 1)) ? true : false);
  return(returnValue);
};

/*---------------------------------------------------------------*/

//  Sliding Main Menu Interstitial Ad - inherits from staticAd()
function slidingInterstitialAd(code, manager, domElement) {
    this.code = code;
    this.type = "slidingInterstitial";
    this.domElement = (domElement) ? domElement : "#"+code;
    this.manager = manager;
    this.content = [];
    this.periodTicker = -1;
    this.period = 0;
    this.disabled = false;
    this.periodTimeout = null;
    this.hideOnDefault = true;

    this.slideTimeout = null;
    this.slideTimeoutMS = 1000;
}

slidingInterstitialAd.prototype = new ad;

//  Fill this ad unit with content and in this.slideTimeoutMS slide it down from the top of the main menu page.
slidingInterstitialAd.prototype.insertContent = function slidingInterstitialAdInsertContent(found,rollValue) {
    //  Disable after first use - this is a one-time interstitial.
    this.disabled = true;

    //  If this ad unit is set to hide on default, and all we have is the default, don't show an ad
    if(this.doHideDefault())
        throw("hidingDefaultAd");

    //  Check to make sure this content exists
    if(!this.contentExists(found))
        throw("fileNotFound");

    try {
        var me = this;
        var adHTML = "<div style='width:100%;height:100%;background:url("+this.manager.content[found].location+") no-repeat;'></div>";
        $(this.domElement).removeClass("visible").html(adHTML);
    
        //  Bind behavior
        this.bindBehavior(rollValue);
    
        this.slideTimeout = setTimeout(function() { $(me.domElement).addClass("visible"); me.slideTimeout = setTimeout(function() { me.hide(); }, me.period*1000 + me.slideTimeoutMS); }, this.slideTimeoutMS);
    } catch(e) { throw("insertFailed"); }
};

//  Hide the related dom element and clear the slide timeout
slidingInterstitialAd.prototype.hide = function slidingInterstitialAdHide() {
    clearTimeout(this.slideTimeout);
    $(this.domElement).removeClass("visible").unbind();
    this.manager.sessionCampaignId = null;
};

/*---------------------------------------------------------------*/

// Sliding Main Menu Interstitial Ad - inherits from staticAd()
function timedInterstitialAd(code, manager, domElement) {
    this.code = code;
    this.type = "timedInterstitialAd";
    this.domElement = (domElement) ? domElement : "#" + code;
    this.manager = manager;
    this.content = [];
    this.periodTicker = -1;
    this.period = 0;
    this.disabled = false;
    this.periodTimeout = 480000;
    this.hideOnDefault = true;

    this.slideTimeout = null;
    this.slideTimeoutMS = 1000;
}

timedInterstitialAd.prototype = new ad;

timedInterstitialAd.prototype.show = function timedInterstitialAdShow() {
    var found = null, rollValue = null, timestamp = null, randomizedArray, me = this, periodTimeout = 0;
    try {
    //  Check to make sure this ad is enabled and has content
    this.checkIfActive();

    //  If we only have the default item, fill the randomized array with all zeroes
    randomizedArray = this.fillRandomizedArray();

    //  Construct timestamp
    timestamp = this.constructTimestamp();

    //  Roll dice and return chosen content index
    rollValue = this.rollDice(randomizedArray);

    //  Add impression for this ad unit / content pair and return index of the content
    found = this.manager.addImpression(this.content[rollValue], this.code, timestamp);

    //  Draw the ad to the page    
    this.slideTimeout = setTimeout(function() {
        periodTimeout = me.periodTimeout;
        me.insertContent(found, rollValue);
    }, periodTimeout);

    //  Log success
    this.success(found,timestamp,rollValue);

    return true;
    } catch(e) { this.handleShowError(e,found,rollValue,timestamp); return false; }
};

// Fill this ad unit with content and in this.slideTimeoutMS slide it down from
// the top of the main menu page.
timedInterstitialAd.prototype.insertContent = function timedInterstitialAdInsertContent(found, rollValue) {
    var me = this;

    // If this ad unit is set to hide on default, and all we have is the
    // default, don't show an ad
    if (me.doHideDefault())
        throw ("hidingDefaultAd");

    // Check to make sure this content exists
    if (!me.contentExists(found))
        throw ("fileNotFound");

    try {
        var adHTML = "<div class='adContent' style='background-image:url(" + me.manager.content[found].location + ");'></div>";
        $(me.domElement).removeClass("visible").html(adHTML);

        // Bind behavior
        me.bindBehavior(rollValue);

        clearTimeout(me.slideTimeout);
        me.slideTimeout = setTimeout(function() {
            $(me.domElement).addClass("visible");
            me.slideTimeout = setTimeout(function() {
                me.hide();
            }, (me.period * 10));
        }, me.slideTimeoutMS);
    } catch (e) {
        throw ("insertFailed");
    }
};

// Hide the related dom element and clear the slide timeout
timedInterstitialAd.prototype.hide = function timedInterstitialAdHide() {
    var me = this;
    clearTimeout(me.slideTimeout);
    $(me.domElement).removeClass("visible").unbind();
    this.manager.sessionCampaignId = null;
};

/*---------------------------------------------------------------*/

//  Sliding Main Menu Interstitial Ad - inherits from staticAd()
function prerollVideoAd(code, manager, domElement) {
    this.code = code;
    this.type = "slidingInterstitial";
    this.domElement = (domElement) ? domElement : "#"+code;
    this.manager = manager;
    this.content = [];
    this.periodTicker = 0;
    this.period = 0;
    this.disabled = false;
    this.periodTimeout = null;
    this.hideOnDefault = true;
    this.preRollVideoAdTimeout = null;
    this.slideTimeout = null;
    this.slideTimeoutMS = 1000;
    this.videoBool = false;
    this.found = -1;
    this.rollValue;
}

prerollVideoAd.prototype = new ad;

//  If period ticker is at zero, fill the given ad unit with a randomly-chosen video from content array, and record the impression.
prerollVideoAd.prototype.show = function prerollVideoAdShow() {
    var timestamp = null;
    try {
        // Check to make sure this ad is enabled and has content
        this.checkIfActive();

        // If we haven't yet reached our period count, increment period ticker and bail
        if (!this.periodExpired()) {
            this.tick();
            return false;
        }
        // Reset period ticker
        this.resetTicker();
        // If we only have the default item, fill the randomized array with all zeroes
        var randomizedArray = this.fillRandomizedArray();

        // Construct timestamp
        timestamp = this.constructTimestamp();

        // Roll dice and return chosen content index
        this.rollValue = this.rollDice(randomizedArray);

        // Add impression for this ad unit / content pair and return index of the content
        // var found = this.manager.addImpression(this.content[rollValue], this.code, timestamp);

        // Draw the ad to the page

        this.insertContent(this.content[this.rollValue], this.rollValue);

        this.videoBool = true;
        
        // Log success
        this.success(this.found,timestamp,this.rollValue);

        adMan.sessionCampaignId = viewManager.campaignId = this.content[this.rollValue].campaign;

        return true;
    } catch (e) {
        this.handleShowError(e, this.found, this.rollValue, timestamp);

        adMan.sessionCampaignId = viewManager.campaignId = null;
        return false;
    }
};

prerollVideoAd.prototype.addVideoImpression = function prerollVideoAdAddVideoImpression(playTime) {
    var code = this.code;
    
    var ad = this.content[this.rollValue];
    var impression = new adImpression(ad.id, code, parseInt(ad.campaign), playTime);
    impressions.addImpression(impression);
    this.logAddImpression(ad, code, playTime);
    
    this.videoBool = false;
};

//  Fill this ad unit with content and in this.slideTimeoutMS slide it down from the top of the main menu page.
prerollVideoAd.prototype.insertContent = function prerollVideoAdInsertContent(content, rollValue) {
    //  If this ad unit is set to hide on default, and all we have is the default, don't show an ad
    if(this.doHideDefault())
        throw("hidingDefaultAd");

    try {
        for( var i=0, ilen=this.manager.content.length; i<ilen; i++ ) {
            if(this.manager.content[i].id != content.id)
                continue;
    
            this.found = i;
            break;
        }
        
        if(this.found < 0)
            throw("contentIdNotFound");//  If content id didn't match main ad content list, bail.
    
        //  Kill existing video player
        var $videoContainer = $("#videoContainer");
    
        stopVideo($videoContainer);

        //  Start video player
        if(this.preRollVideoAdTimeout)
           clearTimeout(this.preRollVideoAdTimeout);
    
        var locationStr = this.manager.content[this.found ].location;
    
        this.preRollVideoAdTimeout = setTimeout( function(){
           // https://npjira.atlassian.net/browse/QT-485
           // FIX: Previous volume setting retained at new session for the duration of a campain ad.
           // https://npjira.atlassian.net/browse/QT-507
           // FIX: Campaign ads are muted when transitioning from iPod to an option which prompts to play an ad.
           // Get the volume from the current view.
           setVolume("ondemand", String((viewManager.activeObject.volume) ? viewManager.activeObject.volume : machineObj.getVolumeLevel()));
           
            //  Insert html string
           var playerstring = '<object type="video/mpeg" vout="yes" id="videoPlayer" data="' + locationStr + '">' +
                                  '<param name="wmode" value="transparent" />' +
                                  '<param name="data_type" value="ondemand" />' +
                                  '<param name="startInFullscreen" value="' + ($('#fullscreenBackground').length && $('#fullscreenBackground').css("display") != "none") + '">' +
                                  '<param name="fullscreen_support" value="' + ((machineObj.getSlaveState() == 3) ? "no" : "yes") + '" />' +
                              '</object>';
            playVideo($videoContainer, playerstring);
        }, 500 );
        
        this.disableChannelButtons();
        
        // Bind behavior
        this.bindBehavior(rollValue);
        
    } catch(e) { throw("insertFailed"); }
};

prerollVideoAd.prototype.disableChannelButtons = function disableChannelButtons(){
    
    if($("#channel #nextButton").length && $("#channel #backButton").length){
        $("#channel #nextButton").addClass("disabled");
        $("#channel #backButton").addClass("disabled");
    }

};

//  Hide the related dom element and clear the slide timeoutdoNetworkCheck
prerollVideoAd.prototype.hide = function prerollVideoAdHide() {
    clearTimeout(this.slideTimeout);
    $(this.domElement).removeClass("visible");
    this.manager.sessionCampaignId = null;
};

/*---------------------------------------------------------------*/

// Startup Video Ad - inherits from prerollVideoAd()
function startupVideoAd(code, manager, domElement) {
    this.code = code;
    this.type = "slidingInterstitial";
    this.domElement = (domElement) ? domElement : "#"+code;
    this.manager = manager;
    this.content = [];
    this.periodTicker = 0;
    this.period = 0;
    this.disabled = false;
    this.periodTimeout = null;
    this.hideOnDefault = false;
    this.preRollVideoAdTimeout = null;
    this.slideTimeout = null;
    this.slideTimeoutMS = 1000;
    this.videoBool = false;
    this.found = -1;
    this.rollValue;
    this.startupVideoCounter = 1;
}
startupVideoAd.prototype = new prerollVideoAd;

startupVideoAd.prototype.showStartupVideoView = function startupVideoAdShowStartupVideoView(nextView) {
    
    var startupVideoFrequency = adMan.ads[this.code].period;
    this.periodTicker = 0;

    if(viewManager.getViewCount("startupVideo") >= 1)
        this.startupVideoCounter--;
    
    if (!this.hideOnDefault && viewManager.isViewAvailable("startupVideo") && this.startupVideoCounter == startupVideoFrequency) {
        viewManager.nextView = nextView;
        viewManager.show("startupVideo");
        this.startupVideoCounter = 1;
    } else if (!this.hideOnDefault && viewManager.isViewAvailable("startupVideo") && this.startupVideoCounter != startupVideoFrequency) {
        this.startupVideoCounter++;
        viewManager.showNextView();
    } else {
        viewManager.showNextView();
    }
};

startupVideoAd.prototype.showLandingVideoAd = function startupVideoAdShowLandingVideoAd() {
    if(viewManager.getViewCount("landingPage") == 0 && !this.hideOnDefault && this.period > 0 && this.show()){
        this.period--;
        return true;
    } else {
        writeLog("info","Landing video is not supposed to play");
        return false;
    }
};


/*---------------------------------------------------------------*/

//  Video carousel content - inherits from basic ad()
function videoCarouselAd(code, manager, domElement) {
    this.code = code;
    this.type = "videoCarousel";
    this.manager = manager;
    this.domElement = (domElement) ? domElement : "#"+code;
    this.content = [];
    this.periodTicker = -1;
    this.period = 0;
    this.disabled = false;
    this.periodTimeout = null;
    this.hideOnDefault = false;
}

videoCarouselAd.prototype = new ad;

videoCarouselAd.prototype.show = function videoCarouselAdShow() {
    var items = [],
vmCampaign = this.manager.sessionCampaignId;
    for ( var i = 0, ilen = this.content.length; i < ilen; i++) {
        for ( var j = 0, jlen = this.manager.content.length; j < jlen; j++) {
            var contentItem = this.manager.content[j];
            if (contentItem.id != this.content[i].id) {
                continue;
            }
            var thisItem = {
                "id" : contentItem.id,
                "title" : contentItem.name,
                "artist" : contentItem.info2,
                "type" : contentItem.type,
                "thumbnail" : contentItem.thumbnail,
                "location" : contentItem.location,
                "campaign" : this.manager.ads["branded_carousel"].content[i].campaign
            };
            if (vmCampaign && vmCampaign != thisItem.campaign) {
                // Only show if this is part of the same campaign.
                continue;
            }
            items.push(thisItem);
        }
    }
    return items;
};

//  -------------------------- Ad click-thru behaviors ---------------------------------

//  Open the popup video player with the given background and video IDs
function ad_clickToPopupVideo(bkgndId, videoId) {
    try {
        adMan.showPopupVideo(bkgndId, videoId);
    } catch(e) { popError(e); }
}

//  Redirect the user to the given page
function ad_clickToPage(pageName, adUnit, campaignId, rollValue) {
    try {
        adMan.sessionCampaignId = campaignId;
        viewManager.campaignId = campaignId;
        viewManager.show(pageName);
    } catch (e) { popError(e); }
}

//  Trigger the email behavior for the given campaign
function ad_clickSubscribe(contentId, adUnit, campaignId, rollValue) {
    var isText = false;
    if (!athleteObj.get_user_id()) {
        adMan.loginPrompt();
        return;
    }
    adMan.subscribe(contentId, adUnit, campaignId, rollValue);
}
function ad_clickToSubscribe(contentId, adUnit, campaignId, rollValue, adId) { 
    var isText = true;
    if (!athleteObj.get_user_id()) {
        adMan.loginPrompt();
        return;
    }
    adMan.subscribe(contentId, adUnit, campaignId, rollValue, adId, isText);
}

function ad_popupStatic(){
    var me = this;
    adMan.showPopupVideo();
}

//  -------------------------- Ad Rotation ---------------------------------

// Ad rotation and period checker.
// var adRotation = new AdRotation(); adRotation.allowAd();
function AdRotation(rotationPeriod, secondsToElapse) {"use strict";
    var me = this;
    this.isFirstRotation = true;
    this.rotationPeriod = ((rotationPeriod) ? rotationPeriod : 3);
    this.secondsToElapse = ((secondsToElapse) ? secondsToElapse : 3);
    this.videosShown = 0;
    this.intervalTimer = null;

    this.clearVideoInterval = function clearVideoInterval() {
        if (me.intervalTimer) {
            clearInterval(me.intervalTimer);
        }
    };

    this.checkVideoInterval = function checkVideoInterval() {
        me.clearVideoInterval();
        me.intervalTimer = setInterval(function checkVideoIntervalTimer() {
            if (me.secondsToElapse <= (guiObj.getVideoTimeElapsedInPer() * 100)) {
                me.clearVideoInterval();
                me.videosShown += 1;
            }
        }, 500);
    };

    this.allowAd = function allowAd() {
        var allowThisAd = (me.isFirstRotation || (me.videosShown >= me.rotationPeriod));
        if (me.isFirstRotation) {
            me.isFirstRotation = false;
        }
        if (!allowThisAd && !me.intervalTimer) {
            me.checkVideoInterval();
        }
        return (allowThisAd);
    };

    this.reset = function reset() {
        me.clearVideoInterval();
        me.videosShown = 0;
    };

    this.reset();
}



function showAds(){
    var reqURL = DIR_ROOT+"/data/prod/media.xml";

    var successCallback = function(data){
        writeLog('info', 'n5iads.jsp failed - but here are the ads we should have: ')

        var theAds = $(data).find('allads')[0].getElementsByTagName('content');

        for(var i=0; i<theAds.length; i++){

            var adID = theAds[i].getAttribute('id');

            writeLog('info','Ad Unit: ID - ' + adID);
        }
    }

    var errorCallback = function(textStatus){
        writeLog('info', 'media.xml did not load to show available ads.');
    }

    var continueCallback = null;
    var reqTimeout = null;
    var reqType = null;
    var reqDataType = "xml";

    dirtyHarry(reqURL, successCallback, errorCallback, continueCallback, reqTimeout, reqType, reqDataType);
}


