

function slidingBox(data, $window, $slidingBox, $backButton, $nextButton, itemsToScroll, parallaxWidth, backButtonOnTop, $cueContainer, hidePagination)
{
    this.data = data;
    this.$window = $window;
    this.$box = $slidingBox;
    this.$back = $backButton;
    this.$next = $nextButton;
    this.itemsToScroll = itemsToScroll;
    this.parallaxWidth = parallaxWidth;
    this.backButtonOnTop = backButtonOnTop;
    this.$cueContainer = ($cueContainer) ? $cueContainer : false;
    this.currentPage = 0;
    this.hidePagination = hidePagination;
    this.inTransition = false;

    //  Get the initial left position
    this.currentLeft = new Number(parseInt(this.$box.css("left")));
    this.currentLevel = 0;
    this.chosenItems = new Array();
    this.savedLefts = new Array();

    this.scrollSpeed = 500;

    this.attachEvents();
    this.drawLevel(0);
}

slidingBox.prototype.attachEvents = function slidingBoxAttachEvents() {
    var me = this;

    //  Always select the item that is pressed.
    me.$box.find("li").live("mousedown", function() { me.chosenItems[me.currentLevel] = $(this).find("input").val(); });

    if(me.$cueContainer)
        me.$cueContainer.bind("click", function(e) { me.cueContainerPressed(e); });
};

slidingBox.prototype.drawLevel = function slidingBoxDrawLevel(which) {
    var me = this;

    var scrollingDown = (which > me.currentLevel);

    //  Scrolling down - add current left position to this.savedLefts[]
    if(scrollingDown)
    {
        me.savedLefts[me.currentLevel] = me.currentLeft;
        me.currentPage = 0;
    }

    me.currentLevel = which;

    //  Always set the left to zero if scrolling down. Otherwise set it back to what it previously was (if we have it saved).
    me.currentLeft = (scrollingDown) ? 0 : (me.savedLefts[me.currentLevel]) ? me.savedLefts[me.currentLevel] : 0;

    me.drawList();

    if(!scrollingDown)
    {
        var itemWidth = new Number(parseInt(me.getItemWidth(me.$box.find(".separator"))));
        me.currentPage = -1*(me.currentLeft/itemWidth);
    }

    me.attachScrollEvents();

    //  If there is an attachEvents() function defined for this level, use it. Otherwise use the default.
    if(me.data.levels[me.currentLevel])
    {
        if(me.data.levels[me.currentLevel].attachEvents)
        {
            me.data.levels[me.currentLevel].attachEvents(me, me.$box);
            return;
        }
    }

    me.attachEventsDefault();
};

slidingBox.prototype.attachScrollEvents = function slidingBoxAttachScrollEvents() {
    var me = this;
    me.$next.unbind("click");
    me.$back.unbind("click");
    
    // For next and back, make sure the page is not transitioning to the next one before
    // invokinig scrollNext or scrollBack. We don't want to skip pages if the button is double
    // clicked
    if(me.data.levels[me.currentLevel].scrollNext)
        me.$next.bind("click", function(e) {
        	if (!me.inTransition) {  
        		me.data.levels[me.currentLevel].scrollNext(e);
        		if (doTransitions) {
        			me.inTransition = true;
        			setTimeout(function() { me.inTransition = false; }, 500);
        		}
        	}
        });
    else
        me.$next.bind("click", function(e) {
        	if (!me.inTransition) {  
        		me.scrollNext(e); 
        		if (doTransitions) {
        			me.inTransition = true;
        			setTimeout(function() { me.inTransition = false; }, 500);
        		}
        	}
        });
    
    if(me.data.levels[me.currentLevel].scrollBack)
        me.$back.bind("click", function(e) { 
        	if (!me.inTransition) { 
        		me.data.levels[me.currentLevel].scrollBack(e); 
        		if (doTransitions) {
        			me.inTransition = true;
        			setTimeout(function() { me.inTransition = false; }, 1000);
        		}
        	}
        });
    else
        me.$back.bind("click", function(e) { 
        	if (!me.inTransition) { 
        		me.scrollBack(e);
        		if (doTransitions) {
        			me.inTransition = true;
        			setTimeout(function() { me.inTransition = false; }, 500);
        		}
        	}
        });
};

slidingBox.prototype.drawNextLevel = function slidingBoxDrawNextLevel() {
    var me = this;
    me.drawLevel(me.currentLevel+1);
};

slidingBox.prototype.attachEventsDefault = function slidingBoxAttachEventsDefault() {
    var me = this;

    me.$box.find("li").each(function() {
        $(this).bind("click", function() { me.drawNextLevel(); });
    });
};

slidingBox.prototype.drawItemDefault = function slidingBoxDrawItemDefault(data) {
    return("<h3>"+data.title+"</h3>");
};

slidingBox.prototype.drawCue = function slidingBoxDrawCue() {
    var me = this;

    if(doTransitions)
        me.$cueContainer.animate({"opacity" : "0"}, 150, "linear", function() { me.updateCues(); });

    else
    {
        me.$cueContainer.css("opacity","0");
        me.updateCues();
    }
};

slidingBox.prototype.updateCues = function slidingBoxupdateCues()
{
    var me = this;

    //  If only one page, don't draw cues.
    if(me.$box.find(".separator").size() <= 1)
        return;

    var htmlStr = "<ul>";

    for(var i=0;i<me.$box.find(".separator").size();i++)
    {
        htmlStr += (i == me.currentPage) ? "<li class='selected' rel='"+i+"'></li>" : "<li rel='"+i+"'></li>";
    }

    htmlStr += "</ul>";

    me.$cueContainer.css("width", "auto").html(htmlStr);

    me.centerCueContainer();

    if(doTransitions)
        me.$cueContainer.animate({"opacity" : "1"}, 150, "linear");
    else
        me.$cueContainer.css("opacity","1");
}

slidingBox.prototype.centerCueContainer = function slidingBoxcenterCueContainer()
{
    var me = this;
    me.$cueContainer.width(me.$cueContainer.find("ul").width());
    me.$cueContainer.css("left", (me.$window.width() - me.$cueContainer.width())/2+"px");
}

slidingBox.prototype.highlightCurrentPageCue = function slidingBoxhighlightCurrentPageCue()
{
    var me = this;

    var i = 0;

    me.$cueContainer.find("li").each(function() {

        if(i == me.currentPage)
            $(this).addClass("selected");
        else
            $(this).removeClass("selected");

        i++;

    });
}

slidingBox.prototype.cueContainerPressed = function slidingBoxcueContainerPressed(e)
{
    if(e.target.nodeName.toLowerCase() != "li")
        return true;

    var chosenPage = $(e.target).attr("rel");
    this.scrollTo(chosenPage);
}

slidingBox.prototype.drawList = function slidingBoxdrawList()
{
    var me = this;
    var list = me.getCurrentList();
    var str = "";

    //  If no list, return an empty string (TODO)
    if(!list)
        return(str);

    var itemsPerPage = (me.data.levels[me.currentLevel].itemsPerPage) ? me.data.levels[me.currentLevel].itemsPerPage : 1;
    for(var i=0;i<list.length;i++)
    {
        if(i%itemsPerPage == 0)
            str += "<div class='separator'>";

        str += "<li id='level_"+me.currentLevel+"_item_"+i+"' class='level"+me.currentLevel+"'>";

            //  If drawItem() is not defined for this level, use the default.
            str += (me.data.levels[me.currentLevel])
                ?   (me.data.levels[me.currentLevel].drawItem)
                    ?   me.data.levels[me.currentLevel].drawItem(list[i])
                    :   me.drawItemDefault(list[i])
                :   me.drawItemDefault(list[i]);

            //  Hidden input containing the id of this item
            str += "<input type='hidden' class='item_id' value='"+i+"' / >";

        str += "</li>";

        if((i+1)%itemsPerPage == 0)
            str += "</div>";
    }

    me.$box.html(str);
    me.resetBoxWidth();
    me.$box.css("left", me.currentLeft+"px");

    if(me.$cueContainer)
        me.drawCue();

    me.updateScrollButtons();
}

slidingBox.prototype.resetBoxWidth = function slidingBoxresetBoxWidth()
{
    var me = this;
    var width = 0;

    me.$box.find(".separator").each(function() {

        width += me.getItemWidth($(this));

    });

    if(width < parseInt(me.$window.css("width")))
        width = parseInt(me.$window.css("width"));

    me.$box.css("width", width+"px");
}

slidingBox.prototype.getItemWidth = function slidingBoxgetItemWidth($item)
{
    var width = (parseInt($item.css("width")) + parseInt($item.css("border-left-width")) + parseInt($item.css("border-right-width")) + parseInt($item.css("padding-left")) + parseInt($item.css("padding-right")) + parseInt($item.css("margin-left")) + parseInt($item.css("margin-right")));

    return(width);
}

slidingBox.prototype.getCurrentList = function slidingBoxgetCurrentList()
{
    var me = this;

    var str = "me.data.items";

    for(var i=0;i<me.currentLevel;i++)
        str += "[me.chosenItems["+i+"]].items";

    return(eval(str));
}

slidingBox.prototype.scrollBack = function slidingBoxscrollBack()
{
    var me = this;

    var windowWidth = new Number(parseInt(me.$window.css("width")));
    var itemWidth = new Number(parseInt(me.getItemWidth(me.$box.find(".separator"))));
    var scrollWidth = itemWidth*me.itemsToScroll;

    //  If we are scrolling up one level, return.
    if(me.currentLeft >= 0 && me.currentLevel > 0 && parseInt(me.$box.css("left")) >= 0)
    {
        me.drawLevel(me.currentLevel - 1);
        me.updateScrollButtons();
        return;
    }
    else if(me.currentLeft >= 0)
    {
        //  If we're at the very beginning of the list, do backButtonOnTop()
        if(me.currentLevel == 0 && this.backButtonOnTop && parseInt(me.$box.css("left")) >= 0)
        {
            this.backButtonOnTop();
            return;
        }
        //  Beginning of list - just bounce
        me.currentLeft = 0;
        me.bounceBack();
        me.updateScrollButtons();
        return;
    }
    else if(me.currentLeft + scrollWidth >= 0)
    {
        this.currentPage--;
        me.currentLeft = 0;
    }
    else
    {
        this.currentPage--;
        me.currentLeft += scrollWidth;
    }

    me.scroll();
    me.updateScrollButtons();
}

slidingBox.prototype.scrollNext = function slidingBoxscrollNext()
{
    var me = this;

    var windowWidth = new Number(parseInt(me.$window.css("width")));
    var boxWidth = new Number(parseInt(me.$box.css("width")));
    var itemWidth = new Number(parseInt(me.getItemWidth(me.$box.find(".separator"))));
    var scrollWidth = itemWidth*me.itemsToScroll;

    if(me.currentLeft <= parseInt((boxWidth*-1) + windowWidth))
    {
        //  End of list - just bounce
        me.currentLeft = parseInt((boxWidth*-1) + windowWidth);
        me.bounceForward();
        me.updateScrollButtons();
        return;
    }
    else if(me.currentLeft - windowWidth <= (boxWidth*-1) + scrollWidth)
    {
        this.currentPage++;
        me.currentLeft = (boxWidth*-1) + windowWidth;
        me.scroll(true);
        me.updateScrollButtons();
        return;
    }
    else
    {
        this.currentPage++;
        me.currentLeft -= scrollWidth;
    }

    me.scroll();
    me.updateScrollButtons();
}

slidingBox.prototype.scrollTo = function slidingBoxscrollTo(chosenPage)
{
    var me = this;

    var windowWidth = new Number(parseInt(me.$window.css("width")));
    var boxWidth = new Number(parseInt(me.$box.css("width")));
    var itemWidth = new Number(parseInt(me.getItemWidth(me.$box.find(".separator"))));
    var scrollWidth = itemWidth*me.itemsToScroll;

    this.currentPage = chosenPage;
    me.currentLeft = -1*scrollWidth*chosenPage;

    me.scroll();
    me.updateScrollButtons();
}

// based on scrollTo() and transitions set to false
slidingBox.prototype.scrollJump = function slidingBoxscrollJump(chosenPage)
{
    var me = this;
	doTransitions = false;

    var windowWidth = new Number(parseInt(me.$window.css("width")));
    var boxWidth = new Number(parseInt(me.$box.css("width")));
    var itemWidth = new Number(parseInt(me.getItemWidth(me.$box.find(".separator"))));
    var scrollWidth = itemWidth*me.itemsToScroll;

    this.currentPage = chosenPage;
    me.currentLeft = -1*scrollWidth*chosenPage;

    me.scroll();
    me.updateScrollButtons();
}

slidingBox.prototype.updateScrollButtons = function slidingBoxUpdateScrollButtons() {
    var me = this;
    var windowWidth = new Number(parseInt(me.$window.css("width")));
    var boxWidth = new Number(parseInt(me.$box.css("width")));

    if(me.currentLeft <= parseInt((boxWidth*-1) + windowWidth))
        me.hideScrollNextButton();
    else
        me.showScrollNextButton();

    if(me.currentLeft >= 0)
    {
        if(me.currentLevel == 0)
        {
            if(me.backButtonOnTop)      //  Allow us to back out of this page at the top level
                me.showScrollBackButton();
            else
                me.hideScrollBackButton();
        }
        else
            me.showScrollBackButton();
    }
    else
        me.showScrollBackButton();

    if(me.$cueContainer)
        me.highlightCurrentPageCue();
};

slidingBox.prototype.hideScrollBackButton = function slidingBoxHideScrollBackButton() {
    if(!this.$back.is(".hidden"))
        this.$back.addClass("hidden");
};

slidingBox.prototype.showScrollBackButton = function slidingBoxShowScrollBackButton() {
    if(this.$back.is(".hidden"))
        this.$back.removeClass("hidden");
};

slidingBox.prototype.hideScrollNextButton = function slidingBoxHideScrollNextButton() {
    if(!this.$next.is(".hidden"))
        this.$next.addClass("hidden");
};

slidingBox.prototype.showScrollNextButton = function slidingBoxShowScrollNextButton() {
    if(this.$next.is(".hidden"))
        this.$next.removeClass("hidden");
};

slidingBox.prototype.bounceForward = function slidingBoxBounceForward() {
    var me = this;

    if(!doTransitions)
        return;

    me.$box.stop().animate(
        {left : (me.currentLeft-25)+"px"},
        150,
        function()
        {
            me.$box.animate(
                {left: me.currentLeft+"px"},
                300,
                "easeOutBack"
            );
        }
    );
};

slidingBox.prototype.bounceBack = function slidingBoxBounceBack() {
    var me = this;

    if(!doTransitions)
        return;

    me.$box.stop().animate(
        {left : (me.currentLeft+25)+"px"},
        150,
        function()
        {
            me.$box.animate(
                {left: me.currentLeft+"px"},
                300,
                "easeOutBack"
            );
        }
    );
};

slidingBox.prototype.scroll = function slidingBoxScroll() {
    var me = this;

    if(me.parallaxWidth)
        me.doParallax();

    if(doTransitions)
        me.$box.stop().animate({left : me.currentLeft+"px"}, me.scrollSpeed);
    else
        me.$box.css("left",me.currentLeft+"px");
};

slidingBox.prototype.doParallax = function slidingBoxDoParallax() {
    var me = this;

    var scrollDistance = parseInt(me.$box.css("left")) - me.currentLeft;
    var scrollRatio = scrollDistance/parseInt(me.$box.css("width"));
    var parallaxDistance = scrollRatio*me.parallaxWidth;
    var currentBackgroundX = parseInt(me.$window.css("background-position-x"));
    var newBackgroundX = currentBackgroundX - parallaxDistance;

    if(newBackgroundX > 0)
        newBackgroundX = 0;

    if(doTransitions)
        me.$window.stop().animate({"background-position-x" : newBackgroundX+"px"}, me.scrollSpeed, "linear");
};