//
//  Media.xml parser
//
function mediaXMLObj($data) {
    this.$data = $data;
    this.musicVideos = [];
    this.onDemand = [];
    this.allMusic = [];
    this.virtualActive = [];
    this.featured = {
        "onDemand": [],
        "musicVideos": [],
        "virtualActive": []
    }; 
    this.isYouTubeEnabled = (!!window.enableYouTube && "US" == machineObj.getCountryCode());
    this.isCbsEnabled = (!!window.enableCBS && "US" == machineObj.getCountryCode()); 
    this.init();
}

mediaXMLObj.prototype.init = function mediaXMLObjInit() {
	this.loadOnDemandContent();
	this.loadMusicVideoContent();
	this.loadCustomPlaylistContent();
	this.loadVirtualActive();
};


mediaXMLObj.prototype.loadOnDemandContent = function mediaXMLObjLoadOnDemandContent() {
    
    writeLog("info", "Starting Load of OnDemand Content...");

    var me = this;
    me.onDemand = [];
    me.featured.onDemand = [];

    var list = me.$data.find('list');
    var ifile = me.$data.find('ifile');
    try{
        for(var i=0; i<list.length; i++){
            var listParent = list[i].parentNode.getAttribute("name");
            
            if(listParent == "ondemand"){
                var listChannel = list[i].getElementsByTagName('channel'); 
                if (listChannel.length == 0) {
                    throw "legacyMediaXML";
                }
                
                var channelThumb = $(listChannel).find('ifile').attr('name');
        
                var channel = {};
                channel.title = list[i].getAttribute("name");
                channel.shuffle = (list[i].getAttribute("shuffle") == "yes") ? true : false;
                channel.thumbnail = MEDIA_DIR+channelThumb;
                channel.items = [];


                for(var j=0; j<listChannel.length; j++){
                    var channelContent = listChannel[j].getElementsByTagName("content");
                    var showThumb = $(channelContent).find('ifile').attr('name');

                    var show = {
                        title     : listChannel[j].attributes.item(0).value,
                        shuffle   : false,
                        thumbnail : MEDIA_DIR + showThumb,
                        type      : "onDemand",
                        items     : []
                    };

                    for(var z=0; z<channelContent.length; z++){

                        var whichContentType = channelContent[z].attributes.item(3).value;
                        switch(whichContentType.toUpperCase()){
                            case "CBS":
                            case "CBS-V2":
                                if (!me.isCbsEnabled) { return; }
                                break;
                                
                            case "GATEWAY":
                            case "LOCAL":
                                break;
                                
                            case "YOUTUBE-PLAYLIST":
                                if (!me.isYouTubeEnabled) { return; }
                                break;
                                
                            default:
                                return;
                        }
                        var thisItem = me.createNewItem(channelContent[z]);
                        show.items.push(thisItem);
                    }
                    
                    if(show.items.length > 0){
                        channel.items.push(show);
                                        
                        var $featured = $(this).find("featured[skin='"+g_mfgStyle+"']");
                        if ($featured.length > 0) {
                            me.featured.onDemand.push({
                                title     : $(this).attr("name"),
                                thumbnail : MEDIA_DIR + $featured.find("ifile").attr("name"),
                                channel   : me.onDemand.length,
                                show      : channel.items.length-1
                            });
                        }
                    }
                    
                }

                if(channel.items.length > 0){
                    me.onDemand.push(channel);
                }
            }
        }
    } catch(e) { 
        if (e == "legacyMediaXML") {
            me.loadLegacyOnDemandContent();
        } else {
            popError(e);
        }
    }
};

mediaXMLObj.prototype.loadLegacyOnDemandContent = function mediaXMLObjLoadLegacyOnDemandContent() {
    var me = this;
    me.onDemand = [];
    
    me.$data.find("page").each(function mediaXMLObjFindODPage() {
        if ($(this).attr("name").toLowerCase() != "ondemand" || machineObj.isOutsideUS())
            return;
        
        $(this).find("list").each(function mediaXMLObjFindODList() {
            if ($(this).attr("name").toLowerCase() == "virtual active")
                return;
            
            var $this = $(this);
            var channel = {
                title     : $this.attr("name"),
                shuffle   : (($this.attr("shuffle") == "yes") ? true : false),
                thumbnail : (MEDIA_DIR + $this.find("ifile").attr("name")),
                type      : "onDemand",
                items     : []
            };
            
            $(this).find("content").each(function mediaXMLObjFindODContent() {
                try {
                    switch ($(this).attr("type").toUpperCase()) {
                        case "CBS":
                        case "CBS-V2":
                            if (!me.isCbsEnabled) { return; }
                            break;
                            
                        case "GATEWAY":
                        case "LOCAL":
                            break;
                            
                        case "YOUTUBE-PLAYLIST":
                            if (!me.isYouTubeEnabled) { return; }
                            break;
                        
                        default:
                            return;
                    }
                    
                    var thisItem = me.createNewItem(this);
                    //TODO: This needs to find which show it belongs to, then say .items[i] = episode
                    for (var i = 0, thisShow = (-1), clen = channel.items.length; i < clen; i++) {
                        if (thisItem.artist == channel.items[i].title)
                            thisShow = i;
                    }
                    //  If a matching artist/show was found, add this episode to that show.
                    if (thisShow > -1)
                        channel.items[thisShow].items.push(thisItem);
                    //  Otherwise add this show to the list of shows for this channel.
                    else {
                        var show = {
                            title     : thisItem.artist,
                            shuffle   : thisItem.shuffle,
                            thumbnail : thisItem.thumbnail,
                            type      : "onDemand",
                            items     : [thisItem]
                        };
                        
                        if (show.items.length > 0)
                            channel.items.push(show);
                    }
                    
                } catch(e) { popError(e); }
            });
            
            if (channel.items.length > 0)
                me.onDemand.push(channel);
         });
     });

    writeLog("info", "OnDemand Content Loaded.");
};

mediaXMLObj.prototype.loadMusicVideoContent = function mediaXMLObjLoadMusicVideoContent() {

    writeLog("info", "Starting Load of Music Content...");

    var me = this;
    me.musicVideos = [];
    me.featured.musicVideos = [];

    var list = me.$data.find('list');
    try {
        for(i=0; i<list.length; i++){
            var listParent = list[i].parentNode.getAttribute("name");
            if(listParent == "music"){
                var channelContent = list[i].getElementsByTagName('content');
                var fileList = list[i].getElementsByTagName("ifile").item(0);
                var fileName = fileList.attributes.item(0).value;
                var channel = {};
                channel.title = list[i].getAttribute("name");
                channel.shuffle = (list[i].getAttribute("shuffle") == "yes") ? true : false;
                channel.thumbnail = MEDIA_DIR + fileName;
                channel.type = "musicVideos";
                channel.items = [];
        
                var listContent = channelContent;

                for(var j=0; j < channelContent.length; j++){
                    var episode = me.createNewItem(listContent[j]);
                    channel.items.push(episode);  
                }

                 if (channel.items.length > 0) {
                    me.musicVideos.push(channel);
                    
                    var $featured = $(this).find("channel").find("featured[skin='"+g_mfgStyle+"']");
                    if ($featured.length > 0) {
                        me.featured.musicVideos.push({
                            title     : $(this).attr("name"),
                            thumbnail : MEDIA_DIR + $featured.find("ifile").attr("name"),
                            channel   : me.musicVideos.length-1,
                        });
                    }
                }
            }
        }
    } catch(e) {popError(e);}
   writeLog("info","Music Content Loaded.");
};

mediaXMLObj.prototype.loadCustomPlaylistContent = function mediaXMLObjLoadCustomPlaylistContent() {
    var me = this;
        me.playlist = [];
    var allMusic = me.$data.find('allmusic');

    try{
        for(var i=0; i<allMusic.length; i++){
            var musicContent = allMusic[i].getElementsByTagName('content');
            for(var j=0; j<musicContent.length; j++){

                var created = null;
                var createdTimestamp = 1;
                var createdStr = musicContent[j].getAttribute('created');
                
                if(createdStr != ''){
                    var createdDate = createdStr.split(" ")[0];
                    var createdTime = createdStr.split(" ")[1];
                    var createdHours = (createdStr.split(" ")[2].toLowerCase() == "pm") ? parseInt(createdTime.split(":")[0]) + 12 : createdTime.split(":")[0];

                    created = new Date(
                        createdDate.split("/")[2], parseInt(createdDate.split("/")[0]) - 1, createdDate.split("/")[1],
                        createdHours, createdTime.split(":")[1], createdTime.split(":")[2]
                    );

                    createdTimestamp = created.getTime();
                }

                var contentMfile = musicContent[j].getElementsByTagName('mfile');
                var mfileName = contentMfile.item(0).attributes.item(0).value;
                var contentLocation = musicContent[j].getAttribute('type');
                
               
                if(contentLocation == "Local"){
                    var location = MEDIA_DIR + mfileName;
                }else if(contentLocation == "Gateway"){
                    var location = mfileName;
                }

                var contentIfile = musicContent[j].getElementsByTagName('ifile');
      

                var genres = musicContent[j].getAttribute('genre') ? musicContent[j].getAttribute('genre').split(",") : [];
                
                var thumb = false;
                var contentIfile = musicContent[j].getElementsByTagName('ifile');

                for(var z=0; z<contentIfile.length; z++){
                    var fileName = contentIfile[z].getAttribute('name');
                    thumb = new Image();
                    thumb.src = MEDIA_DIR + fileName;
                } 

                me.playlist.push({
                    "title"           : musicContent[j].getAttribute('title'),
                    "artist"          : musicContent[j].getAttribute('info2'),
                    "id"              : musicContent[j].getAttribute('id'),
                    "genres"          : genres,
                    "createdDate"     : created,
                    "createdTimestamp": createdTimestamp,
                    "type"            : musicContent[j].getAttribute('type'),
                    "location"        : location,
                    "thumb"           : thumb
                });
            }
        }
    } catch(e) {popError(e);}
};

mediaXMLObj.prototype.loadVirtualActive = function mediaXMLObjLoadVirtualActive() {
    
    writeLog('info', 'Starting Load of Virtual Active Content...');

    var me = this;
    me.virtualActive = [];
    me.featured.virtualActive = [];
    var list = me.$data.find('list');
    try{
        for(i=0; i<list.length; i++){
            var listParent = list[i].parentNode.getAttribute("name");
            
            if(listParent == "virtual_active"){
                var channelContent = list[i].getElementsByTagName('content');
                var listContent = channelContent;

                for(var j=0; j< channelContent.length; j++){
                    var thisItem = me.createNewItem(listContent[j]);
                    me.virtualActive.push(thisItem); 
                }  

                var $featured = $(this).find("channel").find("featured[skin='"+g_mfgStyle+"']");
                    if ($featured.length > 0) {
                        me.featured.virtualActive.push({
                            title     : $(this).attr("name"),
                            thumbnail : MEDIA_DIR + $featured.find("ifile").attr("name"),
                            channel   : me.virtualActive.length-1,
                        });
                    } 
            }   
        }
    } catch(e) {popError(e);}

    writeLog('info', 'Virtual Active Content Loaded.');
};

mediaXMLObj.prototype.createNewItem = function mediaXMLObjCreateNewItem(item) {
	var $item = $(item),
		$ifile = $item.find("ifile"),
		$mfile = $item.find("mfile"),
		dir = media_dir_cleanup(MEDIA_DIR),
		thisItem = {
			id          : $item.attr("id"),
			title       : $item.attr("title"),
			artist      : $item.attr("info2"),
			type        : $item.attr("type"),
			description : $item.find("summary").text(),
			dir         : dir,
			location    : (dir + $mfile.attr("name")),
			thumbnail   : (($ifile.length > 0) ? (dir + $ifile.attr("name")) : "")
		};

	switch ($item.attr("type").toUpperCase()) {
		case "CBS":
		case "CBS-V2":
			if (this.isCbsEnabled) {
				thisItem.location = $item.attr("location");
			}
			break;

		case "GATEWAY":
			thisItem.location = $mfile.attr("name");
			thisItem.id = $mfile.attr("id");
			break;

        case "YOUTUBE-PLAYLIST":
            thisItem.location = $item.attr("location");

	}

	return (thisItem);
};
