//
//  Sliding box (used for presentation).
//
function multiSlidingBox(container, scrollUpButton, scrollDownButton, scrollBackButton, name, levelCount)
{
    this.$container = container;                                    //  <--- JQuery reference to parent container
    this.$scrollUpButton = scrollUpButton;                          //  <--- JQuery reference to scroll up button
    this.$scrollDownButton = scrollDownButton;                      //  <--- JQuery reference to scroll down button
    this.$scrollBackButton = scrollBackButton;                      //  <--- JQuery reference to scroll back button
    this.name = name;                                               //  <--- Name of parent object (used for event handler namespacing)
    this.levelCount = levelCount;                                   //  <--- Number of sublevels to be drawn
    this.$levels = new Array();                                     //  <--- Array of JQuery references to sub levels
    this.$scrollingLevels = new Array();                            //  <--- Array that holds references to scrollableList() objects.
    this.currentMenu = 0;                                           //  <--- Current menu

    this.init();
}

//
//  Fill this.$container with <ul>s and save a reference to each of them.
//
multiSlidingBox.prototype.init = function()
{
    try {

    var htmlStr = "";

    for(var i=0, htmlStr="";i<this.levelCount;i++)
        htmlStr += "<ul id='level"+i+"'></ul>";

    this.$container.html(htmlStr);

    for(var i=0;i<this.levelCount;i++)
    {
        this.$levels[i] = this.$container.find("#level"+i);
        this.$scrollingLevels[i] = new scrollableList(this.$levels[i], this);
    }

    this.$scrollBackButton.addClass("disabled");
    this.$scrollDownButton.addClass("disabled");
    this.$scrollUpButton.addClass("disabled");

    this.attachEvents();

    } catch(e) {popError(e);}
}

//
//  Attach events to this sliding box.
//
multiSlidingBox.prototype.attachEvents = function()
{
    var _this = this;

    //  Attach back button functionality
    this.$scrollBackButton.bind("click."+this.name, function() { _this.scrollBack(); } );

    //  Attach scroll down button functionality
    this.$scrollDownButton.bind("click."+this.name, function() { _this.scrollDown(); } );

    //  Attach scroll up button functionality
    this.$scrollUpButton.bind("click."+this.name,   function() { _this.scrollUp(); } );
}

multiSlidingBox.prototype.getButtonHeight = function()
{
	var buttonHeight = 34; // default value, adds a slight buffer to scroll height
	try {
		if (this.$scrollUpButton.length > 0) {
			buttonHeight = buttonHeight + this.$scrollUpButton.outerHeight();
		}
		if (this.$scrollDownButton.length > 0) {
			buttonHeight = buttonHeight + this.$scrollDownButton.outerHeight();
		}
	} catch(e){
	}
	return(buttonHeight);
};


//
//  Slide the box to the current menu and update the scroll buttons
//
multiSlidingBox.prototype.slideTo = function(which)
{
    var position = which.css("left");

    if(doTransitions)
        this.$container.animate({"left" : (-1*parseInt(position))+"px"}, 150, "linear");
    else
        this.$container.css("left",(-1*parseInt(position))+"px");

    this.updateScrollButtons();
}

//
//  Slide the current menu to the top.
//
multiSlidingBox.prototype.scrollToTop = function(which)
{
    which.css("top", "0px");
}

//
//  Scroll to the last page of the list (if not already there).
//
multiSlidingBox.prototype.scrollToBottom = function()
{
    var _this = this;
    var currentlyScrolling = this.getCurrentlyScrolling();

    //  Only scroll if we're not at the bottom already
    var scrollTo = this.$container.height() - currentlyScrolling.height();
    if(scrollTo > 0)
        scrollTo = 0;

    if(doTransitions)
        currentlyScrolling.stop().animate({top: scrollTo+"px"}, 250, "linear", function() { _this.updateScrollButtons(); } );
    else
    {
        currentlyScrolling.css("top",scrollTo+"px");
        this.updateScrollButtons();
    }
}

//
//  Set the current menu and return a reference to current menu
//
multiSlidingBox.prototype.setCurrentMenu = function(which)
{
    this.currentMenu = which;

    return(this.getCurrentlyScrolling());
}

//
//  Get current menu based on this.currentMenu.
//
multiSlidingBox.prototype.getCurrentlyScrolling = function()
{
    return(this.$levels[this.currentMenu]);
}

//
//  Show/hide scroll up/down buttons.
//
multiSlidingBox.prototype.updateScrollButtons = function()
{
    try {

    //  Show the scroll back button on every list aside from the first one
    if(this.currentMenu > 0)
        this.$scrollBackButton.removeClass("disabled");
    else
        this.$scrollBackButton.addClass("disabled");

    var currentlyScrolling = this.getCurrentlyScrolling();

    if(-1 * (parseInt(currentlyScrolling.css("top")) - this.$container.height()) >= currentlyScrolling.height())
        this.$scrollDownButton.addClass("disabled");
    else
        this.$scrollDownButton.removeClass("disabled");

    //  Show the scroll up button if this menu's top value isn't zero
    if(parseInt(currentlyScrolling.css("top")) < 0)
        this.$scrollUpButton.removeClass("disabled");
    else
        this.$scrollUpButton.addClass("disabled");

    } catch(e) {popError(e);}
}

//
//  Decrement this.currentMenu and scroll back.
//
multiSlidingBox.prototype.scrollBack = function()
{
    //  Set the selected item of the current menu to null
    this.getCurrentlyScrolling().data("selectedItem", null);

    //  Set the current menu to one back
    var currentMenu = this.setCurrentMenu(this.currentMenu - 1);

    //  Slide the box to show the new current menu
    this.slideTo(currentMenu);
}

//
//  Scroll the current menu down.
//
multiSlidingBox.prototype.scrollDown = function()
{
    var _this = this;
    var currentlyScrolling = this.getCurrentlyScrolling();
    var bottom = this.$container.height() - currentlyScrolling.height();
    var scrollToPx = (parseInt(currentlyScrolling.css("top")) - this.$container.height()) + this.getButtonHeight();

    if(this.$scrollDownButton.is(".disabled"))
    {
        var currentTop = parseInt(currentlyScrolling.css("top"));

        if(doTransitions)
            currentlyScrolling.animate( 
                {top: (currentTop-50)+"px"},
                40,
                "linear",
                function()
                {
                    currentlyScrolling.animate({top: currentTop+"px"}, 400, "easeOutBack", function() { _this.updateScrollButtons(); } );
                }
            );
        else
            this.updateScrollButtons();

        return;
    }

    //  If there is more than one page left to scroll
    if(-1 * (parseInt(currentlyScrolling.css("top")) - this.$container.height()) < currentlyScrolling.height())
    {
        if(scrollToPx < bottom + 100)
        {
            // add more artists when user reaches the bottom of the page
                viewManager.activeObject.addArtists();

            if(doTransitions)
                currentlyScrolling.stop().animate( {top: bottom+"px"}, 400, "easeOutBack", function() { _this.updateScrollButtons(); } );
            else
            {
                currentlyScrolling.css("top",bottom+"px");
                this.updateScrollButtons();
            }
        }
        else
        {
            if(doTransitions)
                currentlyScrolling.stop().animate({top: scrollToPx+"px"}, 250, "linear", function() { _this.updateScrollButtons(); } );
            else
            {
                currentlyScrolling.css("top",scrollToPx+"px");
                this.updateScrollButtons();
            }
        }
    }
}

//
//  Scroll the current menu up.
//
multiSlidingBox.prototype.scrollUp = function()
{
    var _this = this;
    var currentlyScrolling = this.getCurrentlyScrolling();
    var scrollTo = (parseInt(currentlyScrolling.css("top")) + this.$container.height()) - this.getButtonHeight();

    if(this.$scrollUpButton.is(".disabled"))
    {
        if(doTransitions)
            currentlyScrolling.animate( 
                {top: "50px"},
                40,
                "linear",
                function()
                {
                    currentlyScrolling.animate({top: "0px"}, 400, "easeOutBack", function() { _this.updateScrollButtons(); } );
                }
            );
        else
        {
            currentlyScrolling.css("top","0px");
            this.updateScrollButtons();
        }

        return;
    }

    if(scrollTo >= 0)
    {
        if(doTransitions)
            currentlyScrolling.stop().animate( {top: "0px"}, 400, "easeOutBack", function() { _this.updateScrollButtons(); } );
        else
        {
            currentlyScrolling.css("top","0px");
            this.updateScrollButtons();
        }
    }
    else
    {
        if(doTransitions)
            currentlyScrolling.stop().animate({top: scrollTo+"px"}, 250, "linear", function() {_this.updateScrollButtons();} );
        else
        {
            currentlyScrolling.css("top",scrollTo+"px");
            this.updateScrollButtons();
        }
    }
}

//
//  Remove all event handlers for this box. If emptyHTML is set to true, empty the HTML of this.$container.
//
multiSlidingBox.prototype.destroy = function(emptyHTML)
{
    this.$container.die("click."+this.name);

    if(emptyHTML)
        this.$container.html("");
}

function scrollableList(me, parentObject)
{
    this.$me = me;
    this.$parent = me.parent();
    this.parentObject = parentObject;

    this.mouseMovement = new Array();
    this.scrolling = false;
    this.currentMousePosition = 0;
    this.throwThreshold = 1;
    this.throwMultiplier = 20;  //  i.e. 10px for every 1px scrolled on average.
    this.throwDecelerationFactor = 10;

    this.beginningThrowTop = 0;
    this.endingThrowTop = null;
    this.previousTop = null;

    this.throwingInterval = null;
    this.throwIntervalMS = 30;
    this.mouseStopDetector = null;
    this.mouseStopDetectorTimeoutMS = 200;

    this.attachEvents();
}

scrollableList.prototype.attachEvents = function()
{
    var _this = this;

    this.$me
        .bind("mousedown", function(e) { _this.beginScrolling(e); })
        .bind("mousemove", function(e) { _this.continueScrolling(e); })
    ;

    $("body").bind("mouseup", function(e) { _this.endScrolling(e); })
}

scrollableList.prototype.beginScrolling = function(e)
{
    clearInterval(this.throwingInterval); 
    this.mouseMovement = new Array();
    this.currentMousePosition = e.pageY;
    this.scrolling = true;
}

scrollableList.prototype.continueScrolling = function(e)
{
    if(!this.scrolling)
        return;

    var _this = this;

    //  Get distance scrolled and push it onto this.mouseMovement. Keep this.mouseMovement 4 or less values long.
    var distance = e.pageY - this.currentMousePosition;

    if(this.mouseMovement.length >= 3)
        this.mouseMovement.splice(0,1);
    this.mouseMovement.push(distance);

    //  Figure new top based on current top and distance.
    var newTop = (parseInt(this.$me.css("top")) + distance > 100)
        ?   100
        :   (parseInt(this.$me.css("top")) + this.$me.height() - this.$parent.height() + distance < -100)
            ?   -1*(this.$me.height() - this.$parent.height()) - 100
            :   parseInt(this.$me.css("top")) + distance;

    this.$me.stop().css("top", newTop+"px");

    this.currentMousePosition = e.pageY;

    //  Restart mouse stop detection - If the mouse doesn't move for this.mouseStopDetectorTimeout milliseconds, reset this.mouseMovement array.
    clearTimeout(this.mouseStopDetector);
    this.mouseStopDetector = setTimeout(function() { _this.mouseMovement = new Array(); }, this.mouseStopDetectorTimeoutMS);
}

scrollableList.prototype.endScrolling = function(e)
{
    if(!this.scrolling)
        return;

    //  Turn off scrolling
    this.scrolling = false;

    //  Clear mouse stop detection timeout
    clearTimeout(this.mouseStopDetector);

    //  If past top, animate back to 0 and return.
    if(parseInt(this.$me.css("top")) > 0)
    {
        this.bounceBack("top");
        return;
    }
    else if(parseInt(this.$me.css("top")) + this.$me.height() - this.$parent.height() < 0)
    {
        this.bounceBack("bottom");
        return;
    }

    //  Figure average distance dragged. Not including the last value in this.mouseMovement helps with the
    //  touchscreen's responsiveness (it tends to report a zero before mouseup).
    for(var i=0, avg=0;i<(this.mouseMovement.length - 1);i++)
        avg += this.mouseMovement[i];

    avg /= this.mouseMovement.length;

    //  Throw based on average distance if greater than this.throwThreshold
    if(Math.abs(avg) > this.throwThreshold) this.throwMe(avg);
}

scrollableList.prototype.throwMe = function(avg)
{
    var _this = this;

    //  Figure distance to throw based on average dragged distance and this.throwMultiplier.
    var distance = avg * this.throwMultiplier;

    //  Set up throw values
    var newTop = parseInt(this.$me.css("top")) + distance;
    this.beginningThrowTop = parseInt(this.$me.css("top"));
    this.endingThrowTop = newTop;
    this.previousTop = null;

    //  Begin throwing animation interval.
    this.throwingInterval = setInterval(function() { _this.animateScroll(); }, this.throwIntervalMS);
}

scrollableList.prototype.animateScroll = function()
{
    var currentScrollTop = parseInt(this.$me.css("top"));
    var delta = this.endingThrowTop - currentScrollTop;
    var bottom = this.$me.height() - this.$parent.height();

    //  If stopped via inertia
    if(this.scrolling || Math.abs(delta) <= this.throwDecelerationFactor)
    {
        clearInterval(this.throwingInterval);

        //  If stopped above or below the list, bounce back.
        if(currentScrollTop > 0)
            this.bounceBack("top", 200);
        else if(currentScrollTop + bottom < 0)
            this.bounceBack("bottom", 200);
        else
            this.parentObject.updateScrollButtons();

        return;
    }
    //  If thrown past the top of the list, bounce back
    else if(currentScrollTop + delta/this.throwDecelerationFactor >= 100)
    {
        clearInterval(this.throwingInterval);
        this.bounceBack("top", 400);
        return;
    }
    //  If thrown past the bottom of the list, bounce back
    else if(currentScrollTop + delta/this.throwDecelerationFactor + bottom <= -100 )
    {
        clearInterval(this.throwingInterval);
        this.bounceBack("bottom", 400);
        return;
    }

    this.previousTop = currentScrollTop;
    this.$me.css("top", (currentScrollTop + delta/this.throwDecelerationFactor)+"px");
}

scrollableList.prototype.bounceBack = function(which, speed)
{
    var _this = this;

    if(which == "top")
    {
        if(this.doTransitions)
            this.$me.stop().animate(
                {top: "0px"},
                speed,
                "easeOutBack",
                function()
                {
                    _this.parentObject.updateScrollButtons();
                }
            );
        else
        {
            this.$me.css("top","0px");
            this.parentObject.updateScrollButtons();
        }
    }
    else
    {
        if(this.doTransitions)
            this.$me.stop().animate(
                {top: -1*(this.$me.height() - this.$parent.height())+"px"},
                speed,
                "easeOutBack",
                function()
                {
                    _this.parentObject.updateScrollButtons();
                }
            );
        else
        {
            this.$me.css("top",-1*(this.$me.height() - this.$parent.height())+"px");
            this.parentObject.updateScrollButtons();
        }
    }
}
