//
//  view.js
//
//
//  Basic app class. All apps extend this object. Every app should have: init(), preload(), load(), show(), hide()
//
function app(name, type, vm, superClass, srcDir) {
    this.name = name;
    this.type = type;
    this.vm = vm;
    this.superClass = superClass;
    
    // srcDir is an optional argument. Currently, we use it to load views from an plugin directory controlled by
    // the OEM so that they can implement their own views. Basically, it allows you to load views that don't 
    // exist in the current skin
    this.srcDir = (typeof srcDir === "string") ? srcDir : DIR_ROOT+"/www/"+g_mfgStyle+"/views/";
    
    // Track view-level timeouts and intervals
    this.intervalList = new Array();
    this.timeoutList = new Array();
}

//
//  Preload this app's html and call this.init()
//
app.prototype.preload = function appPreload() {
    var me = this;
    //me.vm.$preloadDiv.load(me.vm.currentView.html, function() { me.init(); });

    $.ajax({
        url: me.vm.currentView.html,
        dataType: 'html',
        async: false,
        success: function appPreloadAjaxSuccess(data) {
            me.vm.$preloadDiv.html(data);
            me.init();
        },
        error: function appPreloadAjaxFail(XMLHttpRequest, textStatus, errorThrown) { popError("Preload ERROR!! --> " +me.vm.currentView.html+ " did not pre-load correctly."); me.disabled = true; }
    });
};

//
//  Initialization called once during setup (after preload)
//
app.prototype.init = function appInit(){};

//
//  Load my html.
//
app.prototype.load = function appLoad() {
    var me = this;
    
    $.ajax({
        url: me.vm.currentView.html,
        dataType: 'html',
        async: false,
        success: function appLoadCallBack(data) {
            me.vm.$viewContainer.html(data);
            me.vm.$viewContainer.show();
            
            if (me.vm.doRaiseGui) {
            	guiObj.raiseGui(me.name);
            	me.vm.doRaiseGui = false;
            }
            
            me.vm.currentView.shown = me.show(); 
        }
    });
};

app.prototype.preLoadShow = function appPreLoadShow(newViewName) {
    var me = this;
    
    $.ajax({
        url: me.vm.currentView.html,
        dataType: 'html',
        async: false,
        success: function appPreLoadShowCallBack(data) {
            me.vm.$viewContainer.html(data);
            me.vm.$viewContainer.show();

            guiObj.raiseGui(newViewName);
            me.vm.doRaiseGui = false;
            
            me.vm.currentView.shown = me.show();   
        	if (typeof doAppShow == 'function'){
            	doAppShow(newViewName);
        	}
        }
    });
};

//
//  Show me.
//
app.prototype.show = function appShow(){};

//
//  Hide me.
//  Note: if this method is overridden in inherited "classes", the same house-
//  cleaning functionality should be included.
app.prototype.hide = function appHide() {
    if(this.hideAds)
        this.hideAds();
    
    // Clear all view-level timeouts and intervals.
    this.clearAllTimeouts();
    this.clearAllIntervals();
};

//
//  Allow sub-classed apps to call parent functions
//
app.prototype._super = function app_super() {
	if (!this.core) {
		popError("super() error : No core - object isn't overridden");
		return;
	} else if (arguments.callee.caller.name == "") {
		popError("super() error : Calling function has no name");
		return;
	}

	var func = "this.core." + arguments.callee.caller.name;

	if (!eval(func)) {
		popError("super() error : this.core." + arguments.callee.caller.name + " doesn't exist");
		return;
	}

	return (func);
};

/**
 * Track view-level timeouts and intervals. These timeouts and intervals should
 * exist only while the view is active, and not persist when switching to
 * another view.
 */

app.prototype.setTimeout = function appSetTimeout(code, delay) {
    var retval = window.setTimeout(code, delay);
    this.timeoutList.push(retval);
    return retval;
};
app.prototype.clearTimeout = function appClearTimeout(id) {
    var ind = this.timeoutList.indexOf(id);
    if(ind >= 0) {
        this.timeoutList.splice(ind, 1);
    }
    var retval = window.clearTimeout(id);
    return retval;
};
app.prototype.setInterval = function appSetInterval(code, delay) {
    var retval = window.setInterval(code, delay);
    this.intervalList.push(retval);
    return retval;
};
app.prototype.clearInterval = function appClearInterval(id) {
    var ind = this.intervalList.indexOf(id);
    if(ind >= 0) {
        this.intervalList.splice(ind, 1);
    }
    var retval = window.clearInterval(id);
    return retval;
};
app.prototype.clearAllTimeouts = function appClearAllTimeouts() {
    for(var i in this.timeoutList) {
        window.clearTimeout(this.timeoutList[i]);
    }
    this.timeoutList = new Array();
};
app.prototype.clearAllIntervals = function appClearAllIntervals() {
    for(var i in this.intervalList) {
        window.clearInterval(this.intervalList[i]);
    }
    this.intervalList = new Array();
};
