//
//
//  New view manager.
//
//

function vwManager() {
    this.views = [];

    this.initCounter = 0;
    this.onInitComplete = null;
    this.activeObject = null;
    this.currentView = null;
    this.previousView = null;
    this.nextView = null;
    this.doRaiseGui = false;
    
    this.history = [];
    
    //  Main container for all views
    this.$viewContainer = $("#mainView");
    //  Preload staging area for views
    this.$preloadDiv = $("#preloadDiv");

    this.constructHookPost();
}

// post-construct hook; override in skin-specific js when additional functionality is desired
vwManager.prototype.constructHookPost = function vwManagerConstructHookPost() {};


vwManager.prototype.clearHistory = function vwManagerClearHistory() {
    this.history.splice(0, this.history.length);
}
//
//  Update views for skin-specific behavior
//
vwManager.prototype.updateView = function vwManagerUpdateView(viewName, params) {
    try {

    var view = this.getNewView(viewName);

    if(params.name)
        view.name = params.name;
    if(params.type)
        view.type = eval(params.type);  //  <---    Got to eval() here so that type is an object type and not a string.
    if(params.showControlBar)
        view.showControlBar = eval(params.showControlBar);  //  <--- Got to eval() here or else the string "false" will be treated as true.

    } catch(e) {popError(e);}
};

//
//  Use when we need to override default page flow.
//
vwManager.prototype.showNextView = function vwManagerShowNextView() {
    var nextView = this.nextView;
        
    if (nextView == "mainMenu") {
        this.show(nextView);
        return;
    }

    //  If the user needs to enter their secondary id, go to the main menu no matter what (bug #2932). TODO: secondary id should not be tied to main menu.
    if (userIsLoggedIn && (!machineObj.getMachineDemoNetwork()) && secondaryID_daysRemaining)
        nextView = "mainMenu";

    this.show(nextView);
};

//
//  Go to previous view
//
vwManager.prototype.showPreviousView = function vwManagerShowPreviousView() {
    if (this.history.length > 1) {
        var currentView = this.history.pop();
        var previousView = this.history.pop();
        this.show(previousView);
    }
};

vwManager.prototype.getPreviousViewName = function vwManagerGetPreviousViewName() {
    var previousView = "";
    
    if (this.history.length > 1) {
        previousView = this.history[this.history.length - 2];
    }
    
    return previousView;
}

//
//  
//
vwManager.prototype.initView = function vwManagerInitView(view) {
    try {

    var me = this;

    var mainSrcRoot = DIR_ROOT + "/www/views/";
    var skinSrcRoot = view.srcDir;

    var htmlSrc = (file_exists(skinSrcRoot + view.name + "/index.html") == "1")
        ?   skinSrcRoot + view.name + "/index.html"
        :   mainSrcRoot + view.name + "/index.html";

    var thisView = {
        name       : view.name,
        type       : view.type,
        superClass : view.superClass,
        parent     : me,
        html       : htmlSrc,
        js         : mainSrcRoot + view.name + "/js.js",
        skinjs     : skinSrcRoot + view.name + "/js.js",
        css        : mainSrcRoot + view.name + "/style.css",
        skincss    : skinSrcRoot + view.name + "/style.css",
        viewCount  : 0
    };

    loadScript(thisView.js);
    
    var errors = checkForSyntaxErrors(thisView.skinjs);
    if (errors.length > 0) {
        writeLog("info", "Removing " + thisView.name + " from list of available apps");
        for (var i=0; i<availableApps.length; i++) {
            if (availableApps[i].name.toLowerCase() == thisView.name.toLowerCase()) {
                availableApps.splice(i, 1);
                break;
            }
        }
        return;
    }
    loadScript(thisView.skinjs);
    
    loadCSS(thisView.css);
    loadCSS(thisView.skincss);

    thisView.type = eval(thisView.type);

    me.views.push(thisView);

    me.previousView = me.currentView;
    me.currentView = me.getNewView(thisView.name);

    me.cleanUpPreviousView();
    me.createNewActiveObject();
    me.activeObject.preload();

    //  If this view object is disabled after initializing, disable the view.
    if(me.activeObject.disabled)
        me.views[me.views.length - 1].disabled = true;

    } catch(e) { popError("Error while loading " + view.name + " - " + e); }
};

//
//  Call to show a new view. Example: vwManager.show("register");
//
vwManager.prototype.show = function vwManagerShow(newViewName, dontDoTransition) {
    var me = this;
    try {
    	var newView = me.getNewView(newViewName);
	    if (!newView) 
	    	return;
    	
	    me.previousView = me.currentView;
	    if(me.currentView)
	        me.currentView.shown = false;
	
	    me.currentView = newView;
	
	    me.cleanUpPreviousView();
	    me.showHookBeforeCreateNewActiveObject();
	    me.createNewActiveObject();
	    
	    // Since the pageChange function is only called when we receive an op=show message from the OEM, 
	    // we can query the caller to determine whether or not to send a view change notification
	    if (controlObj.isViewChangeEnabled() && me.show.caller && me.show.caller.name != "pageChange")
            nsSend2("op=viewchange", "page="+newViewName.toLowerCase());
	    
	    me.showHookBeforeShow();

	    if(me.activeObject.oemControlled)
	        me.activeObject.oemControlled();
	    else if(doTransitions && !dontDoTransition)
	        me.transitionToNewView();
	    else {
	        me.activeObject.load();
	    }
	    
	    me.showHookAfterShow();
	
	    //  Increment user views for this view
	    me.currentView.viewCount++;
    } catch(e) { popError(e); }
};

// hooks for any additional processing at the skin level when displaying views
vwManager.prototype.showHookBeforeCreateNewActiveObject = function vwManagerShowHookBeforeCreateNewActiveObject() {};
vwManager.prototype.showHookBeforeShow = function vwManagerShowHookBeforeShow() {};
vwManager.prototype.showHookAfterShow = function vwManagerShowHookAfterShow() {};

vwManager.prototype.preLoadThenShow = function vwManagerPreLoadThenShow(newViewName, dontDoTransition, arguments) {
    var me = this;
    try {
    	var newView = me.getNewView(newViewName);
	    if (!newView)
	    	return;
	    	
	    me.previousView = me.currentView;
	    if(me.currentView)
	        me.currentView.shown = false;
	
	    me.currentView = newView;
	
	    me.cleanUpPreviousView();
	    me.showHookBeforeCreateNewActiveObject();
	    me.createNewActiveObject();
	
	    if (me.activeObject.setArgs) {
	        me.activeObject.setArgs (arguments);
	    }	
	    
	    // Since the pageChange function is only called when we receive an op=show message from the OEM, 
	    // we can query the caller to determine whether or not to send a view change notification
		if (controlObj.isViewChangeEnabled() && me.preLoadThenShow.caller.name != "pageChange") {
            nsSend2("op=viewchange", "page=" + newViewName.toLowerCase());
        }

	    me.showHookBeforeShow();
	
	    if (me.activeObject.oemControlled) {
	        me.activeObject.oemControlled();
	    } else if(doTransitions && !dontDoTransition) {
	        me.transitionToNewView();
	    } else {
	        me.activeObject.preLoadShow(newViewName);
	    }
	    
		me.showHookAfterShow();
	
	    //  Increment user views for this view
	    me.currentView.viewCount++;
    } catch(e) {popError(e);}
};

vwManager.prototype.transitionToNewView = function vwManagerTransitionToNewView(newViewName) {
    var me = this;
    try {
        me.$viewContainer.fadeOut(150, function vwManagerTransitionToNewViewFadeOutCallBack() { 
        	me.activeObject.load();
        	me.$viewContainer.fadeIn(150); 
        });
    } catch(e) { popError(e); }
};

vwManager.prototype.cleanUpPreviousView = function vwManagerCleanUpPreviousView() {
    //  If previous view is not null
    if(this.previousView != this.currentView && this.previousView != null)  {
        if (this.activeObject) {
            this.activeObject.hide();                   //  <--- Use this to do any save state prep and unload related html
        }

        this.collectObjectSettings();               //  <--- Save state

        if (this.activeObject) {
            $("*").unbind("." + this.activeObject.name);  //  <--- Unbind all events specific to this object (via namespace)
        }
    }
};

//
//  Loop through all views to find the one to which we're going.
//
vwManager.prototype.getNewView = function vwManagerGetNewView(newViewName) {
    if (!newViewName)
        return;
    
    newViewName = newViewName.toLowerCase()
    for (var i in this.views)  {
        if (this.views[i].name.toLowerCase() == newViewName)
            return this.views[i];
    }

    writeLog("info", "Warning: Selected view ["+newViewName+"] is not available in the current skin");
};

//
//  Set vwManager.activeObject to a new object of the type specified in this.objectType, and pass that
//  object this.objSettings to set it back to the state it was last in.
//
vwManager.prototype.createNewActiveObject = function vwManagerCreateNewActiveObject() {
	try {
		this.activeObject = null;
		var tempObj = new this.currentView.type(this.currentView.name, this.currentView.type, this, this.currentView.superClass);
		this.applyObjectSettings(tempObj);

		// Set this new object to activeObject.
		this.activeObject = tempObj;
		
		this.history.push(this.activeObject.name);
	} catch (e) { popError(e); }
};

//
// Collect all the settings of the current vwManager.activeObject into
// view.settings to allow
//  us to set it back to its current state if we navigate back to it.
//
vwManager.prototype.collectObjectSettings = function vwManagerCollectObjectSettings() {
	try {
		if (this.previousView == null)
			return;

		this.previousView.objSettings = new Array();

		for ( var att in this.activeObject) {
			// Don't copy functions
			if (typeof (this.activeObject[att]) == "function")
				continue;

			this.previousView.objSettings.push({
				"name" : att,
				"value" : this.activeObject[att]
			});
		}
	} catch (e) { popError(e); }
};

//
// Apply all saved settings to the current active object.
//
vwManager.prototype.applyObjectSettings = function vwManagerApplyObjectSettings(tempObj) {
	try {
		for ( var i in this.currentView.objSettings ) {
			for ( var att in tempObj ) {
				if ( att != this.currentView.objSettings[i].name || typeof (tempObj[att]) == "function" )
					continue;

				tempObj[att] = this.currentView.objSettings[i].value;
			}
		}
	} catch (e) { popError(e); }
};

//
// Get a value of a currently unloaded view.
//
vwManager.prototype.getObjectValue = function vwManagerGetObjectValue(viewName, valueName) {
    try {
	    var view = this.getNewView(viewName);
	
	    for(var i in view.objSettings)
	        if(view.objSettings[i].name == valueName)
	            return(view.objSettings[i].value);
	
	    return(null);
    } catch(e) { popError(e); }
};

//
//  Show/Hide the control bar based on this views settings
//
vwManager.prototype.showHideControlBar = function vwManagerShowHideControlBar() {
    //  If this view has a control bar, draw it. Otherwise hide it.
    if(this.currentView.showControlBar)
        this.showControlBar();
    else
        this.hideControlBar();
};

//
//  Show control bar (if not showing).
//
vwManager.prototype.showControlBar = function vwManagerShowControlBar() {
    $("#controlBar").show();
};

//
//  Hide control bar (if not hiding).
//
vwManager.prototype.hideControlBar = function vwManagerHideControlBar() {
    $("#controlBar").hide();
};

//
//  Write out page views to xml at end of session.
//
vwManager.prototype.writePageViews = function vwManagerWritePageViews() {
    try {
	    var viewsXML = "";
	    var today = new Date();
	    var todaysDate = today.getFullYear()+"-"+parseInt(today.getMonth() + 1)+"-"+today.getDate();
	
	    viewsXML += "<pageviews machine_id='"+configObj.getMid()+"' date='"+todaysDate+"'>";
	
	    for(var i=0;i<this.views.length;i++) {
	        if(this.views[i].viewCount == 0)
	            continue;
	
	        viewsXML += "<page name='"+this.views[i].name+"' count='"+this.views[i].viewCount+"' />";
	    }
	
	    viewsXML += "</pageviews>";
	
	    //  Filename is expected to be relative from machine.xml
	    var filename = DIR_ROOT + "/upload/pageViews_"+today.getTime()+".xml";
	
	    //  Remove pageviews file if exists
	    npfunctions.remove_file(filename);
	
	    //  Write pageviews file
	    SetFileContents(filename, viewsXML);
    } catch(e) {popError(e);}
};

vwManager.prototype.reloadSpecificView = function vwManagerReloadSpecificView(nameDizzle) {
    var me = this;
    try {
	    var view = this.getNewView(nameDizzle);
	
	    var LOCAL_ROOT="/home/isabelle/netpulse/aries-s16/";
	   
	    var mainSrcRoot = DIR_ROOT + "/www/views/";
	    var skinSrcRoot = DIR_ROOT + "/www/"+g_mfgStyle+"/views/";
	    
	    var newmainSrcRoot = LOCAL_ROOT + "/www/views/";
	    var newskinSrcRoot = LOCAL_ROOT + "/www/"+g_mfgStyle+"/views/";
	
	    var htmlSrc = (file_exists(skinSrcRoot + view.name + "/index.html") == "1")
	        ?   skinSrcRoot + view.name + "/index.html"
	        :   mainSrcRoot + view.name + "/index.html";
	
	    var thisView = {
	        name       : view.name,
	        type       : view.type,
	        superClass : view.superClass,
	        parent     : me,
	        html       : htmlSrc,
	        js         : mainSrcRoot + view.name + "/js.js",
	        skinjs     : skinSrcRoot + view.name + "/js.js",
	        css        : mainSrcRoot + view.name + "/style.css",
	        skincss    : skinSrcRoot + view.name + "/style.css"
	    };
	
	    var parentCSSfile = read_file(newmainSrcRoot + view.name + "/style.css");
	    var childCSSfile = read_file(newskinSrcRoot + view.name + "/style.css");
	    
	    SetFileContents(view.css, parentCSSfile);
	    SetFileContents(view.skincss, childCSSfile);
	
	    loadScript(thisView.js);
	    loadScript(thisView.skinjs);
	    loadCSScached(thisView.css);
	    loadCSScached(thisView.skincss);
	
	    thisView.type = eval(thisView.type);
	
	    me.views.push(thisView);
	
	    me.previousView = me.currentView;
	    me.currentView = me.getNewView(thisView.name);
	
	    me.cleanUpPreviousView();
	    me.createNewActiveObject();
	    me.activeObject.preload();
	
	    //  If this view object is disabled after initializing, disable the view.
	    if(me.activeObject.disabled)
	        me.views[me.views.length - 1].disabled = true;
	
	
	    for(var i in this.views)  {
	        if(this.views[i].name == view.name){
	             this.views[i] = view;
	        }
	    }
    } catch(e) {popError("Error while loading "+view.name+" - "+e);}
};

// A neat little function that will display a modal box over the screen, whose
// appearance can vary depending on the 'type' you specify. Currently two types
// - 'prompt' and 'alert'. Timeout is only used if autoClose is true.
vwManager.prototype.displayModal = function vwManagerDisplayModal(msg, type, okEvent, cancelEvent, autoClose, timeout) {
	var me = this;

	var $modal = $("#modalBox");
	var $modalContent = $modal.find("#modalContent");
	var $modalMsg = $modal.find("#modalMsg");
	var $modalButtons = $modal.find("#modalButtons");

	$modal.css("visibility", "hidden").css("display", "block");

	$modalMsg.html(msg);
	$modalMsg.css("margin-bottom", "auto");

	switch (type) {
		case "alert":
			$modalContent.attr("class", "alert");
			if (autoClose) {
				$modalButtons.hide();
				timeout = parseInt(timeout) || 3000;
				clearTimeout(this.displayModalTimeout);
				this.displayModalTimeout = setTimeout(function() {
					me.closeModal();
					if (okEvent) okEvent();
				}, timeout);
			} else {
				if (!okEvent) {
					okEvent = function() { me.closeModal(); };
				}
				$modalButtons.show();
				$modalMsg.css("margin-bottom", "40px");
				$modalButtons.find(".okBtn").show().bind("click", okEvent);
				$modalButtons.find(".cancelBtn").hide();
			}
			break;
		case "prompt":
			$modalContent.attr("class", "prompt");
			$modalButtons.find(".button").show();
			$modalButtons.show();
			$modalMsg.css("margin-bottom", "40px");
			$modalButtons.find(".okBtn").bind("click", okEvent);
			$modalButtons.find(".cancelBtn").bind("click", cancelEvent);
			break;
	}

	var totalHeight = $modalContent.outerHeight();
	var totalWidth = $modalContent.outerWidth();
	
	var top = 0 - Math.round(totalHeight / 2);
	$modalContent.css("margin-top", top + "px");
	$modalContent.css("top", "50%");
	
	var left = 0 - Math.round(totalWidth / 2);
	$modalContent.css("margin-left", left + "px");
	$modalContent.css("left", "50%");
	
	$modal.css("visibility", "visible").show();
};

vwManager.prototype.closeModal = function vwManagerCloseModal() {
	var $modal = $("#modalBox");

	clearTimeout(this.displayModalTimeout);
	$modal.find("*").unbind();
	$modal.hide();
};

//Checks to see if an app is available or not
vwManager.prototype.isViewAvailable = function(viewName) {
    var bool = false;
    for (var i = 0, vlen = this.views.length; i < vlen; i++) {
        if (this.views[i].name.toLowerCase() == viewName.toLowerCase()) {
            bool = true;
        }
    }
    return bool;
};

vwManager.prototype.getViewCount = function(viewName){
	for(var i = 0, vlen = this.views.length; i < vlen; i++){
		if (this.views[i].name.toLowerCase() == viewName.toLowerCase())
			return viewManager.views[i].viewCount;
	}
	return -1;
};

vwManager.prototype.drawMenu = function vwManagerDrawMenu(target, format) {
    var items = this.items,
        itemsLen = items.length,
        item = null,
        itemHtml = '',
        $item = null,
        checkDisabled = false,
        i = 0;

    for ( i = 0; i < itemsLen; i++) {
        try {
            item = items[i];
            checkDisabled = (item.hideWhenDisabled && item.disabled);
            itemHtml = item.drawMe(checkDisabled, format);
            $item = $(itemHtml).css({ 'width' : (100 / itemsLen) + '%' });
            if (item.attachMouseDown) { item.attachMouseDown($item); }
            target.append($item);
        } catch(e) {
            popError(e);
        }
    }

    if (this.bindExit) { this.bindExit(); }
};

vwManager.prototype.buildItemsLists = function vwManagerBuildItemsLists () {
    // Reset menu list to avoid inheriting from base
    this.items = [];
};


/* Menu item class -------------------------------- */

function menuItem(name, requiresNetwork, requiresEmbedded, onclick, hideWhenDisabled) {
    this.name = name;
    this.requiresNetwork = requiresNetwork;
    this.requiresEmbedded = requiresEmbedded;
    this.onclick = onclick;
    this.hideWhenDisabled = hideWhenDisabled;

    this.view = this.name;

    this.disabled = false;
    //  <-- Based on whether the related view is enabled.

    this.init();
}

menuItem.prototype.init = function coreMenuItemInit() {
    this.attachEvents();
};

menuItem.prototype.clicked = function coreMenuItemClicked(e) {
    if (this.disabled) { return; }

    if (this.onclick) {
        this.onclick();
    } else {
        if (this.view == 'endOfWorkout'
        && ((workoutdataObj.get_status_byte() == "STATUS_BYTE_MANUAL")
        || (workoutdataObj.get_status_byte() == "STATUS_BYTE_OFFLINE"))) {
            pauseResumeObj.show(workoutdataObj.get_status_byte());
        } else {
            viewManager.show(this.view);
        }
    }
};

menuItem.prototype.attachMouseDown = function coreMenuItemAttachMouseDown($target) {
    var _this = this;
    $target
        .unbind("mousedown." + this.name)
        .bind("mousedown." + this.name, function menuItemMouseDown(e) {
            _this.clicked(e);
        });
};

menuItem.prototype.attachEvents = function coreMenuItemAttachEvents() {
    if (this.attachMouseDown) { this.attachMouseDown($("#id_menu_" + this.name)); }
}; 

menuItem.prototype.getHtml = function coreMenuItemGetHtml(itemName, itemLabel, itemClass) {
    // Default menu item formatting.
    var itemHtml = '<div id="id_menu_' + itemName + '" class="menu_button' + itemClass + '"><div class="logo"></div><h2>' + itemLabel + '</h2>' +
                   '<input type="hidden" class="nameValue" value="' + itemName + '" /></div>';
    return(itemHtml);
};

// Return html to draw this menu item.
menuItem.prototype.drawMe = function coreMenuItemDrawMe(checkDisabled, format) {
    var itemName = '', itemLabel = '', itemClass = '', itemHtml = '', vmName = '';

    try {
        itemName = this.name;
        itemLabel = this.label = IDS_LANGUAGE.mainMenu[itemName];
        // <-- Point this menu item to a view - name parameter should match the view's name.
        vmName = viewManager.activeObject.name;

        switch(vmName) {
            case 'watch': {
                itemClass = ((itemName == watchObj.target.parentView.name || (watchObj.target.parentView.name == 'playlist' && itemName == 'music')) ? ' active' : '');
                break;
            } case 'playlist': {
                itemClass = ((itemName == vmName || itemName == 'music') ? ' active' : '');
                break;
            } default: {
                itemClass = ((itemName == vmName) ? ' active' : '');
                break;
            }
        }

        // If disabled, add disabled class.
        if (checkDisabled) { itemClass = itemClass.concat(' disabled'); }

        itemHtml = this.getHtml(itemName, itemLabel, itemClass);
    } catch (e) { popError(e); }

    return(itemHtml);
};

/* End menu item class -------------------------------- */


function loadCSS(src) {
    if (file_exists(src) == "1") {
        $('head').append($('<link rel="stylesheet" type="text/css" />').attr({href : src}));
    }
}
function loadCSScached(src) {
    loadCSS(src + '?updated=' + ((new Date()).getTime() / 1000.0));
}
