// www/jsi/config.js

var CONFIG_DEFAULTS = {
    'display.size':'15',
    'network.enabled': true
};

var AUTO_INTERFACE_TYPE = 'wired';
var AUTO_CONFIG_TYPE = 'dhcp';

var CONFIG_FILE = DIR_ROOT + '/data/machine.xml';
var ETHERNET_FIX_FILE = DIR_ROOT + '/tmp/eth0_fix_attempted';

var npinstall_curr_status = '';
var npinstall_prev_status = '';

var g_UI = 0;

Function.prototype.bind = function(obj) {
    var func = this;
    return function() { return func.apply(obj, arguments); }
}

Function.prototype.bindArgs = function() {
    if(arguments.length < 1) {
        throw new Error(IDS_LANGUAGE.installCore.genError['tooFew']);
    }

    var fn = this;
    var args = [ ];
    for(var i = 0; i < arguments.length; i++) {
        args[i] = arguments[i];
    }

    return function() { return callvar(fn, args); }
}


jQuery.fn.enabled = function(set_to) {
    if(set_to == null || set_to == undefined) {
        return !($(this).attr('disabled') == 'disabled');
    } else {
        $(this).each(function(){
            if (set_to) {
                $(this).removeAttr('disabled');
            } else {
                $(this).attr('disabled', 'disabled');
            }
        });
        return this;
    }
}; 

function CancelStepExit(message) {
    this.message = message;
}
CancelStepExit.prototype.name = 'CancelStepExit';
CancelStepExit.prototype.toString = function() {
    return this.message;
}

function StopExecution() {
}
StopExecution.prototype.name = 'StopExecution';
StopExecution.prototype.toString = function() {
    return 'StopExecution';
}

function ConfigurationFetchError(message) {
    this.message = message;
}
ConfigurationFetchError.prototype.name = 'ConfigurationFetchError';
ConfigurationFetchError.prototype.toString = function() {
    return this.message;
}

function ConfigurationSendError(code, desc) {
    this.code = code;
    this.desc = desc;
}
ConfigurationSendError.prototype.name = 'ConfigurationSendError';
ConfigurationSendError.prototype.toString = function() {
    return this.desc;
}

function PullCertComplete()
{
    mpRestart();
    $('#content__ipod__pull_cert_button').enabled(true);

    // we're done. Kill the interval timer
    clearTimeout(g_UI.objTimer);

    setTimeout(new function() {$('#content__ipod__response').html(IDS_LANGUAGE.install.ipodPairing['pairingComplete']);}, 1000);

    g_UI.closeDialog();
}

//
//  Test to see if the network is up. If so, write "Connected!" into the status window and draw the
//  wireless signal strength meter. Otherwise, write "Connection failed." into the status window.
//
function WirelessComplete()
{
    _this = g_UI;

    //  Enable "Test connection" button
    $('#content__wireless__test__button').enabled(true);
    clearTimeout(g_UI.objTimer); g_UI.objTimer = null;

    //  Test the network connection
    var network_is_up = TestNetwork();

    //  If network is up:
    if(network_is_up)
    {
        //  Write "Connected!" into status window
        $("#wireless__status__window").html($("#wireless__status__window").html()+"<span style='color:green;'>"+IDS_LANGUAGE.install.ipodPairing['connected']+"</span><br/>");

        //  Prep g_UI.signalStrength[] to hold signal strengths
        _this.signalCounter = -1;
        _this.signalStrength = new Array();

        //  Every second, check the signal strength and add that value to g_UI.signalStrength[]. Then update
        //  the meter to show the strongest of the most recent ten readings (to help cover the bounciness of the
        //  Chinese wireless adapter).
        _this.wirelessSignalTimer = setInterval(function() 
        {

            //  Keep an array of the ten most recent signal strengths
            _this.signalCounter = (_this.signalCounter >= 9) ? 0 : _this.signalCounter+1;

            // Get signal strength (0 - 100)
            var signalStrength = Math.round((runSudoProgram(DIR_ROOT+'/bin/n5i-net', ['wireless-strength'])));
            _this.signalStrength[_this.signalCounter] = signalStrength;

            // Use the greatest signal strength value in g_UI.signalStrength
            for(var i=0, greatest = 0;i<_this.signalStrength.length;i++)
            {
                if(_this.signalStrength[i] > greatest) greatest = _this.signalStrength[i];
            }

            // Set signal meter color based on signal strength
            var signalColor = (greatest <= 25) ? "red" : (greatest <= 50) ? "orange" : (greatest <= 75) ? "yellow" : "green";

            // Grow/shrink signal meter box and change it's color based on signal strength
            $("#signal__strength__cap").animate({"height": 130-(greatest*1.2),}, 1000);
            $("#signal__strength__meter").animate({"backgroundColor": signalColor}, 1000);
			
		}, 1000);
  
    }
    //  Otherwise we are not connected - don't show the wireless meter, and output "Connection failed."
    else
    {
			$("#wireless__status__window").html($("#wireless__status__window").html()+"<span style='color:red;'>"+IDS_LANGUAGE.install.ipodPairing['failedConnection']+"</span><br/>");
			// If network is not up, indicate that connection failed.
			_this.showAlert(IDS_LANGUAGE.install.ipodPairing['unableToConnect']);
    }
    // Scroll to the bottom of the status window
    $('#wireless__status__window').prop({"scrollTop": $("#wireless__status__window").prop("scrollHeight")});
 
    //  Enable nav buttons
    $("#next_button").enabled(true);
    $("#back_button").enabled(true);
	
	
	
}

function DeviceConfig(defaults) {
    this.xml_document = null;

    this.network = new Object();

    this.network.interface_type = defaults['network.interface_type'];

    /* This is hard set since interface only supports DHCP */
    this.network.config_type = 'dhcp';

    /* IP/DNS parameters will come from the DHCP server */
    this.network.address = undefined;
    this.network.netmask = undefined;
    this.network.gateway = undefined;
    this.network.primary_dns = undefined;
    this.network.secondary_dns = undefined;

    this.network.essid = defaults['network.essid'];
    this.network.security = defaults['network.security'];
    this.network.secret = defaults['network.secret'];

    this.display = new Object();
    this.display.size = defaults['display.size'];

    this.tv = new Object();
    this.tv.enabled = defaults['tv.enabled'];

    this.tv.present = defaults['tv.present'];
    this.tv.signal_type = this.getTVInterfaceTypes();
    
    this.machine_list = new Object();
}

DeviceConfig.prototype.getTVInterfaceTypes = function() {
    return get_television_tuner_type();
}

DeviceConfig.prototype.getInterfaceTypes = function() {
    interface_types = ['wired'];
    if(HasWireless()) {
        interface_types.push('wireless');
    }
    interface_types.push('none');
 
    return interface_types;
}

DeviceConfig.prototype.fetchConfiguration = function() {
    
    xmlDoc = parse_xml_document(CONFIG_FILE);
    
    if(! xmlDoc) {
        throw new ConfigurationFetchError(
          'Failed to fetch configuration file.');
    }

    var tv_enabled = false;
    
    try {
        $(xmlDoc).find("tv").each(function() {
            var tv = $(this);
            tv_enabled = Boolean(tv.attr("enabled").toUpperCase() == 'TRUE');
        });
    }
    catch (e) {
        throw new ConfigurationFetchError(
           'Failed to parse configuration file: ' + String(e));
    } 

    this.tv.enabled = tv_enabled;
    this.xml_document = xmlDoc;
}

DeviceConfig.prototype.getAssetServerParameters = function() {
    var tv_type;
    switch(this.tv.signal_type)
    {
        default:
        case 'cable':
        {
            tv_type = 0;
            break;
        }
        case 'digital':
        {
            tv_type = 1;
            break;
        }
    }
    
    return {
      'cn': GetComputerName().toUpperCase(),
      'tv_enable': Number(this.tv.enabled),
      'tv_present': Number(this.tv.present),
      'tv_type': tv_type
    };
}

DeviceConfig.prototype.sendConfiguration = function() {

    // return early
    return;

    var params = this.getAssetServerParameters();

    var params_encoded =
      'cn=' + params['cn'] +
      '&tv_enable=' + params['tv_enable'] +
      '&tv_type=' + params['tv_type']
    ;

    /* This would send the parameters as POST data, which would be arguably more
     * correct, however the server only wants GET parameters.  We still do a
     * POST to avoid caching.
     */
    //var response = request_xml_document(INSTALL_URL, 'POST', params_encoded);

    var response = request_xml_document(
      INSTALL_URL + '?' + params_encoded, 'POST');

    var code = Number(attr_value(
      xpath_eval(response, '/response/@code').iterateNext()));
    if(code != 0) {
        var desc = attr_value(
          xpath_eval(response, '/response/@desc').iterateNext());
        throw new ConfigurationSendError(code, desc);
    }
}

DeviceConfig.prototype.saveConfiguration = function() {
    var params = this.getAssetServerParameters();

    attr_value(
      xpath_eval(this.xml_document, '/machine/tv/@enable').iterateNext(),
      params['tv_enable']
    );

    attr_value(
      xpath_eval(this.xml_document, '/machine/tv/@tuner_type').iterateNext(),
      params['tv_type']
    );

    var dirname_basename = splitPath(CONFIG_FILE);
    var dirname = dirname_basename[0];
    var basename = dirname_basename[1];

    createDirectory(dirname);
    writeFile(CONFIG_FILE, serialize_xml_document(this.xml_document));
}

DeviceConfig.prototype.loadConfiguration = function() {
    try {
        return parse_xml_document(CONFIG_FILE);
    } catch(e) {
        if(e.name != 'FileDoesNotExist') {
            throw e;
        }
    }
}

DeviceConfig.prototype.saveNetworkConfig = function() {
    return SaveNetworkConfiguration(this.network);
}

DeviceConfig.prototype.stopNetworking = function() {
    return StopNetworking();
}

DeviceConfig.prototype.startNetworking = function() {
    return StartNetworking();
}

DeviceConfig.prototype.testNetwork = function() {
    return TestNetwork();
}

DeviceConfig.prototype.saveDisplayConfig = function() {
    return SaveDisplayConfiguration(this.display);
}

DeviceConfig.prototype.getAllTvChannels = function() {
    var min, max, channels, channel;

    min = 2;
    channels = [ ];

    switch(this.tv.signal_type)
    {
        default:
        case 'cable':
        {
            max = 158;
            break;
        }
        case 'digital':
        {
            max = 999;
            break;
        }
    }

    for(channel = min; channel <= max; channel++) {
        channels.push(channel);
    }

    return channels;
}

function DeviceConfigUi(config)
{
    var _this = this;

    this.changed_existing_config = false;
    this.changed_display_setting = false;
    this._current_step = undefined;
    this._step_history = [ ];
    this.pages_to_view = new Array();
    this.config = config;
    this.network_is_configured = false;
    this.network_autoconfigured = false;
    this.assignComputerName = true;
    
    this.disable_buttons_counter = 0;

    $('#next_button').click(function (evt) { 
        _this.nextStep(); 
    });
    
    $('#back_button').click(function (evt) { 
    	_this.prevStep(); 
    });
    
    $('#finish_button').click(function (evt) { _this.finish(); });
    
    $('form').submit(function (evt) { _this.nextStep(); });
   
    $('#content__configure_touchscreen_button').click(
    function (evt)
    {
        if ("1" == file_exists("/usr/local/bin/LinearAp"))
        {
            // figure out what device the touchscreen is
            var hid_device = "/dev/usb/hiddev0";
            for (var i = 0 ; i < 5; i++)
            {
                if ("1" == file_exists("/dev/usb/hiddev"+i))
                {
                    hid_device = "/dev/usb/hiddev"+i;
                    break;
                }
            }

            run("/usr/local/bin/LinearAp "+hid_device+" 9");
        }
        else if ("1" == file_exists("/usr/bin/hlincal"))
        {
            run("/usr/bin/hlincal -q 9");
        }
    });

    $('#content__welcome_new_configure_touchscreen_button').click(
    function (evt)
    {
        $('#content__configure_touchscreen_button').click();
    });

    $('#footer').click(
    function(evt) {

        if (_this._current_step == 'network__interface_type')
        {
            // tell the user what's about to happen
            var options = { modal:true, beforeclose: function() { return false; } };
            _this.openDialog(
            IDS_LANGUAGE.install.restart['oneMoment']+ ','
            + IDS_LANGUAGE.install.restart['pleaseWait'] + '<br/><br/><center><img src=images/loadingAnimation.gif /></center>',
            options);

            
            if ("1" == file_exists("/etc/udev/rules.d/70-persistent-net.rules")) {
                _this.fixEthernetConfig();
            } else {
                _this.closeDialog();
            }
        }
    });

    $('#content__network__interface_type__id_network_devices').click(
        function (evt)
        {
            _this.setInterfaceTypes(config.getInterfaceTypes());
            $('#content__network__interface_type__interface_type__' + _this.config.network.interface_type).attr('checked', 'true');

            $('#content__network__interface_type__interface_type__none').click(function (evt){
                countryConf.show();
            })
        }
    );
    
    var wireless_security_scheme = (this.config.network.security)
        ?   this.config.wireless.security_scheme
        :   'wep';

    $('#content__network__wireless__security_scheme__' + wireless_security_scheme).attr('checked', 'true');

    $('#content__ipod__pull_cert_button').click(
        function(evt)
        {
            _this.pullCert(_this);
        }
    );

    $('#content__wireless__test__button').click(
        function(evt)
        {
            _this.processFormData();
            _this.testWireless(_this);
        }
    );

    $('#content__assign_computer_name__populate_button').click(
        function(evt)
        {
            _this._disableButtons();
            _this.populateComputerName();
            _this._enableButtons();
        }
    );

    $('#content__configure_language_button').click(function(evt) { languageConf.show(); });
    
    $('#footer').append($('<p>' +'[' + GetComputerName() + ']' +'</p>'));
	
	
			updateModal = function(text,title){
				_this.showNotification(text,title);
			};
			
			updateFn = function() {               
                 //  Rewrite install file
                 writeToFile(DIR_ROOT + '/data/install', '{ "pages" : ["assign_computer_name","ipod","tv_config"] }'); 
                 //  Call sync_master.pl to get new machine.xml, and download available updates
				writeLog('info', 'Check for software update, onclick event has been actived.');                
				_this.syncDevice();
                
				//If there is an update available, n5i-download-updates will automatically restart gui. Ticket#38592955
                noUpdateAvailable();
            };	
            
            noUpdateAvailable = function (){
            	//Closes first Notification for software updates. &&
            	//Shows the second notification when there is no update available.
            	_this.closeDialog();
                var text = IDS_LANGUAGE.install.update['noUpdateAvailable'];
 				var title = IDS_LANGUAGE.install.update['noUpdateAvailableTitle'];
 				
 				setTimeout(updateModal(text,title),1000);
                setTimeout(function (){_this.closeDialog();},5000);
            }
			
			$('#checkForUpdates').click( function () {
				var text = IDS_LANGUAGE.install.update['checkUpdate'];
 				var title = IDS_LANGUAGE.install.update['checkUpdateTitle'];
 				setTimeout(updateModal(text,title),1000);
				setTimeout(updateFn, 3000);
				}
			);	
}

DeviceConfigUi.prototype.updateNetworkSettings = function(interface_type, essid, security, secret) {
	this.config.network.interface_type = interface_type;
	this.config.network.essid = essid;
    this.config.network.security = security;
    this.config.network.secret = secret;
	this.changed_existing_config = true;
}

DeviceConfigUi.prototype.start = function() {

    this.showNotification(
    		IDS_LANGUAGE.install.initialize['initialConfig'],
    		IDS_LANGUAGE.install.initialize['initial']
    );

    var _this = this;

    fn = function() {

        /* Pre-populate configuration from the config file, if it exists. */
        _this.config.loadConfiguration();

        _this.closeDialog();
        
        var start = getInstallFileContent().trim();
        if (start.length) {
            start = evalJSON(start);
            _this.pages_to_view[i] = new Array();

            if(start.pages) {

                for(var i=0;i<start.pages.length;i++) {

                  _this.pages_to_view[i] = String(start.pages[i]).trim();

                }
            }
            //  Backwards compatibility 
            else {

                if(start.single_page == "1") _this.pages_to_view[0] = String(start.name).trim();
                else {

                    var thisPage = String(start.name).trim();
                    var pageSequence = ["network__interface_type","ipod","tv_config"];

                    for(var i=0;i<pageSequence.length;i++) {

                        if(thisPage == pageSequence[i]) {

                            for(var j=i,k=0;j<pageSequence.length;j++,k++) {

                                _this.pages_to_view[k] = pageSequence[j];
                            }
                        }
                    }
                }
            }

            //  Continue
            _this._setCurrentStep(_this.pages_to_view[0], false);
        } 
        else {
            _this._setCurrentStep('welcome_new', false);
        }
    };

    // Return control to main thread so that dialog box can be displayed.
    setTimeout(fn, 0);
}

DeviceConfigUi.prototype.getMenuFileName = function() {

    var strRet = "";
    
    try {
      xmlFile = DIR_ROOT + "/www/xml/";
      if(this.config.network.interface_type == "none") {

        switch(workoutdataObj.get_csafe_application_state())
        {
            case "CSAFE_EMBEDDED":
            {
                xmlFile += "menu_tv_only_embedded.xml";
                break;
            }
            default:
            {
                xmlFile += "menu_tv_only_standalone.xml";
                break;
            }
        }

      } else {

        switch(workoutdataObj.get_csafe_application_state())
        {
            case "CSAFE_EMBEDDED":
            {
                xmlFile += "menu_full_embedded.xml";
                break;
            }
            default:
            {
                xmlFile += "menu_full_standalone.xml";
                break;
            }
        }

      }

      strRet = xmlFile;

    } catch(e) {
        strRet = "";
        popError(e);
    }

    return strRet;
}

DeviceConfigUi.prototype.finish = function() {
    var _this = this;
    
    if ('none' == this.config.network.interface_type) {
      // we need to set the host name to something other than 'netpulse'
      if (configObj.getMid() =="netpulse")
        SetComputerName('0');
    }
    else {
        configObj.load();
        var mid = configObj.getMid();
        if (mid > 0) {
            SetComputerName(mid);
            writeLog('info', 'installer: final: setting computer name: ' + mid);
        }
        else {
            writeLog('info', 'installer: final: machine id is wack: ' + mid);
        }
    }
    
    //
    //  Update network type in machine.xml to:
    //  <network type="Wireless" />  or  <network type="Wired" />  or  <network type="TV Only" />
    //
    var network_type = (this.config.network.interface_type == "none") ? "TV Only" : (this.config.network.interface_type == "wireless") ? "Wireless" : "Wired";
    
    try
    {
        machine_str = read_file(CONFIG_FILE);
        var xmlMachineObject = (new DOMParser()).parseFromString(machine_str, "text/xml");

        // remove the current network node if found
        var networkNode = xmlMachineObject.getElementsByTagName("network")[0];
        if (networkNode)
            xmlMachineObject.documentElement.removeChild(networkNode);
        
        
        // set the <network type>
        var string = (new XMLSerializer()).serializeToString(xmlMachineObject);
        var xmlMachineObject2 = (new DOMParser()).parseFromString(string.replace('</machine>',"<network type='"+network_type+"' />\n</machine>"), "text/xml");

        writeToFile(CONFIG_FILE, (new XMLSerializer()).serializeToString(xmlMachineObject2));
    }
    catch(e)
    {
        popError(e);
    }
    
    //
    //  Configure the main menu...
    //  1. Read in the proper menu configuration file based upon the value of
    //     this.config.network.interface_type and workoutdataObj.get_csafe_application_state()
    //      a. data/menu_tv_only_embedded.xml
    //      b. data/menu_tv_only_standalone.xml
    //      c. data/menu_full_embedded.xml
    //      d. data/menu_full_standalone.xml
    //  2. Read in the machine.xml_document
    //      if there's a <menu> tag already, remove it
    //      insert the new xml_menu
    //  3. Write out the new machine.xml
    //
    try
    {
        // 1. Read in the proper configuration file
        xmlFile = this.getMenuFileName();
        menu_str = read_file(xmlFile);
        
        // 2. Read in the machine.xml doc
        machine_str = read_file(CONFIG_FILE);
        var xmlMachineObject = (new DOMParser()).parseFromString(machine_str, "text/xml");

        // remove the current menu node if found
        var menuNode = xmlMachineObject.getElementsByTagName("menu")[0];
        if (menuNode)
            xmlMachineObject.documentElement.removeChild(menuNode);

        // append the menu node to machine.xml
        var string = (new XMLSerializer()).serializeToString(xmlMachineObject);
        var xmlMachineObject2 = (new DOMParser()).parseFromString(string.replace('\n</machine>', menu_str+'</machine>'), "text/xml");

        // 3. Write out the new machine.xml
        writeToFile(CONFIG_FILE, (new XMLSerializer()).serializeToString(xmlMachineObject2));
    }
    catch(e)
    {
        popError(e);
    }

    var apply_configuration = function()
    {
        try {
            remove_file(DIR_ROOT + '/data/install');
            if(machineObj.getSlaveState() == 3) {
            	nsSend2("op=button","id=cnx");
            }
            else {
            	RestartX();
            }
        }
        finally {
            // do nothing....
        }
        _this.closeDialog();
    };

    this.showNotification(
     IDS_LANGUAGE.install.configuration['configApplied'],
     IDS_LANGUAGE.install.configuration['saveConfig']
    );

    // Return control to main thread so that dialog box can be displayed.
    setTimeout(apply_configuration, 0);
}

function getSelectSelection(select) {
    var result = [ ];
    var index;
    if(select && select.options) {
        for(index = 0; index < select.options.length; index++) {
            if(select.options[index].selected) {
                result.push(select.options[index].value);
            }
        }
    }
    return result;
}

function getSelectValues(select) {
    var result = [ ];
    var index;
    if(select && select.options) {
        for(index = 0; index < select.options.length; index++) {
            result.push(select.options[index].value);
        }
    }
    return result;
}

function getRadioSelection(radios) {
    var index;
    for(index = 0; index < radios.length; index++) {
        if(radios[index].checked) {
            return radios[index].value;
        }
    }
    return null;
}

DeviceConfigUi.prototype.getCurrentStep = function() {
    return this._current_step;
}

DeviceConfigUi.prototype._flipPage = function(to_step, skip_exit)
{
    if('welcome_new' == to_step || 'welcome_existing' == to_step || 'assign_computer_name' == to_step)
		athleteObj.set_is_aboard(0);
    else
        athleteObj.set_is_aboard(1);
    
    if(! $('#content__' + to_step).get(0))
        throw new Error(IDS_LANGUAGE.install.error['noStep'] + to_step);

    var from_step = this.getCurrentStep();
		
    if(! skip_exit)
        this.stepExit(from_step, to_step);
	  
    this._hideCurrentPage();
    this.stepEnter(from_step, to_step);
    this._showPage(to_step);
    if(to_step == "network__interface_type" && $('#content__network__interface_type').length)
    		$('#content__network__interface_type__id_network_devices').click();
}

DeviceConfigUi.prototype._hideCurrentPage = function()
{
    var me = this;

    if(this.getCurrentStep() == "tv_config")
    {
        killTVPlayer();
        saveSetup();
    }

	$('#content__' + this.getCurrentStep()).removeClass('current_page');
}

DeviceConfigUi.prototype._showPage = function(step)
{
    var _this = this;

	$('#content__' + step).addClass('current_page');

    //  If leaving the tv page, remove visible class
    if(this.getCurrentStep() == "tv_config")
        $("#tvViewContents").removeClass();

    //  Set up tv page
    if(step != "tv_config")
        return;

    this.showTvPage();
}

//
//  When we show the tv page: turn off audio and update the UI based on the current tv signal type
//
DeviceConfigUi.prototype.showTvPage = function()
{
    var hasTuner = eval(has_television_tuner());
    if(!hasTuner)
        this.showAlert(IDS_LANGUAGE.install.noTv['header']);

    g_tunerType = get_television_tuner_with_ntscmode();

    tvStep("tuner");
}

DeviceConfigUi.prototype.stepEnter = function(from_step, to_step) {

    if (to_step == 'ipod') {
        $('#content__ipod__response').html('');
    }
    else if (to_step == 'welcome_new')
    {
        if ("1" == file_exists("/usr/local/bin/LinearAp") || "1" == file_exists("/usr/bin/tscal")) {
            $('#content__welcome_new_configure_touchscreen_button').show();
        }
        else {
            $('#content__welcome_new_configure_touchscreen_button').hide();
        }
    }
    else if (to_step == 'welcome_existing')
    {
        if (! this.changed_existing_config)
        {
            var tv_enabled = this.config.tv.enabled ? 'Yes' : 'No';
            var tv_present = this.config.tv.present ? 'Yes' : 'No';

            var tv_signal_type;
      
            if(this.config.tv.signal_type == 'cable_standard') {
                tv_signal_type = IDS_LANGUAGE.install.tvConfig["tunerType_cable_standard"]; //'Cable/Satellite';
            } else if(this.config.tv.signal_type == 'cable_irc') {
                tv_signal_type = IDS_LANGUAGE.install.tvConfig["tunerType_cable_irc"];
            } else if(this.config.tv.signal_type == 'cable_hrc') {
                tv_signal_type = IDS_LANGUAGE.install.tvConfig["tunerType_cable_hrc"];
            } else if(this.config.tv.signal_type == 'digital_cable') {
                tv_signal_type = IDS_LANGUAGE.install.tvConfig["tunerType_digital_cable"];
            } else if(this.config.tv.signal_type == 'digital_ota') {
                tv_signal_type = IDS_LANGUAGE.install.tvConfig["tunerType_digital_ota"];
            } else if(this.config.tv.signal_type == 'analog_digital_cable') {
                tv_signal_type = IDS_LANGUAGE.install.tvConfig["tunerType_analog_digital_cable"];
            } else {
                throw new Error(IDS_LANGUAGE.installCore.genError['signalType'] + this.config.tv.signal_type);
            }
        }
        else {
            $('#content__welcome_existing__configuration').empty();
            $('#content__welcome_existing__configuration').append(
              $('<p>'+IDS_LANGUAGE.install.configuration['changed'] +'</p>')
            );
        }
    }
    else if (to_step == "network__wireless") {
		// Reset signal meter and status window
		$("#wireless__signal__strength").css("opacity",0);
		$("#signal__strength__cap").css("height",129);
		$("#signal__strength__meter").css("backgroundColor","red");
		$("#wireless__connection__status").css("opacity",0);
		$("#wireless__status__window").html("");
	}
}

//
//  Get machine list from server and draw available machines. Set onclick functionality for the buttons.
//
DeviceConfigUi.prototype.populateComputerName = function() {

    //  Get machine list
    this.getMachineListFromServer();

    //  If machine list exists:
    if (null != this.machine_list)
    {
        machineList = this.machine_list.getElementsByTagName('machine');
        
        //  If no results, output error message and bail.
        if (0 == machineList.length)
        {
            $('#content__assign_computer_names__listing').html("<hr/><p>"+IDS_LANGUAGE.install.computerName['noMachines']+"</p>");
            return;
        }

        // Reset the machine list container.
        $('#content__assign_computer_names__listing').html("<hr/><p>"+IDS_LANGUAGE.install.computerName['selectPair']+"</p>");

        var _this = this;

        //  For each available machine, draw a button to the list and apply onclick functionality
        for (var i = 0; i < machineList.length; i++)
        {
            var nodeMachine = machineList[i];
            if (nodeMachine)
            {
                //  Get attributes from xml:
                //  <machine id="12" model="Desmo Elite" type="Treadmill" />
                var model = nodeMachine.attributes.getNamedItem("model").value;
                var id = nodeMachine.attributes.getNamedItem("id").value;
                var type = nodeMachine.attributes.getNamedItem("type").value;

                //  Draw button and set attributes and onclick
                var elmBtn = $('<button></button>')
                    .attr("rel", id)
                    .html(type  + ": " + model + " ["+id+"]")
                    //
                    //  When a machine is chosen:
                    //    - Disable nav buttons.
                    //    - Pair this machine to the server.
                    //    - If pairing succeeds:
                    //        1. Rewrite the install file to show the ipod and tv pages the next time it starts.
                    //        2. Call sync_master.pl to grab the proper machine.xml.
                    //        3. Pull updates down from the server.
                    //        4. RestartX - any updates will be installed when the GUI restarts.
                    //    - If not, re-populate the machine list (start over).
                    //
                    .click(function() {

                        //  Disable the 'back', 'next' and 'finished' buttons
                        _this._disableButtons();

                        //  Disable the dynamic machine buttons
                        $('#content__assign_computer_names__listing > button').enabled(false);

                        //  Pair this device to the server using the chosen id
                        var val = _this.pairDevicetoServer($(this).attr("rel"));

                        //  Empty string = successful pairing
                        if ('' == val)
                        {

                            //  Tell the user we succeeded
                            _this.showNotification(
                            		IDS_LANGUAGE.install.update['downloadUpdates'], IDS_LANGUAGE.install.update['deviceSucceeded']
                            );

                            //  Use short timeout to ensure that the notification is drawn
                            setTimeout(function() {
                                    
                                //  Rewrite install file
                                writeToFile(DIR_ROOT + '/data/install', '{ "pages" : ["ipod", "tv_config"] }');

                                //  Call sync_master to get new machine.xml, and download available updates
                                _this.syncDevice();

                                //  Restart GUI
                                RestartX();

                            }, 500);

                        }
                        else
                        {
                            // Oh no. Let's update the list again...
                            _this.machine_list = null;
                            _this.populateComputerName();
                        }

                        // Enable the 'back', 'next' and 'finished' buttons
                        _this._enableButtons();
                    });

                //  Add this button to the list
                $('#content__assign_computer_names__listing').append(elmBtn);
            }
        }
    }
    $('#content__assign_computer_names__listing').append("<div style='height:100px;'>&nbsp;</div>");
}

//
//  Pair device to server using specified machine id
//
DeviceConfigUi.prototype.pairDevicetoServer = function(id) {

    //  Empty string is true/successful
    var retValue = "";

    //  If a blank id is sent, bail.
    if (id == "")
    {
        retValue = IDS_LANGUAGE.installCore.genError['invalid_machine_id'];
        return retValue;
    }

    //  Get this device's MAC and IP addresses
    var mac = GetEth0MacAddress();
    var ip = GetPrimaryIpAddress();
    if ('' == ip) ip ="0.0.0.0";

    //  1. Send http request to server to pair this device with the id (via n5i-pair.jsp).
    var responseXML = request_xml_document(machineObj.getServerLocation()+"/n5i-pair.jsp?id="+id+"&ip="+ip+"&mac="+mac);
    if(responseXML)
    {
        var code = responseXML.getElementsByTagName('response')[0].getAttribute("code");
        retValue = responseXML.getElementsByTagName('response')[0].getAttribute("message");

        if (0 == code)
        {
            //  2. If successfull, set the computer's name to specified id
            SetComputerName(String(id));

            //  3. GetHostname(). If the same as specified id, we're good.
            var hostName = GetHostname();
            if(String(hostName).trim() == String(id).trim())
                retValue = '';
        }
    }

    return retValue;

}

//
//  After pairing this device to the server, pull proper machine.xml and download updates.
//
DeviceConfigUi.prototype.syncDevice = function() {
    runProgram(DIR_ROOT + '/bin/syncmaster');
    runSudoProgram('/usr/local/bin/n5i-download-updates');

}
// JACK: Add multi-language support below
DeviceConfigUi.prototype.fixEthernetConfig = function() {
    var options = { modal:true, beforeclose: function() { return false; } };
    _this.openDialog( IDS_LANGUAGE.install.configuration['wait'],
             IDS_LANGUAGE.install.configuration['misconfigured'] + '<br/><br/><center><img src=images/loadingAnimation.gif /></center>',
        options);
    setTimeout(function () {			
        runProgram('/usr/bin/sudo '+ DIR_ROOT +'/bin/n5i-sys', ['delete_file', '/etc/udev/rules.d/70-persistent-net.rules']); 
        runProgram('/usr/bin/touch '+ ETHERNET_FIX_FILE);
        reboot();
    }, 3000);
}

DeviceConfigUi.prototype.handleUnfixableEthernet = function() {
  _this.showNotification(IDS_LANGUAGE.installCore['bustedEthernet']);
  setTimeout(function () {			
    reboot();
  }, 3000);
}

DeviceConfigUi.prototype.ethernetFixFileExists = function() {
  return "1" == file_exists(ETHERNET_FIX_FILE);
}

DeviceConfigUi.prototype.networkInterfaceExists = function(ifName) {
        return runProgram( "/sbin/ifconfig "+ifName) != '';
}

DeviceConfigUi.prototype.stepExit = function(from_step, to_step) {

    if ('network__interface_type' == to_step) {
        //check if a valid mac address exists

        if(this.networkInterfaceExists("eth0")) {
          if (this.ethernetFixFileExists()) {
            runProgram('/bin/rm '+ ETHERNET_FIX_FILE);
          }
          this.config.fetchConfiguration(); // if so then fetch the config
        } else { 
            // display modal clear udev rules then reboot and retry unless we've
            // already tried it and we're still here.
            if ( ! this.ethernetFixFileExists()) {
                this.fixEthernetConfig();
            } else {
                this.handleUnfixableEthernet();
            }
        }
    }
    
    if(from_step == 'welcome_existing') {
        this.changed_existing_config = true;
    }

    if(from_step == 'network__wireless' && this.config.network.interface_type == 'wireless') {
        // Clear wireless signal strength interval
        clearInterval(g_UI.wirelessSignalTimer);
    }
    
    // if we're coming from the network__interface_type, make
    // sure that the network__interface_type, network is available
    if(from_step == 'network__interface_type' && this.config.network.interface_type == 'wired')
    {
        // Set wired connection here
		this.updateNetworkSettings("wired");
      	this.deconfigureNetwork();
      	this.configureNetwork();
    }
 
    /*if(from_step == 'display_settings') {
        if (this.changed_display_setting)
        {
            //SetInstallMode('network__interface_type', '0');
            writeToFile(DIR_ROOT + '/data/install', '{ "pages" : ["network__interface_type","assign_computer_name","ipod","tv_config"] }');
            
            // restart X
            RestartX();
        }
    }
    */
}

DeviceConfigUi.prototype.configureNetwork = function() {
    var error;

    if(this.network_is_configured) {
        return;
    }


    this.showNotification(
     IDS_LANGUAGE.install.configuration['wait'],
     IDS_LANGUAGE.install.configuration['configNetwork']
    );

    var _this = this;

    fn = function() {

        error = null;
        if(! _this.config.saveNetworkConfig()) {
            error = IDS_LANGUAGE.installCore.genError['netConfigFail'];
        } else {
          _this.config.startNetworking();
          if(! _this.config.testNetwork()) {
            _this.config.stopNetworking();
            error = IDS_LANGUAGE.installCore.genError['netFail'];
          } else {
            try {
                _this.config.fetchConfiguration();
            } catch(e) {
                _this.config.stopNetworking();
                error = String(e);
            }
          }
        }

        _this.closeDialog();

        if(error) {
            _this.showAlert(error);
        } else {
            _this.network_is_configured = true;
        }
    }

    // Return control to main thread so that dialog box can be displayed.
    setTimeout(fn, 500);
	
	fn = function() {

        error = null;
        if(! _this.config.saveNetworkConfig()) {
            error = IDS_LANGUAGE.installCore.genError['netConfigFail'];
        } else {
          _this.config.startNetworking();
          if(! _this.config.testNetwork()) {
            _this.config.stopNetworking();
            error = IDS_LANGUAGE.installCore.genError['netFail'];
          } else {
            try {
                _this.config.fetchConfiguration();
            } catch(e) {
                _this.config.stopNetworking();
                error = String(e);
            }
          }
        }

        _this.closeDialog();

        if(error) {
            _this.showAlert(error);
        } else {
            _this.network_is_configured = true;
        }
    }
	
    
    //throw new StopExecution();
}

DeviceConfigUi.prototype.getMachineListFromServer = function() {

    var bRet = false;
    this.showNotification(
       IDS_LANGUAGE.install.settings["settingsWait"],
       IDS_LANGUAGE.install.settings["settingsTitle"]
    );
    
    try {
        // ToDo:
        // 1. Get the MAC and LAN IP
        // 2. Send this information to server to retrieve a list of machines to allow the installer
        //      to select from
        // 3. save the list of machines to an array
        //  NOT IN HERE 4. _setCurrentStep(step, append_history, skip_exit) 
        //
        var mac = GetEth0MacAddress();

        var ip = GetPrimaryIpAddress();

				if ('' == ip)
            ip ="0.0.0.0";

        var list = request_xml_document(machineObj.getServerLocation()+"n5i-getMachineList.jsp?mac="+mac+"&ip="+ip);

        if (list)
        {
            this.machine_list = list; // <-- we are here
            bRet = true;
        }
        else
            this.machine_list = null;
    
    }
    catch(e) {
        throw new ConfigurationFetchError(
        IDS_LANGUAGE.install.error["fetchFail"] + String(e));

        this.closeDialog();
    }

    this.closeDialog();
    return bRet;
}

DeviceConfigUi.prototype.autoConfigureNetwork = function() {
    var error;

    this.showNotification(
    		  IDS_LANGUAGE.install.settings["settingsWait"],
    	      IDS_LANGUAGE.install.settings["settingsTitle"]
    );

    this.config.network.interface_type = AUTO_INTERFACE_TYPE;
    this.config.network.config_type = AUTO_CONFIG_TYPE;

    var _this = this;

    fn = function() {
        error = false;
        if(! _this.config.saveNetworkConfig()) {
            error = true;
        } else if(! _this.config.startNetworking()) {
            _this.config.stopNetworking();
            error = true;
        } else if(! TestNetworkEx()) {
            _this.config.stopNetworking();
            error = true;
        } else {
            try {
                // if the machine is named 'netpulse' then we need to contact the server to pair the device
                // and get a valid computer name
                if (GetComputerName().toUpperCase() == 'NETPULSE') {
                    error = this.assignComputerName = true;
                }
                else
                {
                    this.assignComputerName = false;
                    _this.config.fetchConfiguration();
                }
                
            } catch(e) {
                _this.config.stopNetworking();
                error = true;
            }
        }

        _this.closeDialog();

        if(error) {
            _this._setCurrentStep('welcome_new', false);
        } else {
            _this.network_is_configured = true;
            _this.network_autoconfigured = true;
            _this._setCurrentStep('welcome_existing', false);
        }
    }

    // Return control to main thread so that dialog box can be displayed.
    setTimeout(fn, 0);
}

DeviceConfigUi.prototype.deconfigureNetwork = function() {
    if(! this.network_is_configured) {
        return;
    }
    if(! this.config.stopNetworking()) {
        this.showAlert(IDS_LANGUAGE.install.error["network"]);
    }
    this.network_is_configured = false;
}

DeviceConfigUi.prototype._addDialogDiv = function(title, text) {
    $('<div class="flora" id="dialog" title="' +
      title + '"><p>' + text + '</p></div>'
    ).appendTo($('body'));
}

DeviceConfigUi.prototype.showNotification = function(text, title) {
    if(title == undefined) { title = 'Notice'; }
    this.openDialog(title, text);
};

DeviceConfigUi.prototype.showAlert = function(text, title)
{
    if(title == undefined) { title = IDS_LANGUAGE.installCore.genError['alertTitle']; }
    var okTransString = ((IDS_LANGUAGE.installCore['ok']) ? IDS_LANGUAGE.installCore['ok'] : "ok");
    var _this = this;
    var options = { 
			'buttons' : [{
				text: okTransString, 
				click: function() { 
					// Note: when using openDialog, always use closeDialog to dismiss the alert
					// This function will do proper clean up and re-enable to next, back, and finish buttons.
					_this.closeDialog(); 
				}
			}],
			// This will prevent the 'x' button from closing the dialog box.
			'beforeclose' : function() { return false; }
    };
    this.openDialog(title, text, options);
};

DeviceConfigUi.prototype.openDialog = function(title, text, options) {
    this._disableButtons();
    this._addDialogDiv(title, text);
	minimizeTVPlayer();
    
    if (options)
        $('#dialog').dialog(options);
    else
        $('#dialog').dialog();
}

DeviceConfigUi.prototype.closeDialog = function()
{
    $('#dialog').dialog('close').remove();
    this._enableButtons();
    
    // Let jQuery finish closing the dialog box first
	setTimeout(function() { maximizeTVPlayer(); }, 20);	
}

DeviceConfigUi.prototype._disableButtons = function() {
    this.disable_buttons_counter = this.disable_buttons_counter + 1;
    $('#button_panel > button').enabled(false);
}

DeviceConfigUi.prototype._enableButtons = function() {

    this.disable_buttons_counter = this.disable_buttons_counter - 1;

    if(this.disable_buttons_counter > 0)
        return;
    
    var current_step = this.getCurrentStep();
    var next_step = this.getNextStep(current_step);
    if(this._step_history.length > 0) {
        $('#back_button').enabled(true);
    }
    if(next_step) {
        $('#next_button').enabled(true);
    }
    if(
      (
        (current_step == 'welcome_existing') &&
        (! this.changed_existing_config)
      ) ||
      (! next_step)
    ) {
        $('#finish_button').enabled(true);
    }
    
    
    
    /*
    if (true == this.single_page) {
        $('#finish_button').enabled(true);
        $('#next_button').enabled(false);
        $('#back_button').enabled(false);
    }
    */
}

DeviceConfigUi.prototype._setCurrentStep = function(step, append_history, skip_exit)
{
    this._disableButtons();

    try {

    this._flipPage(step, skip_exit);

    if(append_history)
        this._step_history.push(this._current_step);

    this._current_step = step;

    } finally {

    this._enableButtons();
	if(this.getCurrentStep() == "network__wireless")
        $('#next_button').enabled(false);

    }
}

DeviceConfigUi.prototype.setCurrentStep = function(step) {
    try {
        this._setCurrentStep(step, true);
    } catch(e) {
        if(isObjInst(e, CancelStepExit)) {
            this.showAlert(e);
        } else if(isObjInst(e, StopExecution)) {
            ;
        } else {
            throw e;
        }
    }
}

DeviceConfigUi.prototype.processFormDataNetworkInterfaceType = function() {
    this.config.network.interface_type =
      getRadioSelection($('input[type=radio][name=interface_type]').get());
}

DeviceConfigUi.prototype.processFormDataNetworkWireless = function() {
		this.config.network.interface_type = "wireless";
    this.config.network.essid =
            $('#content__network__wireless__essid').attr('value');
    this.config.network.security =
            getRadioSelection($('input[type=radio][name=security_scheme]').get());
    this.config.network.secret =
            $('#content__network__wireless__secret').attr('value');
}

DeviceConfigUi.prototype.processFormData = function() {
    var current_step = this.getCurrentStep();

    if(current_step == 'network__interface_type'){
        this.processFormDataNetworkInterfaceType();
    }
    else if(current_step == 'network__wireless'){
        this.processFormDataNetworkWireless();
    }
}

DeviceConfigUi.prototype.nextStep = function()
{
	// If user is leaving the wireless connection page, check to see whether the
	// connection was successsful. If not, prompt the user to either continue with 
	// wired settings or try to reconfigure the wireless.
	var proceed = (this.getCurrentStep() == "network__wireless")
		?   this.confirmWirelessSettings()
	    :   true;

	if(proceed) {
		if(this.getCurrentStep() != "network__wireless")
		this.processFormData();
		this.setCurrentStep(this.getNextStep());
	}
}

DeviceConfigUi.prototype.prevStep = function()
{
    var prev_step = this._step_history.pop();

    try {
        this._setCurrentStep(prev_step, false);
    } catch(e) {
        if(isObjInst(e, CancelStepExit)) {
            this.showAlert(e);
            this._step_history.push(prev_step);
        } else {
            throw e;
        }
    }
}

DeviceConfigUi.prototype.confirmWirelessSettings = function() {
		
		var retval = true;
		_this = this;
		
		// If wireless is not connected:
    
    var not_connected = !TestNetwork();
    
	if (not_connected)
    {			
		// Prompt user
		if(confirm(IDS_LANGUAGE.install.configuration['configWireless']))
		{				
			// Continue using wired settings
			this.updateNetworkSettings("wired");
  	        this.deconfigureNetwork();
  	        this.configureNetwork();
		}
		// User has opted to reconfigure the wireless connection. Return to wireless configuration page.
		else retval = false;
    }
	// Wireless is connected:
	else this.showAlert(IDS_LANGUAGE.install.configuration['configSuccess']);
	
	

	return retval;
}

DeviceConfigUi.prototype.getTvStep = function() {
    if(HasTvDevice()) {
        return 'tv_config';
    }
    
    return 'no_tv';
}

DeviceConfigUi.prototype.getNextStep = function() {
    var step = this.getCurrentStep();
	_this = this;	
    // If installer has been entered via scan code, use the list of requested pages
    // to decide next step.
    
    if(this.pages_to_view.length > 0) {
      
      if(step == "finished") return false;
      
      for(var i=0;i<this.pages_to_view.length;i++) {

        // Network interface type fork
        if(step == "network__interface_type")
        {
          if(this.config.network.interface_type == "wireless") return "network__wireless";
          else if(this.config.network.interface_type != "none") return "assign_computer_name";
        }
        else if(step == "network__wireless")
        { 
          if(this.config.network.interface_type != "none") return "assign_computer_name";
        }

        if(step == this.pages_to_view[i]) {

          // Return next step listed in pages_to_view
          if(i == this.pages_to_view.length-1) return "finished";
          else if (isSkipIPod() && this.pages_to_view[(i+1)] == "ipod") {
        	  // Skip iPod pairing if the mfg_style doesn't support it
        	  var current_step = this._current_step;
        	  this._current_step = "ipod";
        	  var next_step = this.getNextStep();
        	  this._current_step = current_step;
        	  return next_step;
          }
          else {
            if(this.pages_to_view[(i+1)] == "tv_config") return this.getTvStep();
            else return this.pages_to_view[(i+1)];
          }

        }
        
      }
      
      return "finished";
      
    }
    
    /*
     * Note the (lack of) break statements here ...
     * Sorry about that, but it really was quite a bit more concise that way.
     */

    switch(step) {
        case 'welcome_new':
        case 'welcome_existing':
            return 'network__interface_type';
        case 'configure_touchscreen':
            return 'network__interface_type';
        case 'network__interface_type':
            if(this.config.network.interface_type == 'wireless')
                return 'network__wireless';
        case 'network__wireless':
            if(this.config.network.interface_type == 'none')
                return isSkipIPod() ? this.getTvStep() : 'ipod';
            return 'assign_computer_name';
        case 'assign_computer_name':						
        	if(isSkipIPod())
        	    return this.getTvStep();
        	else
                return 'ipod';
				
        case 'ipod':
            return this.getTvStep();
        case 'tv_config':
        case 'no_tv':
            return 'finished';
    }

    return undefined;
}

DeviceConfigUi.prototype.getInterfaceTypeDescription = function(interface_type)
{
    if(interface_type == 'wired')
        return IDS_LANGUAGE.installCore['wired'];

    if(interface_type == 'wireless')
        return IDS_LANGUAGE.installCore['wireless'];

    if(interface_type == 'none')
        return isSkipIPod() ? IDS_LANGUAGE.install.wireless['tvOnly'] : IDS_LANGUAGE.install.wireless['tvIpod'];

    this.showAlert(IDS_LANGUAGE.install.wireless['interface'] );
};

DeviceConfigUi.prototype.setInterfaceTypes =
  function(interface_types) {
    this.interface_types = interface_types;


    var index;
    
    // if there's a list, delete the list and regenerate it.
    var ulEl = document.getElementById('content__network__interface_type__interface_type_radio_group');
    if (null != ulEl)
    {
        var content = document.getElementById('content__network__interface_type');
        content.removeChild(content.lastChild); // we assume that the last child is the <ul>!
    }
   

    var html = '<div id="content__network__interface_type__interface_type_radio_group">';
    for (index = 0; index < interface_types.length; index++) {
    	var interface_type = interface_types[index];
    	html += '<input type="radio" name="interface_type" value="' + interface_type + '" ' + ' id="content__network__interface_type__interface_type__' + interface_type + '"/>'
    		+ '<label for="content__network__interface_type__interface_type__' + interface_type + '">'
    		+ '<span>' + this.getInterfaceTypeDescription(interface_type) + '</span>'
    		+ '</label>';
    }
    html += '</div>';
    $('#content__network__interface_type').append(html);
    $(function() { 
    	var me = $("#content__network__interface_type__interface_type_radio_group"); 
    	me.buttonset();
    	// Change to vertical buttons
    	$(':radio, :checkbox', me).wrap('<div style="margin: 1px"/>');
    	$('label:first', me).removeClass('ui-corner-left').addClass('ui-corner-top');
    	$('label:last', me).removeClass('ui-corner-right').addClass('ui-corner-bottom');
    });
};

DeviceConfigUi.prototype.setDisplaySize = function(value) { this.config.display.size = value; };

DeviceConfigUi.prototype.pullCert = function(_this) {

    try {
        mpDetachSPI();
        
        _self = _this;
        setTimeout(function () {
            $('#content__ipod__pull_cert_button').enabled(false);
            
            var options = { modal:true };
            _self.openDialog(
            IDS_LANGUAGE.install.ipodPairing['pairTitle'],
            IDS_LANGUAGE.install.ipodPairing['waitForIt']+'<br/><br/>'+IDS_LANGUAGE.install.ipodPairing['keepWaiting'] +'<br/><center><img src=images/8-1c.gif /></center>',
            options);

            $('#content__ipod__response').html(IDS_LANGUAGE.install.ipodPairing['pairStart']);
            _this.objTimer = setInterval(function() {
            	var pullCertProgress = npdata['gui_run_program_async_info']['status'];
				
				// Find the last line break and remove it          
            	var i = pullCertProgress.lastIndexOf('<br />');
            	if (i != -1) {
            		pullCertProgress = pullCertProgress.slice(0, i);
            	}
            	// Only add a percent sign to the end if the async status is an integer
            	if (!isNaN(parseInt(pullCertProgress))) {
            		pullCertProgress += '%';
            	}
            	
            	$('#content__ipod__response').html(pullCertProgress);
            }, 250);

            // start the pullcert script...
            var retVal = PullCert("PullCertComplete()");
        }, 0);
    }
    catch(e) {
        popError(e);
        PullCertComplete();
    }
}

DeviceConfigUi.prototype.testWireless = function(_this) {

	// Fade in wireless signal strength and connection status boxes
	setTimeout(function () {
		$("#wireless__signal__strength").animate({"opacity": 1}, 750);
		$("#wireless__connection__status").animate({"opacity": 1},750);
	}, 1000);
	
  try {
    if (_this.config.saveNetworkConfig())	{
			
      var _this = this;
      _self = _this;

      $('#content__wireless__test__button').enabled(false);
      $("#next_button").enabled(false);
      $("#back_button").enabled(false);

      var status = '';
      var oldmsg = '';
      setTimeout(function () {
				
        _this.objTimer = setInterval(function() {

            var newmsg = npdata['gui_run_program_async_info']['status'];
            if (newmsg != oldmsg) {
                status += newmsg;
                status += '<br/>';
                oldmsg = newmsg;
            }
            
            // Fill status window
            $('#wireless__status__window').html(status);
            // Scroll to bottom of status window
            $('#wireless__status__window').prop({"scrollTop": $("#wireless__status__window").prop("scrollHeight")});

        }, 250);

        var retVal = BringUpWireless("WirelessComplete()");

      }, 0);

    }
    else
        _this.showAlert(IDS_LANGUAGE.install.error['wireless']);
    
  }
  catch(e) {
    popError(e);
    WirelessComplete();
  }
}

function load() {
    var config, ui, interface_types;

    config = new DeviceConfig(CONFIG_DEFAULTS);

    interface_types = config.getInterfaceTypes();
    config.network.interface_type = interface_types[0];

    config.tv.present = HasTvDevice();

    ui = new DeviceConfigUi(config);
    g_UI = ui;
    ui.start();
}


//
//Skip iPod pairing
//
function isSkipIPod()
{
 if(true == identifyObj.isMatrix4x3())
 	return true;
 
 else if (true == identifyObj.isLifeFitnessAddOn()) 
 	return true;
 
 else
     return false;
}


