//
//  Called when a tuner type is chosen
//
function chooseTunerType(typeArr)
{
    //  Build type from item id
    for(var i=1,type="";i<typeArr.length;i++)
        type += typeArr[i]+"_";

    //  Pluck last character from string
    type = type.slice(0,-1);

    //  Do something based on tuner type
    switch(type)
    {
        //  Skip scan
        case "existing":
            //  Go to completed page
            tvStep("scanComplete");
            break;

        //  Download config from server
        case "download":
            downloadTVTunerScanFiles();
            break;

        //  Digital
        case "digital_cable":
        case "digital_ota":
        case "analog_digital_cable":
            //  Set global tuner type
            g_tunerType = type;
            //  Write tuner type to tv_conf.xml
            set_television_tuner_type(String(type));
            //  Go to scan page
            tvStep("scan");
            break;

        //  Analog
        default:
            //  Set global tuner type
            g_tunerType = type;
            //  Write tuner type to tv_conf.xml
            set_television_tuner_type(String(type));
            //  Go to scan page to run the scanner
            tvStep("scan");
            break;
    }
}

//
//  Show the given tv page
//
function tvStep(page)
{
    $("#tvViewContents").removeClass().addClass(page);

    switch(page)
    {
        case "tuner":
            // $("#scanComplete #uploadConfiguration").removeClass().addClass("hidden");
            killTVPlayer();
            highlightChosenTuner();
            break;
        case "scan":
            killTVPlayer();
            
            // Give the video player time to die so it can free up any resources needed for
            // channel scanning. Specifically for digital tv, we need /dev/dvb/adapter0/frontend0
            // to be available.
            setTimeout(function() { beginTVScan(); }, 500);
            break;
        case "scanComplete":
        	setUpChannels();
            showTVScanCompletePage();
            break;
        default:
            killTVPlayer();
            break;
    }
}

//
//  Show the TV scan complete page
//
function showTVScanCompletePage()
{
    //  Set header based on tuner type
    $("#scanComplete > h2").html(IDS_LANGUAGE.install.tvScan['configured'] +helpMeReadTunerType());

    //  Show "Add Channel" button if analog tuner
    switch(g_tunerType)
    {
        case "cable_standard":
        case "cable_irc":
        case "cable_hrc":
        case "analog_digital_cable":
            $("#addNewChannel").show();
            break;
        default:
            $("#addNewChannel").hide();
            break;
    }

    //  Show the tv player
    setTimeout(function() { showTVPlayer(); }, 800);
}

//
//  Highlight the selected tuner button
//
function highlightChosenTuner()
{
    $("#chooseTunerType ul fieldset li").each(function() {

        var typeArr = $(this).attr("id").split("_");

        for(var i=1,type="";i<typeArr.length;i++)
            type += typeArr[i]+"_";

        type = type.slice(0,-1);

        if(type == g_tunerType)
            $(this).addClass("selected");
        else
            $(this).removeClass("selected");

    });
}

//
//  Convert tuner type string to human readable format
//
function helpMeReadTunerType()
{
    switch(g_tunerType)
    {
        case "cable_standard": return IDS_LANGUAGE.install.tvConfig['tunerType_cable_standard']; break;
        case "cable_irc": return IDS_LANGUAGE.install.tvConfig['tunerType_cable_irc']; break;
        case "cable_hrc": return IDS_LANGUAGE.install.tvConfig['tunerType_cable_hrc']; break;
        case "digital_cable": return IDS_LANGUAGE.install.tvConfig['tunerType_digital_cable']; break;
        case "digital_ota": return IDS_LANGUAGE.install.tvConfig['tunerType_digital_ota']; break;
        case "analog_digital_cable": return IDS_LANGUAGE.install.tvConfig['tunerType_analog_digital_cable']; break;
        default: g_UI.showAlert(IDS_LANGUAGE.install.tvScan['unknown']); break;
    }
}

function minimizeTVPlayer() {
	$("#tvContainer #id_videoPlayerObject").css("width", "1px").css("height", "1px");
}

function maximizeTVPlayer() {
	$("#tvContainer #id_videoPlayerObject").css("width", "100%").css("height", "100%");
}

//
//  Show the tv player
//
function showTVPlayer()
{
    var playerString = '<object id="id_videoPlayerObject" class="videoPlayerObject" style="z-index:1;" type="video/mpeg" data="v4l2://" ><param name="data_type" value="tv" /></object>';
    
    $("#tvContainer").show();
    $("#tvContainer").html(playerString);

    setTimeout(function() {
        guiObj.showFullscreenButton(false);
        $("#tvContainer").css("visibility", "visible");
    }, 200);
}

//
//  Hide/kill the tv player
//
function killTVPlayer()
{
	killVideoPlayer("tvContainer");
	
	// I noticed that when going back to the tuner page of TV setup, an instance of the videoPlayer
	// would show on the screen for about a second. Removing the object from the page entirely should
	// prevent this.
    $("#tvContainer").html("");
}

//
//  Do TV scan based on type
//
function beginTVScan()
{
    //  Do digital/analog scan based on signal type
    switch(g_tunerType)
    {
        case "cable_standard":
        case "cable_irc":
        case "cable_hrc":
            doAnalogScan();
            break;
        case "digital_cable":
        case "digital_ota":
        case "analog_digital_cable":
            doDigitalScan();
            break;
        default:
            break;
    }
}

//
//  Analog TV Scan
//

function doAnalogScan()
{
    resetChannelPairings();
    var ntscmode = get_television_ntsc_mode();
    g_scanInProgress = true;
    $("#scanDetails").html("Starting analog TV scan...<br />");
    g_analogScanPid = runAsyncMuxedLogOutput("/netpulse/bin/channel-scan.sh " + ntscmode.toLowerCase(), "analogScanComplete();", "logOutputAnalog");
    
    var tunerType = runProgram('/netpulse/bin/n5i-sys', ['which-tv-device']).trim();
    if (tunerType == "HVR900H") {
    	g_UI.showAlert(IDS_LANGUAGE.channelInstaller.notify["yourTunerSucks"]);
    }
}

function logOutputAnalog(stringReturn)
{
    if (stringReturn == null)
        return;

    npinstall_curr_status = stringReturn;

    if (npinstall_curr_status == npinstall_prev_status)
        return;

    npinstall_prev_status = npinstall_curr_status;
    $("#scanDetails").append(npinstall_curr_status);
    var scrollHeight = $("#scanDetails")[0].scrollHeight;
    $("#scanDetails").scrollTop(scrollHeight);
}


//
//  Analog TV scan complete
//
function analogScanComplete()
{
    //  If scan was cancelled by user, bail.
    if (g_scanCancelled) {
        g_scanCancelled = false;
        runProgram('cp -f /netpulse/etc/stationlist.xml.default /netpulse/etc/stationlist.xml', '');
        reset_channel_list();
        return;
    }
    g_scanInProgress = false;
    reset_channel_list();

    //  Update JS channel config stuff
    tvStep("scanComplete");
}

//
//  Digital TV Scan
//
function doDigitalScan()
{
    //  Reset all user-entered channel settings kept in tv_conf.xml
    resetChannelPairings();

    g_scanInProgress = true;
    $("#scanDetails").html(IDS_LANGUAGE.install.tvScan['startingDigital']);
    g_digitalScanPid = runAsyncMuxedLogOutput('/netpulse/bin/scan-cable-limit.sh all ' + machineObj.getLocationCountry(), "digitalScanComplete();", "logOutputDigital");
}


//
//  Capture messages from digital scan
//
function logOutputDigital(stringReturn)
{
	if(stringReturn == null)
        return;

	npinstall_curr_status = stringReturn;

    var hasChannel = (npinstall_curr_status.split(":").length > 1);

	if(npinstall_curr_status == npinstall_prev_status || !hasChannel)
        return;

    $("#scanDetails").append(npinstall_curr_status).prop({"scrollTop": $("#scanDetails").prop("scrollHeight")});

    npinstall_prev_status = npinstall_curr_status;
}


function digitalScanComplete()
{
    //  If scan was cancelled by user, bail. bug #3517
    if(g_scanCancelled)
    {
        g_scanCancelled = false;
        reset_channel_list();
        return;
    }

    g_scanInProgress = false;

    //  If digital/analog setup we have to do the analog scan next. bug #3504
    if(g_tunerType == "analog_digital_cable")
    {
        setTimeout(function() { 
			// Clear the details from the previous scan
			$("#scanDetails").html("");
			
            //  Begin analog scan
            doAnalogScan();
        }, 5*1000);

        return;
    }

    //  Reset channel list
    reset_channel_list();

    //  Show TV config stuff
    tvStep("scanComplete");
}

//
//  Rescan channels
//
function rescanChannels()
{
    tvStep("scan");
}

function cancelChannelScan() {
    //  Flag that the scan was cancelled by the user - killing the scan causes the complete callback to be hit. bug #3517
    g_scanCancelled = true;

    //  Kill scan if we have a pid
    if (window.g_digitalScanPid && g_digitalScanPid != "0") {
        writeLog("info", "Killing digital scan PID "+g_digitalScanPid);
        runProgram("/netpulse/bin/n5i-sys kill-pid "+g_digitalScanPid);
    }
    if (window.g_analogScanPid && g_analogScanPid != "0") {
        writeLog("info", "Killing analog scan PID "+g_analogScanPid);
        runProgram("/netpulse/bin/n5i-sys kill-pid "+g_analogScanPid);
    }
    
    // Reset tv_conf.xml to default state. Scan complete callbacks will reset the channel list and
    // restore stationlist.xml if necessary
    set_television_tuner_type("cable");
    
    //  Go back to first page
    tvStep("tuner");
}

var kvTimeout = null;

//  Hide all VLC- and TVTime-based video players the same way to ensure Qt triggers the hide event.
function killVideoPlayer(playerId) {
    //  If no ID received, bail.
 
    if(!playerId)
    {
        writeLog("debug", "Error in killVideoPlayer() - Can't kill video player without an ID.");
        return;
    }

    //  If player doesn't exist, bail.
    if(!document.getElementById(playerId))
    {
        writeLog("debug", "Error in killVideoPlayer() - An element with the ID "+playerId+" doesn't exist.");
        return;
    }

    //  Use reference to the timeout to make sure we don't get more than one at a time.
    if(kvTimeout)
        clearTimeout(kvTimeout);

    kvTimeout = setTimeout(function() { 
        document.getElementById(playerId).style.visibility = "hidden";
        kvTimeout = setTimeout(function() { document.getElementById(playerId).style.display = "none"; }, 200);

    }, 200);
}
