//  www/jsi/language.js

languageConf = {
	/*
	 * Returns whether the installer should display the dialog to select/save 
	 * the default language in the local.xml.  By default, this is disabled,
	 * and should be overridden at the skin-specific level.
	 * 
	 * Parameter:
	 * 		stage	string	Example values:
	 * 						install (n5i/add-on installer)
	 * 						attract (n5i/lifefitness attract screen)
	 */
	'isEnabled' : function(stage) {
		var enabled = false;
		return enabled;
	},
	
	/*
	 * Returns the number of enabled languages
	 */
	'countEnabledLanguages' : function() {
		var count = 0;
		$.each(this.languages, function(index, value) {
			if (value.enabled) {
				count++;
			}
		});
		return count;
	},
	
	/*
	 * Determines the Installer dialog default width.  If not using the default
	 * widths for the language button/li, this should be overridden at the skin
	 * level. 
	 */
	'dialogMinWidth' : function(countEnabled) {
		if(typeof(countEnabled) != 'number') {
			countEnabled = this.countEnabledLanguages();
		}
		var width = 694;	// 3 columns
		if (countEnabled >15) 
			width = 914;	// 4 columns
		return width;
	},
	
	/*
	 * Display the dialog box to select the default language.
	 */
	'show' : function() {
		var me = this;
		
		if ($("#languageDialog").exists())
			$("#languageDialog").remove();
		
		$("body").append('<div id="languageDialog"></div>');
		var html = '<ul id="language_selection">';
		localObj.load();
		var currentLanguage = localObj.getLocale();
		
		var countEnabled = 0;
		$.each(this.languages, function(index, value) {
			if (value.enabled) {
				// Include only enabled languages
				// TODO: accommodate flags/images instead/in-addition-to the name
				html += '<li><button id="' + index + '" value="' + index + (index == currentLanguage ? '" class="selected' : "") + '"><span>' + value.name + '</span></button></li>';
				countEnabled++;
			}
		});
		selectLanguage(currentLanguage);
			
		html += '</ul>';
		var okTransString = ((IDS_LANGUAGE.installCore['ok']) ? IDS_LANGUAGE.installCore['ok'] : "ok");
		var titleTransString = IDS_LANGUAGE.install['selectDefaultLanguage'];
		$("#languageDialog").html(html)
			.dialog({
				'buttons' : [{
					text: okTransString, 
					click: function() { $(this).dialog("close"); }
				}],
				'dialogClass' : 'language',
//				'draggable' : false,
				'modal' : true,
				'position' : ['center', 'center'],
				'title' : titleTransString,
				'minWidth' : this.dialogMinWidth(countEnabled)
			});

		$("ul#language_selection button").live("mousedown." + me.name, function(e) {
			me.select(e);
		});
		
		$("ul#language_selection>li>button.selected").mousedown();
	},
	
	/*
	 * Save the selected language as default in the local.xml
	 */
	'select' : function(e) {
		var target;
		var _this = this;
		if (e.target.nodeName == "BUTTON") {
			target = e.target;
		} else if (e.target.parentElement.nodeName == "BUTTON") {
			target = e.target.parentElement;
		}
		if (target) {
//			$("ul#language_selection button").toggleClass("selected", $(this).attr("id") == target.id);
			$("ul#language_selection button").removeClass("selected");
			$(target).addClass("selected");
			// Save to local.xml
			localObj.setLocale(target.id);
			localObj.write();
			selectLanguage(target.id);
			
			_this.refresh();//This function will refresh the existing strings to reflect language change

            $('#content__network__interface_type__interface_type__none').click(function (evt){
                countryConf.show();
            });
			
			// MBrown following copied from www/views/install/js.js because there it is loaded before languages load.
			var detect = (identifyObj.isTechnoGym() || identifyObj.isStarTrac() || identifyObj.isMatrix7xi() || identifyObj.isLifeFitnessAddOn() || identifyObj.isN5i() || identifyObj.isMatrix4x3() ) ? true : false;
			
			var infoStr;
			if (detect) {
				infoStr = '<br /><strong>'+ IDS_LANGUAGE.installCore.detect['auto'] +'</strong><br />'
						+ IDS_LANGUAGE.installCore.detect['mfgName']
						+ identifyObj.getName()
						+ '<br />'
						+ IDS_LANGUAGE.installCore.detect['mfgId']
						+ identifyObj.getMfr()
						+ '<br />'
						+ IDS_LANGUAGE.installCore.detect['model']
						+ identifyObj.getModel()
						+ '<br />'
						+ IDS_LANGUAGE.installCore.detect['serial']
						+ identifyObj.getSerial()
						+ '<br />';
			} else {
				infoStr = '<big><strong class="fail"><em>'+ IDS_LANGUAGE.installCore.detect['fail'] +'</em></strong><br /></big>';
			}
			
			configObj.load();
			if (configObj.valid()) {
				infoStr += '<br /><strong>'+ IDS_LANGUAGE.installCore.load['prevInstalled'] +'</strong><br />'
				+ IDS_LANGUAGE.installCore.load['localConf'] +'<br />'
				+ IDS_LANGUAGE.installCore.load['machineId']
				+ configObj.getMid()
				+ '<br />'
				+ IDS_LANGUAGE.installCore.detect['mfgName']
				+ configObj.getName()
				+ '<br />'
				+ IDS_LANGUAGE.installCore.detect['mfgId']
				+ configObj.getMfr()
				+ '<br />'
				+ IDS_LANGUAGE.installCore.detect['model']
				+ configObj.getModel()
				+ '<br />'
				+ IDS_LANGUAGE.installCore.load['macAddress']
				+ configObj.getMac()
				+ '<br />';
				
				if (identifyObj.getMfr() != configObj.getMfr() || identifyObj.getModel() != configObj.getModel()) {
					infoStr += '<br /><strong>'+ IDS_LANGUAGE.installCore.load['noMatch'] +'</strong><br />';
				} else {
					infoStr += '<br /><strong>'+ IDS_LANGUAGE.installCore.load['yesMatch'] +'</strong><br />';
				}
			} else {
				infoStr += '<br /><strong>'+ IDS_LANGUAGE.installCore.load['neverInstalled'] +'</strong><br />';
			}			
			$('#installerMsg').html(infoStr);
			
			setTimeout(function(){htmlInternationalString();},150);
			// TODO: redraw screen with new language text
		}
	},
	
	'refresh' : function (){
		//This function will refresh the existing strings to reflect language change
		//This function has been added to support cases when you change a language
		if($("#languageDialog")){
			var okTransString=((IDS_LANGUAGE.installCore['ok']) ? IDS_LANGUAGE.installCore['ok'] : "ok");
			var titleTransString=IDS_LANGUAGE.install['selectDefaultLanguage'];
			$("#languageDialog").dialog({
				'buttons' : [{
					text: okTransString, 
					click: function() { $(this).dialog("close"); }
				}],
				'title' : titleTransString
			});	
		}
		
		setTimeout(function(){
			if($('#content__network__interface_type__id_network_devices'))
				$('#content__network__interface_type__id_network_devices').click();
		},150);
	},
	
	'languages' : {
		'en' : { 'name' : 'English', 'enabled': false, 'image' : null },
		'es' : { 'name' : 'Español', 'enabled': false, 'image' : null },
		'pt' : { 'name' : 'Português', 'enabled': false, 'image' : null },
		'it' : { 'name' : 'Italiano', 'enabled': false, 'image' : null },
		'nl' : { 'name' : 'Nederlands', 'enabled': false, 'image' : null },
		'fr' : { 'name' : 'Français', 'enabled': false, 'image' : null },
		'pl' : { 'name' : 'Polski', 'enabled': false, 'image' : null },
		'ca' : { 'name' : 'Català', 'enabled': false, 'image' : null },
		'eu' : { 'name' : 'Euskara', 'enabled': false, 'image' : null },
		'de' : { 'name' : 'Deutsch', 'enabled': false, 'image' : null },
		'ja' : { 'name' : '日本語', 'enabled': false, 'image' : null },
		'zhs' : { 'name' : '中文', 'enabled': false, 'image' : null },
		'zht' : { 'name' : '簡體中文', 'enabled': false, 'image' : null },
		'tr' : { 'name' : 'Türkçe', 'enabled': false, 'image' : null },
		'ru' : { 'name' : 'Русский язык', 'enabled': false, 'image' : null },
		'ko' : { 'name' : '한국어', 'enabled': false, 'image' : null },
		'fi' : { 'name' : 'Suomi', 'enabled': false, 'image' : null },
		'hu' : { 'name' : 'Magyar', 'enabled': false, 'image' : null },
		'ar' : { 'name' : 'العربية', 'enabled': false, 'image' : null },
		'el' : { 'name' : 'ελληνικά', 'enabled': false, 'image' : null },
		'hi' : { 'name' : 'हिन्दी', 'enabled': false, 'image' : null },
	}
};
