/*=====================================================================
	Main Landing Page (core) | views/landingPage/js.js
=====================================================================*/

function landingPageObj(name, type, vm) {
    this.name = name;
    this.type = type;
    this.vm = vm;
    this.volume = machineObj.getVolumeLevel();
    this.recItemTypes = [];
    this.npSlotTotal = 6;
    this.oemSlotTotal = 0;
    
    // Checking for media types in mediaXML then adding that type into the itemTypes array to 
    // avoid situation of crashing when we encounter a media.xml file that doesn't have the data
    // we are looking for. This will only work if media.xml is loaded and parsed synchronously  
    if(mediaXML.musicVideos.length > 0) this.recItemTypes.push("musicVideos");
    if(mediaXML.onDemand.length > 0) this.recItemTypes.push("onDemand");
    if(mediaXML.virtualActive.length > 0) this.recItemTypes.push("virtualActive");
    
    this.recEngine = new RecEngine({
        "numItems": this.npSlotTotal + this.oemSlotTotal,
        "itemTypes": this.recItemTypes,
        "adSlots": [0, 1],
        "promoSlots": [0]
    });
}

//  Inherit basic view functions init(), show(), hide()
landingPageObj.prototype = new app;

landingPageObj.prototype.showAds = function coreLandingPageObjShowAds() { adMan.showAd("mm_300x250"); };
landingPageObj.prototype.hideAds = function coreLandingPageObjHideAds() { adMan.hideAd("mm_300x250"); };

landingPageObj.prototype.preShowHook = function coreLandingPageObjPreShowHook() {};
landingPageObj.prototype.postShowHook = function coreLandingPageObjPostShowHook() {};

landingPageObj.prototype.hide = function coreHideLandingPage() {this.videoEndReached();};

landingPageObj.prototype.show = function coreLandingPageObjShow() {
	try {
	    // Add functions to the beginning of the view.
        this.preShowHook();
	    
	    this.viewCount();
	    this.recEngine.enableAds(!adMan.disabled);
        this.recEngine.enablePromotions(this.views % 4 == 1);

		this.isVideoPlaying = false;
		this.resetFeaturedItemTypes();
		this.bindHTMLElements();
		this.featuredContent();
		this.attachEvents();
		this.htmlInternationalString();

		//$paginationDiv.hide();

		this.showAds();

		// Add functions to the end of the view.
        this.postShowHook();
	} catch (e) {
		popError(e);
		return false;
	}
};

landingPageObj.prototype.resetFeaturedItemTypes = function(){
	this.recItemTypes = [];
	
	// Checking for media types in mediaXML then adding that type into the itemTypes array to
	// avoid situation of crashing when we encounter a media.xml file that doesn't have the data
	// we are looking for.
	if (mediaXML.playlist.length > 0) this.recItemTypes.push("playlist");
	if (mediaXML.musicVideos.length > 0) this.recItemTypes.push("musicVideos");
	if (mediaXML.onDemand.length > 0) this.recItemTypes.push("onDemand");
	if (mediaXML.virtualActive.length > 0) this.recItemTypes.push("virtualActive");
	
	this.recEngine.setItemTypes(this.recItemTypes);
};

landingPageObj.prototype.views = 0;
landingPageObj.prototype.viewCount = function coreLandingPageObjViewCount() {
	return (this.views = ('undefined' == typeof this.views) ? 0 : this.views + 1);
};

landingPageObj.prototype.isClientZoneFilled = isClientZoneFilled;

landingPageObj.prototype.showFeaturedZone = function coreLandingPageObjShowFeaturedZone() {
    var me = this;
    
    // If 'featured_n5i' is filled, replace with clientZone.
    this.showingClientZone = this.isClientZoneFilled();
    if (this.showingClientZone) {
       this.$watchNowButton.hide();
       this.$featuredTitle.hide();
       this.$featuredImage.hide();

    $('nav#buttonList button.button')
        .unbind('mousedown.' + this.name)
        .bind('mousedown.' + this.name, function(e) {
            window.isFb = false;
            var t = e.target, i = t.id, v = (('featuredRegister' == i) ? 'registration' : 'login');
            if (e.stopImmediatePropagation) {
                e.stopImmediatePropagation();
            } else {
                e.cancelBubble = true;
            }
            return (me.vm.show(v));
        });
    }
};

landingPageObj.prototype.bindHTMLElements = function coreLandingPageObjBindHTMLElements() {
    var me = this;

    me.$container = $("#landingPage");
    me.$usernameWelcome = me.$container.find(".homeIcon h1");
    me.$featureBoxTitle = me.$container.find(".homeIcon h2");
    me.$featuredContent = me.$container.find("#featuredContent");
    me.$featuredImage = me.$featuredContent.find("#featuredImage");
    me.$featuredTitle = me.$featuredContent.find("#featuredTitle span");
    me.$watchNowButton = me.$featuredContent.find("#buttonWatchNow");

    me.$featured1Button = me.$container.find("#buttonFeatured1");
    me.$featured2Button = me.$container.find("#buttonFeatured2");
    me.$featured3Button = me.$container.find("#buttonFeatured3");
    me.$featured4Button = me.$container.find("#buttonFeatured4");
    me.$featured5Button = me.$container.find("#buttonFeatured5");

    me.$menuTray = me.$container.find("#menuTray");
    me.$menuUserInfo = $("#userInfo");
    me.$menuItems = me.$menuTray.find("#items");
    me.$exitButton = $("#exitButtonCopy"); 
};

landingPageObj.prototype.attachEvents = function coreLandingPageObjAttachEvents() {};

landingPageObj.prototype.usernameMainToHtml = function coreLandingPageObjUsernameMainToHtml() {
	var userName = ((user.firstName && user.firstName.toLowerCase() != "null") ? user.firstName : "");
	if (userName.length == 0) userName = IDS_LANGUAGE["defaultUser"];
	return(sprintf(IDS_LANGUAGE["helloUser"], userName));
};

landingPageObj.prototype.nonUserMainToHtml = function coreLandingPageObjNonUserMainToHtml() {
	var html = IDS_LANGUAGE["welcome"];
	return(html);
};

landingPageObj.prototype.nextVideo = function() {
	this.videoEndReached();
	this.showFeaturedImage();
};

landingPageObj.prototype.videoEndReached = function(){
	if(!this.isVideoPlaying)
		return;
	try {
		this.saveImpression();
	} catch (e) { popError(e); }
	stopVideo($("#videoContainer"));
	this.isVideoPlaying = false;
};

landingPageObj.prototype.saveImpression = function(){
	var playTime = guiObj.getVideoTimeElapsedInSeconds();

	if(playTime > 0)
		adMan.ads["landing_video"].addVideoImpression(playTime);
	
	guiObj.resetVideoTimeElapsedInSeconds();
};

landingPageObj.prototype.showFeaturedItem = function coreLandingPageObjShowFeaturedItem(recItem) {
    this.$featuredTitle.html(recItem.title);
    this.$featuredImage.css("background", "url("+recItem.thumbnail+") no-repeat center")
    this.$featuredContent.unbind().bind("click." + this.name, recItem.behavior); 
}

landingPageObj.prototype.featuredContent = function coreLandingPageObjFeaturedContent() {
    this.featured = this.recEngine.getFeaturedContent();
    this.showFeaturedImage();
    this.showRecommendedItems();

}

landingPageObj.prototype.showFeaturedImage = function(){
	var me = this;
	this.$watchNowButton.show();
    $("#featuredTitle").show();
    $("#videoContainer").css("visibility","hidden");
    
    // Main featured content item
    if (this.featured[0].type == "promotion") {
        if (!this.showFeaturedZone()) {
            this.recEngine.enablePromotions(false);
            this.featured[0] = this.recEngine.getUniqueFeaturedItem(this.recItemTypes);
            this.showFeaturedItem(this.featured[0]);
        }
    } 
    else if (this.featured[0].type == "ad") {
    	try{
    		if($("#videoContainer").length && adMan.ads["landing_video"].showLandingVideoAd()){
    			this.$watchNowButton.hide();
    		    $("#videoContainer").css("visibility","visible");
    			this.isVideoPlaying = true;
    		}
    		
    		else if (!adMan.showAd("landing_featured")) {
                this.featured[0] = this.recEngine.getUniqueFeaturedItem(this.recItemTypes);
                this.showFeaturedItem(this.featured[0]);
            }
    	}
    	catch(e){
    		popError("Ad is not available: " + e);
    	}
    } else {
        this.showFeaturedItem(this.featured[0]);
    }
};

landingPageObj.prototype.showRecommendedItems = function(){
    // Recommended item slots
    for (var i=1; i<(this.npSlotTotal+this.oemSlotTotal); i++) {
        if (this.featured[i].type == "ad") {
            if (!adMan.showAd("mmbtn_branded")) {
                this.featured[i] = this.recEngine.getUniqueFeaturedItem(this.recItemTypes);
                i--; continue;
            }
        } else {
            this.$container.find("#buttonFeatured" + i + " span").html(this.featured[i].title);
            this.$container.find("#buttonFeatured" + i).unbind().bind("click." + this.name, this.featured[i].behavior);
        }
    }
};

landingPageObj.prototype.htmlInternationalString = function coreLandingPageObjHtmlInternationalString() {
    // User Welcome.
    var me = this,
        tempTitle = '' + me.$featuredContent.find("#featuredTitle span").html(),
        commaIdx = tempTitle.indexOf(":");

    if (!this.$usernameWelcome || !this.$usernameWelcome.length) {
        this.$usernameWelcome = $('.homeIcon h1');
    }

    if (athleteObj.get_user_id()) {
        if (this.usernameMainToHtml) {
            this.$usernameWelcome.html(me.usernameMainToHtml());
        }
        if(this.$menuUserInfo.length){
        	this.$menuUserInfo.html(viewManager.userInfoToHtml());
        }
        if(this.$featureBoxTitle.length){
        	this.$featureBoxTitle.html(IDS_LANGUAGE.mainMenu["topRecommend"]);
        }
        
    } else {
        if (this.nonUserMainToHtml) {
            this.$usernameWelcome.html(me.nonUserMainToHtml());
        }
        
        if(this.$menuUserInfo.length){
        	this.$menuUserInfo.html(viewManager.nonUserInfoToHtml());
        }
        
        if(this.$featureBoxTitle.length){
        	this.$featureBoxTitle.html(IDS_LANGUAGE.mainMenu['whatHot']);
        }
    }
    this.$watchNowButton.find("span").html(IDS_LANGUAGE["watchNowButton"]);
    this.$featuredContent.find("#featuredTitle span.featuredOnDemandTitle").html(IDS_LANGUAGE.featuredContent["featuredOnDemand"] + tempTitle.slice(commaIdx));
    this.$featuredContent.find("#featuredTitle span.featuredMusicTitle").html(IDS_LANGUAGE.featuredContent["featuredMusic"] + tempTitle.slice(commaIdx));
    this.$featuredContent.find("#featuredTitle span.featuredTitle").html(IDS_LANGUAGE.featuredContent["featured"]);
    this.$featuredContent.find("#featuredTitle span.featuredVtTitle").html(IDS_LANGUAGE.featuredContent["featuredVt"]);
    this.$featuredContent.find("#featuredTitle span.featuredPlaylistTitle").html(IDS_LANGUAGE.featuredContent["featuredPlaylist"]);
    this.$featuredContent.find("#featuredTitle span.featuredVATitle").html(IDS_LANGUAGE.featuredContent["featuredVA"]);
    this.$featuredContent.find("#featuredTitle span.featuredMainTitle").html(IDS_LANGUAGE.featuredContent["featuredMain"]);
    
    if(this.$exitButton.length){
    	this.$exitButton.html(IDS_LANGUAGE['exitNow']);
    }
}; 


