/*=====================================================================
	Custom Playlist Script (CORE) | views/playlist/js.js
=====================================================================*/

function musicPlaylistObj(name, type, vm) {
    this.name = name;
    this.type = type;
    this.vm = vm;

    this.genres = [];
    this.artists = [];
    this.artistsCount = null;
    this.videos =  [];
    this.chosenVideos = [];

    this.chosenGenre = null;
    this.chosenArtist = null;

    this.mainSlidingBox = null;
    this.mySlidingBox = null;

    this.$mainVideoContainer = null;
    this.$mainVideoHeader = null;
    this.$mainVideoList = null;

    this.$myVideoContainer = null;
    this.$myListHeader = null;
    this.$myVideoList = null;
    
    this.$modalPopUp = null;

    this.keyboard = null;
    this.shuffle = false;
    this.lastItem = null;
    this.clicked = false;

    this.listChanged = false;

    

    // track # of items displayed so addArtists can add new items only
    this.curItemCount = null;
    this.pagesToDisplay = ["page0"];
}

//  Inherit basic view functions init(), show(), hide()
musicPlaylistObj.prototype = new app;

//
//  Init() - if mediaXML is null (not found), disable this page.
//
musicPlaylistObj.prototype.init = function coreMusicPlaylistObjInit() {
    if (!mediaXML || !mediaXML.playlist || 0 == mediaXML.playlist.length)
        this.disabled = true;
};

musicPlaylistObj.prototype.loadContent = function coreMusicPlaylistObjLoadContent(data) {
    try {
    
    //  Get video list from mediaXML object
    this.videos = mediaXML.playlist;

    //  Get unique genres
    this.getGenres();

    //  Get unique artists
    this.getArtists();

    //  Remove any doubles
    this.removeDuplicates();

    //  Order videos by create time
    this.videos.sort(sortByCreateTime);

    } catch(e) {popError(e);}
    
};

musicPlaylistObj.prototype.getGenres = function coreMusicPlaylistObjGetGenres() {
    for(var i=0;i<this.videos.length;i++)
    {
        for(var j=0,match=false;j<this.videos[i].genres.length;j++)
        {
            match = false;

            for(var k=0;k<this.genres.length;k++)
            {
                if(this.genres[k] == this.videos[i].genres[j])
                {
                    match = true;
                    break;
                }
            }

            if(!match) this.genres.push(this.videos[i].genres[j]);
        }
    }
};

musicPlaylistObj.prototype.getArtists = function coreMusicPlaylistObjGetArtists() {
    var thisArtist = [];
    var thisVideo = null;
	for(var i=0, match=false, videoLen=this.videos.length; i<videoLen; i++)
    {
        thisVideo = this.videos[i];
        match = false;

        for(var j=0, artistsLen=this.artists.length; j<artistsLen; j++)
        {
            thisArtist = this.artists[j];
            if(!thisArtist || !thisArtist.name) {
                continue;
            }
            //  If we have already added this artist, add this video's genre (if unique) to this artist's list of genres.
            if(thisArtist.name == thisVideo.artist)
            {
                //  Find additional genres for this artist.
                match = true;

                for(var k=0, genreMatch=false, genresLen=thisVideo.genres.length; k<genresLen; k++)
                {
                    for(var l=0, artistGenresLen=thisArtist.genres.length; l<artistGenresLen; l++)
                    {
                        if(thisArtist.genres[l] == thisVideo.genres[k])
                        {
                            // Genre already exists for this artist.
                            genreMatch = true;
                            break;
                        }
                    }

                    //  This genre is new to this artist.
                    if(!genreMatch)
                        thisArtist.genres.push(thisVideo.genres[k]);
                }
            }
        }

        //  If this is a new artist, add it to the list.
        if(!match)
        {
            // thisArtist needs to be cast as an array for fast indexing.
            thisArtist = [];
            thisArtist.name = thisVideo.artist;
            thisArtist.thumb = thisVideo.thumb;
            thisArtist.genres = [];
            for(var m=0, videoGenresLen=thisVideo.genres.length; m<videoGenresLen; m++)
                thisArtist.genres.push(thisVideo.genres[m]);

            this.artists.push(thisArtist);
        }
    }

    this.artists.sort(sortByName);
};

//  Prevent duplicate song/artist pairs
musicPlaylistObj.prototype.removeDuplicates = function coreMusicPlaylistObjRemoveDuplicates() {
	var newVideos = [];
	var tempArray = [];
	for(var i=0, len = this.videos.length;i<len;i++){
		if(!tempArray[this.videos[i].id]){
			tempArray[this.videos[i].id]=true;
			newVideos.push(this.videos[i]);
		}
	}
	this.videos = newVideos;
	
};

musicPlaylistObj.prototype.setupMenuData = function coreMusicPlaylistObjSetupMenuData() {
    var me = this;

    me.menuData = {
        levels : [ {
            drawItem : function coreMusicPlaylistMenuDrawItem(data) {
                // Remove pages to memory before popping back into page.
                var $el = $("#" + data), $saved = $el.clone(true);
                $el.remove();
                return($saved.html());
            },
            attachEvents : function coreMusicPlaylistMenuAttachEvents(obj, $container) {
                $container.find("li").each(function() {
                    // even though this is an empty function it's still needed for init.
                });
            }
        } ],
        items : me.pagesToDisplay
    };
};

musicPlaylistObj.prototype.bindHTMLElements = function coreMusicPlaylistObjBindHTMLElements() {
    //  Main Video Container Setup
    this.$mainVideoContainer = $("#mainVideoContainer");
    this.$mainVideoHeader = this.$mainVideoContainer.find("h1");
    this.$mainVideoList = this.$mainVideoContainer.find("#mainVideoList");

    //  My Video Container Setup
    this.$myVideoContainer = $("#myVideoContainer");
    this.$myListHeader = this.$myVideoContainer.find("h1");
    this.$myVideoList = this.$myVideoContainer.find("#myVideoList");

    this.$titleField     = $("#customTitle");
    this.$playlistInputTitle = $("#playlistTitle");
    this.$modalPopUp     = $("#modalPopUp");
    this.$watchNowButton = $("#watchNowButton");
    this.$shuffleButton  = $("#shuffleToggleButton");
    this.$saveButton = $("#saveButton");

    // Keyboard Init
    this.$titleKeyboard  = $("#id_email_keyboard");
    this.$editButton = $("#editButton");
    this.$enterButton = $("#enterButton");
};

musicPlaylistObj.prototype.show = function coreMusicPlaylistObjShow() {
    var retBool = true;
    try {
    
    this.loadContent();

    this.setupMenuData();
    
    var _this = this;
    this.slidingBox = new slidingBox(
        this.menuData,
        $("#viewPort"),
        $("#playlistContainer"),
        $("#backButton"),
        $("#nextButton"),
        1,
        200,
        function() { _this.savePlaylist();  _this.removeEvents(); viewManager.show("mainMenu"); }
    );

    this.keyboard = null;
    if(userCustomPlaylist.items.length && this.chosenVideos.length == 0)
        for(var i=0;i<userCustomPlaylist.items.length;i++)
            this.chosenVideos.push(userCustomPlaylist.items[i].id);

    //  Main Video Container Setup
    this.$mainVideoContainer = $("#mainVideoContainer");
    this.$mainVideoHeader = this.$mainVideoContainer.find("h1");
    this.$mainVideoList = this.$mainVideoContainer.find("#mainVideoList");

    this.mainSlidingBox = new multiSlidingBox(
        this.$mainVideoList,
        this.$mainVideoList.parent().find(".scrollUp"),
        this.$mainVideoList.parent().find(".scrollDown"),
        this.$mainVideoList.parent().find(".scrollBack"),
        "mainVideoList",
        4
    );

    //  My Video Container Setup
    this.$myVideoContainer = $("#myVideoContainer");
    this.$myListHeader = this.$myVideoContainer.find("h1");
    this.$myVideoList = this.$myVideoContainer.find("#myVideoList");

    this.mySlidingBox = new multiSlidingBox(
        this.$myVideoList,
        this.$myVideoList.parent().find(".scrollUp"),
        this.$myVideoList.parent().find(".scrollDown"),
        this.$myVideoList.parent().find(".scrollBack"),
        "myVideoList",
        1,
        4
    );

    this.$titleField     = $("#customTitle");
    this.$playlistInputTitle = $("#playlistTitle");
    this.$modalPopUp     = $("#modalPopUp");
    this.$watchNowButton = $("#watchNowButton");
    this.$shuffleButton  = $("#shuffleToggleButton");
    this.$saveButton = $("#saveButton");
    //Keyboard Init
    
    this.$titleKeyboard  = $("#id_email_keyboard");
    this.$editButton = $("#editButton");
    this.$enterButton = $("#enterButton");

    this.attachEvents();
    this.updateMainList(0);
    this.initMyList();
          this.mainSlidingBox.$levels[0].find("button").live("mousedown."+this.name, function(e) {_this.mouseDownPos = e.pageY; })
        .live("mouseup."+this.name, function(e) { _this.introListClicked(e);    _this.slidingBox.$back.hide();})
        ;

  	if(userCustomPlaylist.shuffle == true)
   		this.$shuffleButton.addClass("shuffleYes");

 	if(userCustomPlaylist.items.length > 0) {
    	var currentlyScrolling = this.mySlidingBox.getCurrentlyScrolling();
    	var itemHeight = currentlyScrolling.find("li").height() + 2;    //  Add two for border width.
    	this.drawMyList(-1 * (parseInt(currentlyScrolling.css("top")) - this.mySlidingBox.$container.height()) < parseInt(currentlyScrolling.height() + itemHeight));
	
		if(this.$mainVideoContainer.is(".expanded"))
        	this.unHideMyPlaylist();
	}

    var modalStr = (!athleteObj.get_user_id())
            ?   "LogInRequired"
            :   (this.chosenVideos.length > 0)
                ?   "New/Edit"
                :   "Intro";

    this.showModal(modalStr);

    } catch(e) { popError(e); return false; }

	this.htmlInternationalString();
    this.updateTitleField(userCustomPlaylist.title);

	return true;
};


//
//  Override normal menu and quit functionality. If user is logged in, check for changes before proceeding.
//
musicPlaylistObj.prototype.mainMenuButtonOverride = function coreMusicPlaylistObjMainMenuButtonOverride(callback) {
    //if(window.regUser)
    if(athleteObj.get_user_id()) {
        this.checkForChanges( function() { callback(); } );
    } else {
        callback();
    }
};

musicPlaylistObj.prototype.showAds = function coreMusicPlaylistObjShowAds() {
    $("#controlBarAdSpace").html("<div id='playlist_banner'></div>");
    adMan.showAd("playlist_banner");
};

musicPlaylistObj.prototype.hideAds = function coreMusicPlaylistObjHideAds() {
    adMan.hideAd("playlist_banner");
    $("#controlBarAdSpace").html("");
};

musicPlaylistObj.prototype.attachEvents = function coreMusicPlaylistObjAttachEvents() {
    var _this = this;

    this.$mainVideoContainer.find(".scrollBack").bind("click."+this.name, function(e) { _this.goBack(); });

    this.mainSlidingBox.$levels[1]
        .bind("mousedown."+this.name, function(e) { _this.mouseDownPos = e.pageY; })
        .bind("mouseup."+this.name, function(e) { _this.genreListClicked(e); })
    ;
    this.mainSlidingBox.$levels[2]
        .bind("mousedown."+this.name, function(e) { _this.mouseDownPos = e.pageY; })
        .bind("mouseup."+this.name, function(e) { _this.artistListClicked(e); })
    ;
    
    $("body").bind("mouseup."+this.name, function() { _this.mouseDownPos = 0; });

    this.mainSlidingBox.$levels[3].find("a").live("mouseup."+this.name, function(e) { 
    	if ($(e.target).hasClass("add")) {
    		_this.addVideo(e);
    	} else {
    	    _this.removeVideo(e);
    	}
    });
    this.mySlidingBox.$levels[0].find(".subtract").live("mouseup."+this.name, function(e) { _this.removeVideo(e); });

    this.$titleKeyboard.bind("mousedown."+this.name, function(e){_this.keyboardInput(e);});
    this.$editButton.bind("mousedown."+this.name, function(e){_this.toggleKeyboardTray(e);});
    this.$enterButton.bind("mousedown."+this.name, function(e){
    	_this.toggleKeyboardTray(e);
	    _this.updateTitleField(_this.$playlistInputTitle.val());
	});
   
    this.$watchNowButton.bind("mousedown." + this.name, function () { _this.watchNow(); });
    this.$shuffleButton.bind("click."+this.name, function() { _this.toggleShuffle(); listChanged=true; });
    this.$saveButton.bind("click."+this.name, function() { _this.savePlaylist(); viewManager.show("mainMenu");});
    $("#mainMenuButton").bind("mousedown."+this.name, function() { 
    	_this.savePlaylist();
		viewManager.show("mainMenu");
    });
};

musicPlaylistObj.prototype.getEventTarget = function coreMusicPlaylistObjGetEventTarget(e, nodeType) {
    var $target = (e.target.nodeName.toUpperCase() == nodeType.toUpperCase())
        ?   $(e.target)
        :   (e.target.parentNode.nodeName.toUpperCase() == nodeType.toUpperCase())
            ?   $(e.target.parentNode)
            :   null;
    return($target);
};

musicPlaylistObj.prototype.watchNow = function coreMusicPlaylistObjWatchNow() {
    if(this.chosenVideos.length == 0)     {
        showModal(IDS_LANGUAGE["addVideo"], true);
        return;
    }

    this.savePlaylist();
    this.removeEvents();

    //Wait three seconds while playlist saves, then show music page and play playlist.

        viewManager.show("music");
        setTimeout(function() { 
            viewManager.activeObject.slideBox.chosenItems[0] = 0; 
            $("li#level_0_item_0").trigger("click"); }, 2000);

};

musicPlaylistObj.prototype.resetMyList = function coreMusicPlaylistObjResetMyList() {
    listChanged = false;
    this.chosenVideos = [];
    this.initMyList();
    this.hideModal();
    this.$editButton.trigger("click", [IDS_LANGUAGE["entertitle"]]);
};

musicPlaylistObj.prototype.beginNewList = function coreMusicPlaylistObjBeginNewList() {
    this.initMyList();
    this.hideModal();
    this.$editButton.trigger("click", [IDS_LANGUAGE["entertitle"]]);
};

musicPlaylistObj.prototype.toggleShuffle = function coreMusicPlaylistObjToggleShuffle() {
    this.shuffle = !this.shuffle;
    this.updateShuffleButton();
};

musicPlaylistObj.prototype.updateShuffleButton = function coreMusicPlaylistObjUpdateShuffleButton() {
    if(this.shuffle)
        this.$shuffleButton.addClass("shuffleYes");
    else
        this.$shuffleButton.removeClass("shuffleYes");
};

musicPlaylistObj.prototype.updateTitleField = function coreMusicPlaylistObjUpdateTitleField(newTitle) {
    if(!newTitle || !newTitle.trim())
        newTitle = "My Playlist";
	else 
		newTitle = newTitle.trim();

    this.$titleField.html(newTitle);
    this.$playlistInputTitle.val(newTitle);
};

musicPlaylistObj.prototype.goBack = function coreMusicPlaylistObjGoBack(e) {
    var currentMenu = this.mainSlidingBox.getCurrentlyScrolling();
    var currentMenuInt = (currentMenu.attr("id") == "level0") ? 0 : (currentMenu.attr("id") == "level1") ? 1 : (currentMenu.attr("id") == "level2") ? 2 : 3;

    // reset artists count when leaving artists page
    if(currentMenuInt !== 2) {
        this.artistsCount = null; 
        this.curItemCount = null;
    }

    //  Count item in current list
    var counter = 0;
    currentMenu.find("li").each(function() {
        $(this).data('item', counter);
        counter++;
    });

    currentMenu.height("auto");
    //  If this menu is shorter than the parent, grow it to fill the parent (for usability).
    if(currentMenu.height() < currentMenu.parent().height())
        currentMenu.css("min-height", currentMenu.parent().height()+"px");

    // if artists menu then set counter to full count of artists
    if(currentMenuInt === 2) counter = this.artistsCount;

    //  Update main list title
    this.updateMainListTitle(currentMenuInt, counter);
    
    // If we're on the top level AND the back button has a function, then show it.
    if (currentMenuInt == 0 && this.slidingBox.backButtonOnTop) {
        this.slidingBox.$back.show();
    }
};

musicPlaylistObj.prototype.drawAllArtists = function coreMusicPlaylistObjDrawAllArtists() {
    this.updateMainList(1);

    this.chosenGenre = null;

    this.updateMainList(2);
};

musicPlaylistObj.prototype.showLatestVideos = function coreMusicPlaylistObjShowLatestVideos() {
    this.drawAllArtists();

    this.chosenArtist = null;
    this.updateMainList(3);
    
   if(!this.$mainVideoContainer.is(".expanded"))
      this.unHideMyPlaylist();
};

musicPlaylistObj.prototype.updateMainList = function coreMusicPlaylistObjUpdateMainList(which) {
    //  Set currentMenu to which (JQuery reference to current slidingBox menu)
    var currentMenu = this.mainSlidingBox.setCurrentMenu(which);

    //  Scroll current list to top
    this.mainSlidingBox.scrollToTop(currentMenu);

    //  Set this menu to default height
    currentMenu.height("auto");

    //  Fill this list with proper html
    currentMenu.html(this.getMenuContents(which));

    //  If this menu is shorter than the parent, grow it to fill the parent (for usability).
    if(currentMenu.height() < currentMenu.parent().height())
        currentMenu.css("min-height", currentMenu.parent().height()+"px");

    //  Give metadata to each menu item
    var counter = 0;
    currentMenu.find("li").each(function()
    {
        $(this).data('item', counter);
        counter++;
    });
    
    // use total count of artists
    if(which === 2) counter = this.artistsCount;

    //  Update main list title
    this.updateMainListTitle(which, counter);

    //  Slide to current list
    this.mainSlidingBox.slideTo(currentMenu);
};

musicPlaylistObj.prototype.getMenuContents = function coreMusicPlaylistObjGetMenuContents(which) {
    var htmlStr = "";

    switch(which) {
        case 0:
            htmlStr = this.drawIntro();
            break;

        case 1:
            htmlStr = this.drawGenres();
            break;

        case 2:
            htmlStr = this.drawArtists();
            break;

        case 3:
            htmlStr = this.drawVideos();
            break;

        default:
            break;
    }

    return(htmlStr);
};

musicPlaylistObj.prototype.drawIntro = function coreMusicPlaylistObjDrawIntro() {
    return(IDS_LANGUAGE["selectcategory"]);
};

musicPlaylistObj.prototype.drawGenres = function coreMusicPlaylistObjDrawGenres() {
    for (var i = 0, htmlStr = "", ilen = this.genres.length; i < ilen; i++) {
        var thumbnail = null;

        for (var j = 0, jlen = this.videos.length; j < jlen; j++) {
            if (this.videos[j].thumb != false && this.videos[j].genres[0] == this.genres[i]) {
                thumbnail = this.videos[j].thumb.src;
                break;
            }
        }


        htmlStr += "<li>" + ((thumbnail != null)?"<div class='thumb' style='background-image:url(" + thumbnail + ");'></div>":'') + this.genres[i] + "</li>";

        thumbnail = null;
    }

    return htmlStr;
}; 

musicPlaylistObj.prototype.drawArtists = function coreMusicPlaylistObjDrawArtists() {
    for (var i = 0, counter = 0, htmlStr = "", genreMatch = false, ilen = this.artists.length; i < ilen; i++) {
        genreMatch = false;

        for (var j = 0, jlen = this.artists[i].genres.length; j < jlen; j++)
            if (this.artists[i].genres[j] == this.genres[this.chosenGenre]) {
                genreMatch = true;
                break;
            }

        if (genreMatch || this.chosenGenre === null) {
            //  if(  this.artists[i].thumb == false )
            var artistName = this.artists[i].name.replace(/_/gi, " ");
            if (artistName.length > 29) {
                artistName = artistName.substring(0, 29).replace(/\w+$/, '...').replace("....", "...");
            }

            htmlStr += "<li><div class='thumb'" + ((this.artists[i].thumb == false) ? " style='background-image:url(" + this.artists[i].thumb.src + ");'" : "") + "></div><p class='artist'>" + this.artists[i].name + "</p></li>";

            counter++;
        }
        if (counter >= 50) {
            this.curItemCount = i + 1;
            break;
        }
    }

    // count the total # of artists and total # for each genre
    for (var i = 0, genreMatch = false, ilen = this.artists.length; i < ilen; i++) {
        genreMatch = false;

        for (var j = 0, jlen = this.artists[i].genres.length; j < jlen; j++) {
            if (this.artists[i].genres[j] == this.genres[this.chosenGenre]) {
                genreMatch = true;
                break;
            }
        }

        if (genreMatch || this.chosenGenre === null) {
            this.artistsCount++;
        }
    }

    return (htmlStr);
}; 


musicPlaylistObj.prototype.addArtists = function coreMusicPlaylistObjAddArtists() {
    var which = this.mainSlidingBox.currentMenu,
        listCount = 0,
        htmlStr = this.mainSlidingBox.getCurrentlyScrolling().html();

    //  Count item in current list
    this.mainSlidingBox.getCurrentlyScrolling().find("li").each(function() {
        listCount++;
    });

    if (which !== 2 || listCount >= this.artistsCount) // only add items to artists list
        return;

    for(var i = this.curItemCount, counter = 0, genreMatch = false; i < this.artists.length; i++)
    {
        genreMatch = false;

        for(var j = 0; j < this.artists[i].genres.length; j++)
            if(this.artists[i].genres[j] == this.genres[this.chosenGenre])
            {
                genreMatch = true;
                break;
            }

        if(genreMatch || this.chosenGenre === null)
        {
        	var artistName = this.artists[i].name.replace(/_/gi," ");

            //  if(  this.artists[i].thumb == false )
        	if (artistName.length > 29) {
        		artistName = artistName
        			.substring(0, 29)
        			.replace(/\w+$/, '...')
        			.replace("....", "...");
        	}
			
            if(  this.artists[i].thumb == false ){
                htmlStr += "<li><div class='thumb' ></div><p class='artist'>"+this.artists[i].name+"</p></li>";
            } else {
               htmlStr += "<li><div class='thumb' style='background-image:url("+this.artists[i].thumb.src+");'></div><p class='artist'>"+this.artists[i].name+"</p></li>";
            }

            counter++;  
        }

        if (counter >= 50) {
            this.curItemCount = i + 1;
            break;
        }

    }

    this.mainSlidingBox.getCurrentlyScrolling().html(htmlStr);
    this.mainSlidingBox.updateScrollButtons();

};


musicPlaylistObj.prototype.drawVideos = function coreMusicPlaylistObjDrawVideos() {
    var len = this.videos.length;
    
    for (var i=0,counter=0,htmlStr="";i<len;i++)
    {
        if (this.videos[i].artist != this.chosenArtist && this.chosenArtist != null)
            continue;

        htmlStr += (counter%2==0) ? "<li>" : "<li class='grey'>";
             if (this.videos[i].thumb == false)
                   htmlStr += "<div class='thumb' ></div>";
             else
                   htmlStr += "<div class='thumb' style='background-image:url("+this.videos[i].thumb.src+");'></div>";     
            
            htmlStr += "<p><span class='artist'>"+this.videos[i].artist+"</span><br/><span class='title'>"+this.videos[i].title+"</span></p>";
            htmlStr += "<input type='hidden' class='itemId' value='"+this.videos[i].id+"' />";
            htmlStr += "<a class='"+((this.chosenVideos.indexOf(this.videos[i].id) >= 0) ? "subtract" : "add")+"'></a>";
        htmlStr += "</li>";

        counter++;

        //  Only show 20 of the latest items
        if (this.chosenArtist == null && counter > 19) break;
    }

    return htmlStr;
};

musicPlaylistObj.prototype.introListClicked = function coreMusicPlaylistObjIntroListClicked(e) {
    if(Math.abs(this.mouseDownPos - e.pageY) > 10)
        return;

    switch($(e.target).html())
    {
        case IDS_LANGUAGE["allGenres"]:
            this.updateMainList(1);
            break;
        case IDS_LANGUAGE["allArtists"]:
            this.drawAllArtists();
            break;
        case IDS_LANGUAGE["newVideos"]:
            this.showLatestVideos();
            break;
        default:
            break;
    }
};

musicPlaylistObj.prototype.genreListClicked = function coreMusicPlaylistObjGenreListClicked(e) {
    var $target = this.getEventTarget(e, "li");

    if(!$target)
        return;

    if(Math.abs(this.mouseDownPos - e.pageY) > 10)
        return;

    this.chosenGenre = $target.data("item");

    this.updateMainList(2);
};

musicPlaylistObj.prototype.artistListClicked = function coreMusicPlaylistObjArtistListClicked(e) {
    var $target = this.getEventTarget(e, "li");

    if(!$target)
        return;

    if(Math.abs(this.mouseDownPos - e.pageY) > 10)
        return;

    this.chosenArtist = $target.find("p.artist").html();

    this.updateMainList(3);

   if(!this.$mainVideoContainer.is(".expanded"))
              this.unHideMyPlaylist();
};

musicPlaylistObj.prototype.addVideo = function coreMusicPlaylistObjAddVideo(e) {
    listChanged = true;
    this.chosenVideos.push($(e.target.parentNode).find(".itemId").val());
    
    var currentlyScrolling = this.mySlidingBox.getCurrentlyScrolling();
    var itemHeight = currentlyScrolling.find("li").height() + 2;    //  Add two for border width.
    this.drawMyList(-1 * (parseInt(currentlyScrolling.css("top")) - this.mySlidingBox.$container.height()) < parseInt(currentlyScrolling.height() + itemHeight));
    
    $(e.target).removeClass("add").addClass("subtract");

    if (this.$mainVideoContainer.is(".expanded"))
        this.unHideMyPlaylist();
};

musicPlaylistObj.prototype.removeVideo = function coreMusicPlaylistObjRemoveVideo(e) {
    listChanged = true;
    var itemId = $(e.target.parentNode).find(".itemId").val();

    var i = this.chosenVideos.indexOf(itemId);
    if (i >= 0) {
    	this.chosenVideos.splice(i, 1);
    	this.drawMyList(false);
    }
    
    this.$mainVideoContainer.find('.itemId[value="'+itemId+'"]').siblings("a").removeClass("subtract").addClass("add");
};

//
//  Called in .show() - draw existing list or "No videos" if empty.
//
musicPlaylistObj.prototype.initMyList = function coreMusicPlaylistObjInitMyList() {
    //  Set currentMenu to which (JQuery reference to current slidingBox menu)
    var currentMenu = this.mySlidingBox.setCurrentMenu(0);

    //  Fill my video list
//    var currentlyScrolling = this.mySlidingBox.getCurrentlyScrolling();
    this.drawMyList(false);

    //  Scroll current list to top
    this.mainSlidingBox.scrollToTop(currentMenu);

    //  Slide to current list
    this.mySlidingBox.slideTo(currentMenu);
};

musicPlaylistObj.prototype.drawMyList = function coreMusicPlaylistObjDrawMyList(scrollToBottom) {
    //  Set currentMenu to which (JQuery reference to current slidingBox menu)
    var currentMenu = this.mySlidingBox.setCurrentMenu(0);

    var htmlStr = '',
        i = 0,
        j = 0;
    if(this.chosenVideos.length == 0) {
        htmlStr = IDS_LANGUAGE["noVideo"];
    } else {
        for ( i=0; i<this.chosenVideos.length; i++ ) {
            for ( j=0; j<this.videos.length; j++ ) {
                if (this.chosenVideos[i] != this.videos[j].id) {
                    continue;
                }

                htmlStr += (i%2==0) ? "<li>" : "<li class='grey'>";
                  //  htmlStr += (!this.videos[j].thumb) ? "<img class='thumb' />" : "<img class='thumb' src='"+this.videos[j].thumb.src+"' />";
                    htmlStr +="<img class='thumb' />";             
                    htmlStr += "<p><span class='artist'>"+this.videos[j].artist+"</span><br/><span class='title'>"+this.videos[j].title+"</span></p>";
                    htmlStr += "<input type='hidden' class='itemId' value='"+this.videos[j].id+"' />";
                    htmlStr += "<input type='hidden' class='itemIndex' value='"+i+"' />";
                    htmlStr += "<a class='subtract'></a>";
                htmlStr += "</li>";
            }
        }
    }

    currentMenu.html(htmlStr);

    currentMenu.height("auto");

    //  If this menu is shorter than the parent, grow it to fill the parent (for usability).
    if(currentMenu.height() < currentMenu.parent().height())
        currentMenu.css("min-height", currentMenu.parent().height()+"px");

    //  Update scroll buttons based on list contents
    this.mySlidingBox.updateScrollButtons();

    //  Scroll to bottom of the list if adding an item
    if(scrollToBottom)
        this.mySlidingBox.scrollToBottom();

    //  Update main list title
    this.updateMyListTitle(this.chosenVideos.length);
};

musicPlaylistObj.prototype.updateMainListTitle = function coreMusicPlaylistObjUpdateMainListTitle(which, counter) {
	var headerHtml =
        (which == 0) ? '<span id="customplaylistWelcomeString">' + IDS_LANGUAGE["customplaylistString"] + '</span>':
        (which == 1) ? '<span id="customplaylistAllGenresString">' + IDS_LANGUAGE["allGenres"] + '</span>' +"<span class='itemCount'>("+counter+")</span>" :
        (which == 2) ? this.chosenGenre === null ? '<span id="customplaylistAllArtistsString">' + IDS_LANGUAGE["allArtists"] + '</span>'  : this.genres[this.chosenGenre]+" - "+ '<span id = "customplaylistArtistStringString">' + IDS_LANGUAGE["ArtistString"] + '</span>' + "<span class='itemCount'>("+counter+")</span>" :
        (which == 3) ? this.chosenArtist === null ? '<span id = "customplaylistLatestVideoStringString">' + IDS_LANGUAGE["latestVideoString"]+ '</span>' +"<span class='itemCount'>("+counter+")</span>" : this.chosenArtist+" - "+ '<span id = "customplaylistVideoString">' + IDS_LANGUAGE["VideoString"] + '</span>' +" <span class='itemCount'>("+counter+")</span>"
        :   '<span id = "customplaylistVideoString">' + IDS_LANGUAGE["VideoString"] + '</span>' +" <span class='itemCount'>("+counter+")</span>"
    ;

    this.$mainVideoHeader.html(headerHtml);

	this.$mainVideoHeader.show();
};

musicPlaylistObj.prototype.updateMyListTitle = function coreMusicPlaylistObjUpdateMyListTitle(counter) {
    var count = ((counter) ? counter : 0);
    this.$myListHeader.html(("<strong class='itemListLabel'>" + IDS_LANGUAGE.customMusicVideoPlaylist + "</strong><span class='itemCount'>(" + count + ")</span>"));
    if (parseInt(count) > 0) {
        this.$watchNowButton.removeClass('disabled');
    } else {
        this.$watchNowButton.addClass('disabled');
    }
};

musicPlaylistObj.prototype.savePlaylist = function coreMusicPlaylistObjSavePlaylist(displayModal) {
	if (!user.userIsLoggedIn)
    	return;
    
	var me = this;
    
    if(listChanged == true){
        if ('undefined' == typeof displayModal)
    		displayModal = true;
        
        if (displayModal) showModal(IDS_LANGUAGE["savingPlaylistString"], true);

        // Use MR's faster playlist indexing functions
        // to add/remove items from the playlist.
        userCustomPlaylist.empty();
        
        userCustomPlaylist.setTitle($("#customTitle").html());
        
        userCustomPlaylist.shuffle = me.shuffle;

        for (var i=0, ilen=me.chosenVideos.length; i<ilen; i++) {
            for (var j=0, jlen=me.videos.length; j<jlen; j++) {
                if (parseInt(me.chosenVideos[i]) == parseInt(me.videos[j].id)) {
                    userCustomPlaylist.add({
                        "id"        :   me.videos[j].id,
                        "artist"    :   me.videos[j].artist,
                        "title"     :   me.videos[j].title,
                        "type"      :   me.videos[j].type,
                        "location"  :   me.videos[j].location
                    });
                    break;
                }
            }
        }
  } 
   return me;
};

musicPlaylistObj.prototype.showModal = function coreMusicPlaylistObjShowModal(modalStr, callback) {
    //  Callback to be called when we are finished.
    if(callback)
        this.callback = callback;

    this.$modalPopUp.find("#contents").removeClass();

    switch(modalStr) {
        case "LogInRequired":
        	this.$modalPopUp.find("#contents").addClass("loginReqModal");
            this.$modalPopUp.find("#contents").html(this.drawLoginRequiredModal());
            this.attachLoginRequiredModalEvents();
            break;
        case "New/Edit":
        	this.$modalPopUp.find("#contents").addClass("newEditPlaylistModal");
            this.$modalPopUp.find("#contents").html(this.drawNewEditModal());
            this.attachNewEditModalEvents();
            break;
        case "Intro":
        	this.$modalPopUp.find("#contents").addClass("introModal");
            this.$modalPopUp.find("#contents").html(this.drawIntroModal());
            this.attachIntroModalEvents();
            break;
        case "AddVideosBeforeWatching":
        	this.$modalPopUp.find("#contents").addClass("addVideosBeforeWatchingModal");
            this.$modalPopUp.find("#contents").html(this.drawAddVideosBeforeWatchingModal());
            this.attachAddVideosBeforeWatchingModalEvents();
            break;
        case "savePrompt":
        	this.$modalPopUp.find("#contents").addClass("savePromptModal");
            this.$modalPopUp.find("#contents").html(this.drawSavePromptModal());
            this.attachSavePromptModalEvents();
            break;
        case "SavingPlaylist":
            this.$modalPopUp.find("#contents").addClass("savingModal");
            this.$modalPopUp.find("#contents").html(this.drawSavingPlaylistModal());
            break;
        default:
            return;
            break;
    }

    this.$modalPopUp.show();
};

musicPlaylistObj.prototype.hideModal = function coreMusicPlaylistObjHideModal() {
    this.$modalPopUp.hide();
};

musicPlaylistObj.prototype.drawLoginRequiredModal = function coreMusicPlaylistObjDrawLoginRequiredModal() {
    var returnStr = "" +
    IDS_LANGUAGE["createPlaylistString"] +
    IDS_LANGUAGE["PlaylistMsg"] +
    "<button id='loginButton'>"+IDS_LANGUAGE["login/regString"]+"</button>";
    return(returnStr);
};

musicPlaylistObj.prototype.attachLoginRequiredModalEvents = function coreMusicPlaylistObjAttachLoginRequiredModalEvents() {
    var me = this;
    var $container = this.$modalPopUp.find("#contents");

    if (!configObj.isInstalled() && !machineObj.getMachineDemoNetwork()){
    	$container.find("#loginButton").live("click."+this.name, function() { 
        	showModal(IDS_LANGUAGE.installer["notInstalledFeature"], 5000);
        });
    }
    else {
    	$container.find("#loginButton").live("click."+this.name, function() { 
        	viewManager.nextView = viewManager.activeObject.name; 
        	viewManager.show("login"); 
        });
    }
};

musicPlaylistObj.prototype.drawNewEditModal = function coreMusicPlaylistObjDrawNewEditModal() {
    var returnStr = "" +
    IDS_LANGUAGE["updatePlaylistString"] +
    IDS_LANGUAGE["view/editMsg"] +
    "<button id='editExistingListButton'>"+IDS_LANGUAGE["view/editList"]+"</button>" +
    "<button id='createNewListButton'>"+IDS_LANGUAGE["createString"]+"<br/><span style='font-size:18px;'>"+IDS_LANGUAGE["erase'sExistingPlaylist"]+"</span></button>";
    return(returnStr);
};

musicPlaylistObj.prototype.attachNewEditModalEvents = function coreMusicPlaylistObjAttachNewEditModalEvents() {
    var _this = this;
    var $container = this.$modalPopUp.find("#contents");
    $container.find("#editExistingListButton").live("click."+this.name, function() { _this.unHideMyPlaylist(); _this.hideModal();  });
    $container.find("#createNewListButton").live("click."+this.name, function() { _this.resetMyList(); });
};

musicPlaylistObj.prototype.drawIntroModal = function coreMusicPlaylistObjDrawIntroModal() {
    var returnStr = "" +
    IDS_LANGUAGE["createCustomPlaylist"] +
    IDS_LANGUAGE["personalizePlaylistMsg"] +
    "<button id='getStartedButton'>"+IDS_LANGUAGE["getStartString"]+"</button>";
    return(returnStr);
};

musicPlaylistObj.prototype.attachIntroModalEvents = function coreMusicPlaylistObjAttachIntroModalEvents() {
    var _this = this;
    var $container = this.$modalPopUp.find("#contents");
    $container.find("#getStartedButton").live("click."+this.name, function() { _this.beginNewList(); });
};

musicPlaylistObj.prototype.drawAddVideosBeforeWatchingModal = function coreMusicPlaylistObjDrawAddVideosBeforeWatchingModal() {
    var returnStr = "" +
    IDS_LANGUAGE["addVideosString"] +
    IDS_LANGUAGE["addVideoBeforeWatch"] +
    "<button id='okayButton'>"+IDS_LANGUAGE["okayString"]+"</button>";
    return(returnStr);
};

musicPlaylistObj.prototype.attachAddVideosBeforeWatchingModalEvents = function coreMusicPlaylistObjAttachAddVideosBeforeWatchingModalEvents() {
    var _this = this;
    var $container = this.$modalPopUp.find("#contents");
    $container.find("#okayButton").live("click."+this.name, function() { _this.hideModal(); });
};

musicPlaylistObj.prototype.drawSavingPlaylistModal = function coreMusicPlaylistObjDrawSavingPlaylistModal() {
    var returnStr = "" +
    IDS_LANGUAGE["savingPlaylistString"] +
    IDS_LANGUAGE["oneMoment"];
    return(returnStr);
};

musicPlaylistObj.prototype.drawSavePromptModal = function coreMusicPlaylistObjDrawSavePromptModal() {
    var returnStr = "" +
    "<h1>"+IDS_LANGUAGE["saveChanges"]+"</h1>" +
    IDS_LANGUAGE["wouldliketosaveChanges"] +
    "<button id='dontSaveChangesButton'>"+IDS_LANGUAGE["don'tsaveChanges"]+"</button>" +
    "<button id='saveChangesButton'>"+IDS_LANGUAGE["saveChanges"]+"</button>";
    return(returnStr);
};

musicPlaylistObj.prototype.attachSavePromptModalEvents = function coreMusicPlaylistObjAttachSavePromptModalEvents() {
    var _this = this;
    var $container = this.$modalPopUp.find("#contents");
    $container.find("#dontSaveChangesButton").live("click."+this.name, function() { _this.callback(); });
    $container.find("#saveChangesButton").live("click."+this.name, function() { _this.savePlaylist(); setTimeout(function() { _this.callback(); }, 1000); });
};

musicPlaylistObj.prototype.hasChanged = function coreMusicPlaylistObjHasChanged() {
    //  If titles don't match

    

    if(userCustomPlaylist.title != $("#customTitle").html()) {
        this.listChanged = true;
        return true;
    }

    //  If shuffle settings don't match
    if(userCustomPlaylist.shuffle != this.shuffle) {
        this.listChanged = true;
        return true;
    }

    //  If video lists don't match
    if(this.chosenVideos.length != userCustomPlaylist.items.length) {
        this.listChanged = true;
        return true;
    }else{
        this.listChanged = false;
    }

    for(var i=0;i<this.chosenVideos.length;i++) {
        if(parseInt(this.chosenVideos[i]) != parseInt(userCustomPlaylist.items[i].id)) {
            this.listChanged = true;
            return true;
        }
    }

    return false;
};
musicPlaylistObj.prototype.checkForChanges = function coreMusicPlaylistObjCheckForChanges(callback) {
    //  If titles don't match, prompt to save.
    //  If shuffle settings don't match, prompt to save.
    //  If video lists don't match, prompt to save.
	if (this.hasChanged()) {
		this.show("savePrompt", callback);
		return;
	}

    //  If there are no changes, run callback().    
    callback();
};

musicPlaylistObj.prototype.removeEvents = function coreMusicPlaylistObjRemoveEvents() {
     this.mainSlidingBox.$levels[3].find(".add").die();
     this.mySlidingBox.$levels[0].find(".subtract").die();
};

musicPlaylistObj.prototype.proceedToHide = function coreMusicPlaylistObjProceedToHide() {
    viewManager.show('mainMenu');
};

musicPlaylistObj.prototype.hide = function coreMusicPlaylistObjHide() {
    $("*").unbind("." + this.name).die("." + this.name);

    $("#controlBar #mainMenuBtn")
        .unbind("mousedown")
        .bind("mousedown", function () { viewManager.show('mainMenu'); });

    $("#controlBar #mainEndWorkoutBtn")
        .unbind("mousedown")
        .bind("mousedown", function () { workout.endWorkout(); });

    this.hideAds();
    
    if (this.hasChanged()) {
        this.savePlaylist();
    }
};
musicPlaylistObj.prototype.unHideMyPlaylist = function coreMusicPlaylistObjUnHideMyPlaylist() {
    //  Shrink the main container
    if(doTransitions)
        this.$mainVideoContainer.removeClass("expanded").animate({width : "749px"}, 500);
    else
        this.$mainVideoContainer.removeClass("expanded").css("width","749px");

    //  Adjust the left coordinate of the main container
    var position = this.mainSlidingBox.getCurrentlyScrolling().css("left");
    this.mainSlidingBox.$container.css("left", (-1*parseInt(position))+"px");    
};

//  Sort by name
function sortByName(a,b) {   
    return ((a.name < b.name) ? -1 : ((a.name > b.name) ? 1 : 0));
}

//  Sort by create time
function sortByCreateTime(a,b) {   
    return((a.createdTimestamp > b.createdTimestamp) ? -1 : ((a.createdTimestamp < b.createdTimestamp) ? 1 : 0));
}

musicPlaylistObj.prototype.keyboardInput = function coreMusicPlaylistObjKeyboardInput(e) {
	var me = this;
	var newValue = me.$playlistInputTitle.val();
   
    if(e.target.parentNode.id.indexOf('id_email_kbd_row') != -1
    		|| e.target.id == "spaceString"
    		|| e.target.id == "clearString") {
        var inputField = me.$playlistInputTitle;
	    var targetHTML = jQuery.trim(e.target.innerHTML.toLowerCase());
  
	    if(targetHTML == IDS_LANGUAGE["Enter"].toLowerCase()) {
	        return false; }
	        
	    if(targetHTML == IDS_LANGUAGE["space"].toLowerCase())
	    { 
	    	inputField.attr("value", newValue+" ");
	    }
	    else if(targetHTML == IDS_LANGUAGE["shift"].toLowerCase())
	    {
	    	this.shiftOn = true;
	    	$('#shiftKey').css('color','green');
	    }
	    else if(targetHTML == IDS_LANGUAGE["Clear"].toLowerCase())
	    {
	    	inputField.val("");
	    }
        else if(targetHTML == "←")
        {
    	inputField.attr("value",inputField.attr("value").substring(0, inputField.attr("value").length-1));
        } 
	    else
	    { 
	    	if(this.shiftOn == true)
	    	{
	    	    if(newValue.length < 20)
     	    	    inputField.attr("value", newValue+targetHTML.toUpperCase());
	    	 this.shiftOn = false;
	    	 $('#shiftKey').css('color','white');
	    	} 
	    	else
	    	{
	    	     if(newValue.length < 20)
	    	          inputField.attr("value", newValue+targetHTML);
	    	}	    	 
	    }
   }
};

musicPlaylistObj.prototype.toggleKeyboardTray = function coreMusicPlaylistObjToggleKeyboardTray() {
    $("#playListKeyboardTray").toggleClass("visible");
};

musicPlaylistObj.prototype.htmlInternationalString = function coreMusicPlaylistObjHtmlInternationalString() {
    $("#mainVideoContainer #customplaylistWelcomeString").html(IDS_LANGUAGE["customplaylistString"]);
    $("#mainVideoContainer #customplaylistAllGenresString").html(IDS_LANGUAGE["allGenres"]);
    $("#mainVideoContainer #customplaylistAllArtistsString").html(IDS_LANGUAGE["allArtists"]);
    $("#mainVideoContainer #customplaylistArtistStringString").html(IDS_LANGUAGE["ArtistString"]);
    $("#mainVideoContainer #customplaylistLatestVideoStringString").html(IDS_LANGUAGE["latestVideoString"]);
    $("#mainVideoContainer #customplaylistVideoString").html(IDS_LANGUAGE["VideoString"]);

    $("ul#level0 li h2").html(IDS_LANGUAGE['selectToBegin']);
    $("ul#level0 li button:nth-child(2)").html(IDS_LANGUAGE['allGenres']);
    $("ul#level0 li button:nth-child(3)").html(IDS_LANGUAGE['allArtists']);
    $("ul#level0 li button:nth-child(4)").html(IDS_LANGUAGE['newVideos']);

    $('#loginToContinueString').html(IDS_LANGUAGE["logintoContinue"]);
    $('#backString').html(IDS_LANGUAGE["Back"]);
    $('#nextString').html(IDS_LANGUAGE["Next"]);
    $('#titleString').html(IDS_LANGUAGE["titleString"]);
    $('#customTitle').html(IDS_LANGUAGE["customMusicVideoPlaylist"]);
    $('#editString').html(IDS_LANGUAGE["editString"]);
    $('#shuffelString').html(IDS_LANGUAGE["shuffelString"]);
    $('#watchnowString').html(IDS_LANGUAGE["watchNowButton"]);
    $('#saveButton > span').html(IDS_LANGUAGE["save&exitString"]);
    $('#clearString').html(IDS_LANGUAGE["Clear"]);
    $('#spaceString').html(IDS_LANGUAGE["space"]);
    $('#enterString').html(IDS_LANGUAGE["Enter"]);
    $('#shiftKey').html(IDS_LANGUAGE["shift"]);

    if (this.drawLoginRequiredModal) {
        $("#modalPopUp").find(".loginReqModal").html(this.drawLoginRequiredModal());
    }
    if (this.drawNewEditModal) {
        $("#modalPopUp").find(".newEditPlaylistModal").html(this.drawNewEditModal());
    }
    if (this.drawIntroModal) {
        $("#modalPopUp").find(".introModal").html(this.drawIntroModal());
    }
    if (this.drawAddVideosBeforeWatchingModal) {
        $("#modalPopUp").find(".addVideosBeforeWatchingModal").html(this.drawAddVideosBeforeWatchingModal());
    }
    if (this.drawSavePromptModal) {
        $("#modalPopUp").find(".savePromptModal").html(this.drawSavePromptModal());
    }
    if (this.updateMyListTitle && this.chosenVideos) {
        this.updateMyListTitle(this.chosenVideos.length);
    }
};

/*-------------------------------------------------------------------*/
//@ sourceURL=views/playlist/js.js
