/*=====================================================================
	Registration Script (CORE) | views/registration/js.js
=====================================================================*/

// registerObj used for the various account creation pages.

function registerObj(name, type, vm) {
	var me = this;
	
	me.name = name;
	me.type = type;
	me.vm = vm;
	
	me.currentPage = 0;
	
	me.previousSelection = null;
	me.currentSelection = null;
	//this.currentlySelectedId = null;
	
	me.userId = null;
	me.userEmailAddress = null;
    me.userPasscodeCheck = null;
	me.userPasscode = null;
	me.userDOB = null;
	me.userGender = null;
	me.userWeight = null;
    me.preferredUnit = null;
	me.deny = 0;	
	me.oem = null;
	
	//tracks date index
	me.dobIndex = 0;

	// slidingBox
	me.hidePagination = null;
	me.pagesToDisplay = ["page0","page1","page2","page3","page4","page5","page6"];
	me.$cueContainer = null;

	// When view is passed from registration, make sure that you don't get stuck in a loop.
	me.slidingBoxExit = function coreLoginObjSlidingBoxExit() { me.vm.showPreviousView(); };
    
	// HTML
	me.$mainContainer = null;
	me.$backButton = null;
	me.$nextButton = null;
	me.$viewPort = null;
	me.$slidingViewPort = null;
	me.$cueContainer = null;
	me.$registrationContainer = null;
    
	//DOB
	this.dobStrDirection = "ltr";
	this.biDirectionalDOB = false;
    //Predefined (Basic) Date Structures
    me.imperialDateStructure = {
    		0:'month',
    		1:'day',
    		2:'year'
    };
    me.metricDateStructure = {
    		0:'day',
    		1:'month',
    		2:'year'
    };
    me.dobDateStructure = me.imperialDateStructure;
    me.registrationRespDelay = 2000;
}

//  Inherit basic view functions init(), show(), hide()
registerObj.prototype = new app;

//  Whenever this page is shown: reset logged in user values, initialize this page's HTML, and show the first login page.
registerObj.prototype.show = function coreRegisterObjShow() {
	var me = this, returnValue = false;
	try {
		// Hook-in functions to run first.
		me.preShowHook();
		// Find slidingBox DOM elements.
		me.bindSlideElements();
		// Create the menuData object.
		me.setupMenuData();
		// Build the sliding box and attach to the view-port.
		me.buildSlideBox();
		// Find DOM elements.
		me.bindHTMLElements();
		// Bind mouse-down and click events.
		me.attachEvents();
		// Fill text place-holders using the IDS_LANGUAGE object.
		me.htmlInternationalString();
		// Hook-in functions to run last.

		me.postShowHook();
		returnValue = true;
	} catch (e) {
		popError(e);
		returnValue = false;
	}
	return(returnValue);
};

registerObj.prototype.preShowHook = function coreRegisterObjPreShowHook() {};

registerObj.prototype.postShowHook = function coreRegisterObjPostShowHook() {
	var me = this;

	$('#modalOkButton').bind("click.", function () { $('#errorModal').hide(); });
	me.arrangeDOBIPFields();
};

registerObj.prototype.resetUserValues = function resetUserValues() {
    this.userId = null;
    this.userEmailAddress = null;
    this.userPasscode = null;
    this.userDOB = null;
    this.userGender = null;
    this.userWeight = null;
    userId = null;
    userDOB = null;
    userGender = null;
    userEmailAddress = null;
    fbUserId = null;
};

registerObj.prototype.setupMenuData = function coreRegisterObjBuildMenuData() {
	var me = this;

	me.menuData = {
		levels : [ {
			drawItem : function coreRegisterObjDrawItem(data) {
				// Remove pages to memory before popping back into page.
				var $el = $("#" + data), $saved = $el.clone(true);
				$el.remove();
				return($saved.html());
			},
			attachEvents : function loginPageAttachEvents(obj, $container) {
				$container.find("li").each(function() {
					// even though this is an empty function it's still needed for init.
				});
			},
			scrollNext : function loginPageScrollNext(e) {
				me.next(e);
			}
		} ],
		items : me.pagesToDisplay
	};
};

registerObj.prototype.buildSlideBox = function coreRegisterObjBuildSlideBox() {
	var me = this,
		$vp = (0 < this.$slidingViewPort.length) ? this.$slidingViewPort : this.$viewPort;

	me.slidingBox = new slidingBox(
		me.menuData,
		$vp,
		me.$registrationContainer,
		me.$backButton,
		me.$nextButton,
		1,
		200,
		me.slidingBoxExit,
		me.$cueContainer,
		me.hidePagination
	);
};

registerObj.prototype.next = function(e)
{
	_this = this;
	this.menuData.levels[0].scrollNext = function(e) {  };
    switch(this.slidingBox.currentPage)
    {
        case 0:
			this.validateUserId();
         	break;
        case 1:
			this.validateEmailAddress();
			break;
        case 2:
            this.validateUserPasscode();
			break; 
        case 3:
        	this.validateGenderDOB();
			break;
        case 4:
        	this.validateWeight();
			break;
        case 5:
	        this.submitRegistration();
			break;
        default:
			break;
    }
	 setTimeout( function() { _this.menuData.levels[0].scrollNext = function(e) { _this.next(e); };  } , 3000);
};

registerObj.prototype.displayWelcomeMsg = function coreRegisterObjDisplayWelcomeMsg() {
	this.$backButton.hide();
	this.$nextButton.hide();
	
	// reset playlist
    userCustomPlaylist.reset();  
	
	var $element = $("#registrationSuccess");
	var msg = IDS_LANGUAGE.register["congratulation"] + String(this.userId) + ", <br/>" + IDS_LANGUAGE.register["youareLoggedin"];
	
	(!$element || 0 >= $element.length) ? showModal(msg, 3000) : $element.html(msg);
	
	setTimeout(function() { 
		viewManager.showNextView();
	}, this.registrationRespDelay);
};

registerObj.prototype.bindSlideElements = function coreRegisterObjBindSlideElements() {
	var me = this;

	me.$mainContainer = $("#registrationView");
	me.$registrationContainer = $("#registrationContainer");
	me.$backButton    = $("#backButton");
	me.$nextButton    = $("#nextButton");
	me.$viewPort      = $("#viewPort");
	me.$slidingViewPort = $("#slidingViewPort");
};

//
//  Grab HTML elements for future reference
//
registerObj.prototype.bindHTMLElements = function coreRegisterObjBindHTMLElements() {
	var me = this;

    if (me.bindSlideElements) me.bindSlideElements();

	me.$genderContainer = $('#genderContainer');
	me.$imageCategoryContainer = $('#imageCategoryContainer');
	me.$femaleButton = $('#femaleButton');
	me.$maleButton = $('#maleButton');

	me.$newUserId = $('#newUserId');
	me.$newUserPasscode = $('#newUserPasscode');
	me.$newWeight = $('#newWeight');
	me.$newEmail = $('#newEmail');

	me.$dayField = $("#day");
	me.$monthField = $("#month");
	me.$yearField = $("#year");

    //TOS binds
	me.$termsOfServiceIcon = $('#termsOfServiceIcon');
	me.$TOSLink = $('#TOSLink');
	me.$termsCloseButton = $('button#tgDenyCondition');
	me.$termsAcceptButton = $('button#tgAcceptCondition');
	me.$conditionsScrollDown = $('#conditions_next');
};

registerObj.prototype.attachEvents = function coreRegisterObjAttachEvents() {
    var me = this;
    me.resetNewUserPasscode();
    me.resetUserValues();

    //  Keyboard functionality TODO: Scope problem
    me.$mainContainer.find("#userIDKeyboard").bind("mousedown."+me.name,function(e){me.keyboardInput(e);});    
    me.$mainContainer.find("#userPasscodeKeyboard").bind("mousedown."+me.name,function(e){me.userPasscodeKeyboardInput(e);});    
    me.$mainContainer.find("#weightKeyboard").bind("mousedown."+me.name, function(e){me.weightKeyboardInput(e);});    
    me.$mainContainer.find("#id_email_keyboard").bind("mousedown."+me.name, function(e){me.emailKeyboardInput(e);});
    me.$mainContainer.find("#DOBKeyboard").bind("mousedown."+me.name, function(e){me.DOBKeyboardInput(e);});
 
    me.$genderContainer.bind('mousedown', function(e){me.selectGender(e) });
    //me.$genderContainerH3.bind('mousedown', function(e){me.selectGender(e) });
    
    //TOS
    me.$termsOfServiceIcon.bind("mousedown", function(e) {showModal(IDS_LANGUAGE.register["mustAccept"], 3000);});
    me.$termsCloseButton.bind("mousedown", function(e) {showModal(IDS_LANGUAGE.register["mustAccept"], 3000);});
    me.$termsAcceptButton.bind("mousedown", function(e) {$('#conditionsTerms').hide();$('#nextButton').show();$('#backButton').show();});
    me.$TOSLink.bind("mousedown", function(e) {$('#conditionsTerms').show();$('#nextButton').hide();$('#backButton').hide();});

    $(window).bind('resize.' + me.name, function trueRegisterObjResize(e) {
        if (viewManager && viewManager.activeObject && viewManager.activeObject.slidingBox) {
            viewManager.activeObject.slidingBox.resetBoxWidth(e);
        }
    });
};

registerObj.prototype.keyboardInput = function coreRegisterObjKeyboardInput(e) {
	var me = this, newValue = '';
    if (e.target.parentNode.id == "userIDKeyboard") {
        var $inputField = me.$newUserId;
        var inputVal = $inputField.attr("value");
        var targetHTML = jQuery.trim(e.target.innerHTML);
        var maxLength = parseInt($inputField.attr("maxlength"));
            maxLength = ((maxLength > 0) ? ((maxLength < 15) ? maxLength : 14) : 14);

        if (targetHTML == "enter" || targetHTML == "OK" || $(e.target).hasClass("enter")) {
        	this.validateUserId();
        } else {
        	newValue = ((targetHTML == "←") ? inputVal.substring(0, inputVal.length-1) : ((inputVal.length < maxLength) ? inputVal + targetHTML : inputVal));
        }

        $inputField.attr("value", newValue);
    }
};

registerObj.prototype.resetNewUserPasscode = function () {
    var me = this;
    // reset input field and vars
    $('#newUserPasscode').attr("value", "");
    me.userPasscodeCheck = null; 
    me.userPasscode = null;
    //reset input label
    $("#userPasscodeLabel").html(IDS_LANGUAGE.register["newPasscodeLabel"]);
};

registerObj.prototype.userPasscodeKeyboardInput = function(e) {
	var me = this;

	if ( e.target.parentNode.id == "userPasscodeKeyboard" ) {
        var b = me.$newUserPasscode,
            a = $.trim(e.target.innerHTML);
        // if user clicks delete button, reset userpasscode
        if ('✔' == a || 'enter' == a || a == 'OK' || $(e.target).hasClass("enter") || $(e.target).hasClass("clearButton")){
            me.validateUserPasscode();
        } else if (a == '←'){
            me.resetNewUserPasscode();
            showModal(IDS_LANGUAGE.register["createPasscodeReset"] + " " + IDS_LANGUAGE.register["passcodeEmpty"], 3000);
        } else {
            b.attr("value", (b.attr("value").length < 4) ? b.attr("value") + a : b.attr("value"));
            if (b.attr("value").length === 4 && me.userPasscode === null) {
                me.validateUserPasscode();
            } 
        }
	}
};

// XID Validate userPasscode
registerObj.prototype.validateUserPasscode = function(){
    var me = this,
    passcode = this.$newUserPasscode.val();

    if (passcode === "") {
        (me.userPasscodeCheck !== null) ? showModal(IDS_LANGUAGE.register["createPasscodeConfirm"] + " " + IDS_LANGUAGE.register["passcodeMustBe4Digits"], 2000) :  showModal(IDS_LANGUAGE.register["passcodeEmpty"], 3000);
        return;
    } else if (passcode.length < 4) {
        (me.userPasscodeCheck !== null) ? showModal(IDS_LANGUAGE.register["createPasscodeConfirm"] + " " +IDS_LANGUAGE.register["passcodeMustBe4Digits"], 3000) : showModal(IDS_LANGUAGE.register["passcodeEmpty"], 3000);
        return;
    } else { // if (passcode.length === 4) 
        if (me.userPasscodeCheck === null) {  // if first input
            // set newUserPasscode to 4 digits entered
            me.userPasscodeCheck = passcode;
            // modal requesting confirmation passcode
            showModal(IDS_LANGUAGE.register["createPasscodeConfirm"], 2000);
            // pause before clearing input field 
            setTimeout(function() {
                // clear input field
                $('#newUserPasscode').attr("value", "");
                // change label to "Confirm Passcode"
                $("#userPasscodeLabel").html(IDS_LANGUAGE.register["confirmPasscodeLabel"]);
            }, 2000);
            return;
        } else if (me.userPasscodeCheck !== null && me.userPasscodeCheck.length === 4) { //if 2nd input
            if (me.userPasscodeCheck !== passcode){
                showModal(IDS_LANGUAGE.register["createPasscodeFail"], 3000);
                setTimeout(function() {
                    me.resetNewUserPasscode();
                }, 2000);
                return;
            } else if (me.userPasscode !== null){
                me.slidingBox.scrollNext();
            } else {
                me.userPasscode = passcode;
                showModal(IDS_LANGUAGE.register["createPasscodeSuccess"], 3000); 
                setTimeout(function() {
                    me.slidingBox.scrollNext();
                }, 2000);
                return;
            } 
        }
    }
};

registerObj.prototype.weightKeyboardInput = function(e)
{
	var me = this;
    if (e.target.parentNode.id == "weightKeyboard") {
        var inputField = me.$newWeight;
        var targetHTML = jQuery.trim(e.target.innerHTML);
        
        if (targetHTML == "enter" || targetHTML == "OK" || $(e.target).hasClass("enter"))
        	this.validateWeight();
        else
        {
        	var newValue = (targetHTML == "←")
                ?   inputField.attr("value").substring(0, inputField.attr("value").length-1)
                :   (inputField.attr("value").length < 3)
                    ?   inputField.attr("value") + targetHTML
                    :   inputField.attr("value");
        }
        inputField.attr("value", newValue);
    }
}
registerObj.prototype.DOBKeyboardInput = function(e)
{	
	if(e.target.parentNode.id == "DOBKeyboard"){
		
		var me = this;
		var str = jQuery.trim(e.target.innerHTML);
		var inputFieldStatus = new Array();
		var month = me.$monthField.val();
		var day = me.$dayField.val();
		var year = me.$yearField.val();
		
		//Starts update fields
		var updateMonthField = function (){
			var updatedMonth;
			
			/*possibilities:-
			1.	month/day/year
			2.	day/month/year
			3.	year/month/day
			*/
			
			if (str == '←'){
				if(inputFieldStatus['month']=="filled")
					updatedMonth = month.substr(0, month.length-1) + "-";
				else if(inputFieldStatus['month']=="partial")
					updatedMonth = "--";	
				else
					return;//month field erase logical error
			}// Erase entry for Month ends
			
			else{
				if(inputFieldStatus['month']=="empty" && parseInt(str,10)<=01)
					updatedMonth = str + "-";
				
				else if((inputFieldStatus['month']=="partial") && (parseInt((parseInt(month,10)+str),10) <= 12) && (parseInt((parseInt(month,10)+str),10) >= 1)){
					if(inputFieldStatus['day']=="filled" && parseInt(day,10) >= 30){
						if(parseInt(day,10)==30 && parseInt((parseInt(month,10)+str),10) != 02){
							updatedMonth = parseInt(month,10) + str;
						}//if for day==30
						
						else if(parseInt(day,10)==31){
							
							switch(parseInt(month,10)+str){
							case "01":
							case "03":
							case "05":
							case "07":
							case "08":
							case "10":
							case "12":{
								updatedMonth = parseInt(month,10) + str;
								break;
							}
							
							default:
								break;
							}//switch for month ends here
							
						}//else if for day==31
						
					}//if day==filled && >=30
					else if((inputFieldStatus['day']=="filled" && parseInt(day,10) <= 29)){
						updatedMonth = parseInt(month,10) + str;
					}//else if for day<=29 or =="empty"
					
					else if((inputFieldStatus['day']=="empty")){
						updatedMonth = parseInt(month,10) + str;
					}
					
				}//else if month partial ends here
						
				else{
					return;
				}
					
				
			}//Digit entry for months ends
			
			if(updatedMonth)
			me.$monthField.val(updatedMonth);
				
		};//function updateMonthField() Ends
		
		var updateDayField = function (){
			var updateDay;
			
			if(str == '←'){
				if(inputFieldStatus['day']=="filled")
					updateDay = day.substr(0, day.length-1) + "-";
				else if(inputFieldStatus['day']=="partial")
					updateDay = "--";	
				else
					return;//month field erase logical error
			}//Erase entry for day ends
			
			else{
				// 1. Year and Month are filled (y/m/d)
				// 2. Month is filled && Year is empty (m/d/y)
				// 3. Month && Year are empty (d/m/y)
				
				// 1. Check for Month
				if(inputFieldStatus['month']=="filled"){
					switch(month){
	            	case "01":
	            	case "03":
	            	case "05":
	            	case "07":
	            	case "08":
	            	case "10":
	            	case "12":{
	            		if(inputFieldStatus['day']=="empty" && parseInt(str,10)<=3)
	    					updateDay = str + "-";
	    				else if(inputFieldStatus['day']=="partial" && parseInt((parseInt(day,10)+str),10)<=31 && parseInt((parseInt(day,10)+str),10)>=01)
	    					updateDay = parseInt(day,10) + str;
	    				else
	    					return;
	            	}
	            	break;
	            	
	            	case "04":
	            	case "06":
	            	case "09":
	            	case "11":{
	            		if(inputFieldStatus['day']=="empty" && parseInt(str,10)<=3)
	    					updateDay = str + "-";
	    				else if(inputFieldStatus['day']=="partial" && parseInt((parseInt(day,10)+str),10)<=30 && parseInt((parseInt(day,10)+str),10)>=01)
	    					updateDay = parseInt(day,10) + str;
	    				else
	    					return;
	            	}
	            	break;
	            	
	            	case "02":{
	            		if(inputFieldStatus['day']=="empty" && parseInt(str,10)<=2)
	    					updateDay = str + "-";
	            		
	            		else if(inputFieldStatus['year']=="filled" && inputFieldStatus['day']=="partial" && parseInt((parseInt(day,10)+str),10)<=29 && parseInt((parseInt(day,10)+str),10)>=01){
	            			if(parseInt(year,10)%4 == 0){//might be leap year
	            				if(parseInt((parseInt(year,10)/100),10)*100 == parseInt(year,10)){//still need to test for mod 400
	            					
	            					if(parseInt(year,10)%400 == 0){//this is a leap year
	            						//if(parseInt(parseInt(day)+str)<=29)
	    	            					updateDay = parseInt(day,10) + str;
	            					}
	            					
	            					else{//this is not a leap year
	            						if(parseInt((parseInt(day,10)+str),10)<=28)
	    	            					updateDay = parseInt(day,10) + str;
	    	            				else
	    	            					break;
	            					}

	            				}// check for 1900 & 2000 ends here
	            				
	            				else{//this is def a leap year.
	            					//if(parseInt(parseInt(day)+str)<=29)
	            					updateDay = parseInt(day,10) + str;
	            				}
	            				
	            			}//check for year%4 ends here
	            			
	            			else{//not a leap year
	            				if(parseInt((parseInt(day,10)+str),10)<=28)
	            					updateDay = parseInt(day,10) + str;
	            				else
	            					break;
	            			}
	            			
	            		}// end of year filled
	            		
	            		else if(inputFieldStatus['year']=="empty" && inputFieldStatus['day']=="partial" && parseInt((parseInt(day,10)+str),10)<=29){
	            			updateDay = parseInt(day,10) + str;	
	            		}//end of year empty
	            		
	            	}//End of case:02 Feb month
	            	
	            	default:
	            		break;
					}//End of switch
			        
	            	
				}//end of month filled
				
				else if(inputFieldStatus['month']=="empty"){
					if(inputFieldStatus['day']=="empty" && parseInt(str,10)<=3)
    					updateDay = str + "-";
    				else if(inputFieldStatus['day']=="partial" && parseInt((parseInt(day,10)+str),10)<=31 && parseInt((parseInt(day,10)+str),10)>=01)
    					updateDay = parseInt(day,10) + str;
    				else
    					return;
					
				}// end if month empty
			}// Digit entry for day ends
			
			if(updateDay)
			me.$dayField.val(updateDay);
			
		};//function updateDayField() ends
		
		var updateYearField = function (){
			var updateYear;
			
			if(str == '←'){
				if(inputFieldStatus['year']=="filled")
					updateYear = year.substr(0, year.length-1) + "-";
				else if(inputFieldStatus['year']=="partial"){
					//updateDay = "--";	
					if(parseInt(year,10)>99)//for 3 digits (100 and more)
						updateYear = year.substr(0, parseInt(year,10).toString().length-1) + "--";
					else if(parseInt(year,10)>9 && parseInt(year,10)<=99)// for 2 digits (10-99)
						updateYear = year.substr(0, parseInt(year,10).toString().length-1) + "---";
					else if(parseInt(year,10)<9)// for 2 digits (10-99)
						updateYear = "----";
					else return;
				}
					
				else
					return;//month field erase logical error
			}// Erase entry for year ends
			
			else{//for entry of digits
				// We allow ages 10 and up.
				// 1. Year and Month are filled (y/m/d)
				// 2. Month is filled && Year is empty (m/d/y)
				// 3. Month && Year are empty (d/m/y)
				
				var currentYear = (new Date()).getYear() + 1900;    // Returns years since 1900.
		        var latestYear = currentYear - 10;
		        var earliestYear = 1900;
		       
		        if (inputFieldStatus['year']=="empty" && str >= parseInt((parseInt(earliestYear,10)/1000),10) && str <= parseInt((parseInt(latestYear,10)/1000),10))
		        	updateYear = str + '---';
		        else if (inputFieldStatus['year']=="partial" && parseInt((parseInt(year,10)+str),10) >= parseInt((parseInt(earliestYear,10)/100),10) && parseInt((parseInt(year,10)+str),10) <= parseInt((parseInt(latestYear,10)/100),10))
		        		updateYear = parseInt(year,10)+str + '--';
		        else if (inputFieldStatus['year']=="partial" && parseInt((parseInt(year,10)+str),10) >= parseInt((parseInt(earliestYear,10)/10),10) && parseInt((parseInt(year,10)+str),10) <= parseInt((parseInt(latestYear,10)/10),10))
		        		updateYear = parseInt(year,10)+str + '-';
		        else if (inputFieldStatus['year']=="partial" && parseInt((parseInt(year,10)+str),10) >= earliestYear && parseInt((parseInt(year,10)+str),10) <= latestYear){
		        	if(inputFieldStatus['month']=="filled" && inputFieldStatus['day']=="filled" && parseInt(month,10)==02 && parseInt(day,10)==29){
		        		var completeYear = parseInt((parseInt(year,10)+str),10);
		        		if(completeYear%4 == 0){//might be leap year
		        			if(parseInt((completeYear/100),10)*100 == completeYear){//still need to test for mod 400
            					if(completeYear%400 == 0){//this is a leap year
            						updateYear = parseInt(year,10)+str;
            					}
            					else{//this is not a leap year
            						return;
            					}
		        			}// check for 1900 & 2000 ends here
            				else{//this is def a leap year.
            					//if(parseInt(parseInt(day)+str)<=29)
            					updateYear = parseInt(year,10)+str;
            				}
            			}//check for year%4 ends here
		        		else
		        			return;//this is not a leapyear
		        	}//check for month=02 and day=29 ends here
		        	else
		        		updateYear = parseInt(year,10)+str;// month!=02 or day!=29
		        }//else if check for last string ends here
		        		//updateYear = parseInt(year,10)+str;
		        else
		        	return;
			}//Digits entry for year ends
			
			if(updateYear)
				me.$yearField.val(updateYear);
		};//function updateYearField() Ends
		
		//Ends update fields
		
		var assignStatus = function (inputField, name){//This function assigns status to Month,Day, and Year Fields
			if (inputField.val()=="--" || inputField.val()=="----")
				inputFieldStatus[name]='empty';
			else if ((inputField.val()).indexOf("-") == -1)
				inputFieldStatus[name]='filled';
			else if ((inputField.val()).indexOf("-") >= 0)
				inputFieldStatus[name]='partial';
		};//function assignStatus Ends

		var updateFields = function (field){
			//This Function will trigger the right function
			// which will eventually update a particular input field
			switch(field){
			case "day":
				updateDayField();
				break;
			case "month":
				updateMonthField();
				break;
			case "year":
				updateYearField();
				break;
			default:
				break;
			}
		};
		
		var init = function (){
			for (i in me.dobDateStructure){
				//This loop is used to assign status (empty/partial/filled)
				// to Month/Day/Year Fields
				switch(me.dobDateStructure[i]){
					case "month":
						assignStatus(me.$monthField, "month");
						break;
					case "day":
						assignStatus(me.$dayField, "day");
						break;
					case "year":
						assignStatus(me.$yearField, "year");
						break;
					default:
						break;
				}	
			}// Initial status assignment using loop ends
			
			if (str == '←'){
				for(var i=2; i>=0; i--){//###
					if(inputFieldStatus[me.dobDateStructure[i]] != "empty"){
						updateFields(me.dobDateStructure[i]);
						break;
					}	
				}
			}//check for delete entry ends
			
			else if(str == "✔" || str == "OK" || $(e.target).hasClass("enter") || $(e.target).hasClass("clearButton"))
		    {   
		  			me.next(e);
		    }//check for next page ends here
			
			else{
				for(var i=0; i<=2; i++){
					if(inputFieldStatus[me.dobDateStructure[i]] != "filled"){
						updateFields(me.dobDateStructure[i]);
						break;
					}	
				}
			}//check for digits entered ends here
		};//update fields ends here
		
		init();
		
	}// DOB keyboard if ends
	
}

registerObj.prototype.arrangeDOBIPFields = function()
{	
	//this function is only needed to move input fields (Month, Day, and Year)
	//around (ltr or rtl) based on language, locale = "ar" !="ar"
	//mainly used in Lifefitness
	//TODO: Handover this to css.
	var me = this;
			if($("#DOB")){
			var floatPositions = ["left","none","right"];
			if(me.biDirectionalDOB){
				switch(athleteObj.get_locale()){
				case "ar":
					this.dobStrDirection = "rtl";
					break;
				default:
					this.dobStrDirection = "ltr";
					break;
				}
				switch(this.dobStrDirection){
					case "rtl":
						floatPositions.reverse();
						break;
					default:
						break;
				}
			}
			for (var i=0; i<=2; i++){
				switch(me.dobDateStructure[i]){
				case "month":
					$("#month").css('float',floatPositions[i]);
					break;
				case "day":
					$("#day").css('float',floatPositions[i]);
					break;
				case "year":
					$("#year").css('float',floatPositions[i]);
					break;
				default:
					break;
				}
			}
		}
};

registerObj.prototype.emailKeyboardInput = function(e)
{
	var me = this;
    if(e.target.parentNode.id.indexOf('id_email_kbd_row') != -1)
   {
        var inputField = me.$newEmail;
	    var targetHTML = jQuery.trim(e.target.innerHTML.toLowerCase());
        
        var newValue = (targetHTML == "clear")
            ?   ""
            :   (jQuery.trim(e.target.innerHTML) == "←")
                ?   inputField.attr("value").substring(0, inputField.attr("value").length-1)
                :   (inputField.attr("value").length < 500) ? inputField.attr("value") + targetHTML : inputField.attr("value");

        inputField.attr("value", newValue);
   }
}

registerObj.prototype.setText = function()
{
    this.$backButton.html("BACK");
    this.$nextButton.html("NEXT");
}

registerObj.prototype.resetValues = function()
{
    user.id = null;
    user.email = null;
    user.password = null;
    user.gender = null;
    user.dob = null;
    
    this.currentPage = 0;
}

//Changed this object in CORE so that everything changes styles with the addClass instead of hardcoded CSS. Technogym and Strtrac do not currently support this. 03/2013
registerObj.prototype.selectGender = function(e) {
    var me = this;
    var target = e.target.id.replace("String", "Button");
    switch (target) {
        case "maleButton":
            this.userGender = 'M';
            $('#' + target).addClass('selected');
            me.$femaleButton.removeClass('selected');
            break;
        case "femaleButton":
            this.userGender = 'F';
            $('#' + target).addClass('selected');
            me.$maleButton.removeClass('selected');
            break;
    }
};
registerObj.prototype.selectPasswordImg = function coreRegisterObjSelectPassword(e) {
	// Select your password image from the grid.
    if (!(e.target.nodeName.toLowerCase() == "div")) { e.target = e.target.firstElementChild; }
    if (this.previousSelection != null) { $(this.previousSelection).removeClass('selected'); }
    this.currentSelection = e.target.parentNode;
    $(this.currentSelection).addClass('selected');
    this.currentlySelectedId = e.target.id.split('_');
    $('#selectedImage > div').removeClass().addClass(e.target.id);
    // this is where the icon id is stored. 
    this.selectedPasswordImage = e.target.id;
    this.previousSelection = e.target.parentNode;
    return;
};
registerObj.prototype.validateUserId = function(e){

	var _this = this;
	
	var error = "";
	var $userId = _this.$newUserId;
	
	var userName = $userId.val();
	
		
	if(configObj.getMid() == "UNKNOWN"){
	 	showModal(IDS_LANGUAGE.register["midunkownTryagain"],3000);
		return;
	}
	
	if (userName.trim() == "") {
		showModal(IDS_LANGUAGE.login["EnterUserIdUpTo14"], 3000);
		return;
	}
	
	else {
	
		var urlString = (machineObj.getMachineDemoNetwork()) ? "../demo/n5ipicture.xml" : machineObj.getServerLocation() + "n5ipicture.jsp?id=" + userName.trim() + "&mid=" + configObj.getMid();

		var successCallback = function(data, textStatus, errorThrown){	
			// Need to check for passcode
			if (data.getElementsByTagName("response")[0].getAttribute("pic") == "NOT FOUND") {
				_this.userId =  String(userName);
				_this.$newUserId.val(userName);
				_this.slidingBox.scrollNext();
			} else { 
				showModal(IDS_LANGUAGE.register["userIdtaken"], 3000);
			}
		};
		
		var errorCallback = function(data, textStatus, errorThrown){
			var errorString = (textStatus == "timeout") ? IDS_LANGUAGE.login["NetworkCommunicationError"] : IDS_LANGUAGE.register["regproblemString"] + "<br />" +IDS_LANGUAGE.register["anotherTime"] ;
			
			_this.userId = null;
			showModal(errorString, 3000);
		};
		
		dirtyHarry(urlString, successCallback, errorCallback);
	}
	
};

registerObj.prototype.validateEmailAddress = function (e)
{
	    var _this = this;
		var filler = false;

	if(filler)
		filler = false;
		
    else
    {
        var userEmail = document.getElementById('newEmail');
        var emailregex3 = /^(([a-z0-9_\+-]+((\.[a-z0-9_\+-]+)*)*)@([a-z0-9-]+((\.[a-z0-9-]+)*)*\.([a-z]{2,4})))$/i;

        //  If user email address is properly formatted 
        if(emailregex3.test(userEmail.value.trim()))
        {
            // Test the entry against the server
            var urlString = machineObj.getServerLocation() + "n5ipicture.jsp?email=" + encodeURIComponent(userEmail.value.trim()) + "&mid=" + configObj.getMid();

			    if (machineObj.getMachineDemoNetwork()) {
					_this.userEmailAddress = userEmail.value.trim();
					_this.slidingBox.scrollNext();
					return;
				}
				
				else {
					var successCallback = function(responseXML){
					
						if (responseXML.getElementsByTagName('response')[0].getAttribute("pic") == "NOT FOUND") {
							_this.userEmailAddress = userEmail.value.trim();
							_this.slidingBox.scrollNext();
						}
						else 
					showModal(IDS_LANGUAGE.register["emailhastaken"], 3000);
					};
					
					var errorCallback = function(data, textStatus, errorThrown){
						var errorString = (textStatus == "timeout") ? IDS_LANGUAGE.login["NetworkCommunicationError"] : IDS_LANGUAGE.register["regproblemString"] + "<br />" +IDS_LANGUAGE.register["anotherTime"];
						
						_this.userEmailAddress = null;
						
						showModal(errorString, 3000);
					};
					dirtyHarry(urlString, successCallback, errorCallback);
				}
        }
        else
           showModal(IDS_LANGUAGE.register["pleasenterValidemail"],3000);
    }
	

}

registerObj.prototype.validateGenderDOB = function (e)
{	
	var me = this;
	
	var dobEntered = me.$yearField.val().charAt(3);
	var errorMsg = "";
	
	if(this.userGender == null)
		errorMsg = IDS_LANGUAGE.register["enterGender"];
	
	if(dobEntered == "-")
		errorMsg += IDS_LANGUAGE.register["enterDOB"];
	else
		me.reviewpageRearrangeDOB();
	
	if(errorMsg != "")
	    showModal(errorMsg, 3000);
	else
		this.slidingBox.scrollNext();	
}

registerObj.prototype.reviewpageRearrangeDOB = function()
{	
	var me = this;
	var getDOBFieldValues = function(fieldName){
		var fieldVal;
		
		switch(fieldName){
		case "month":
			fieldVal = me.$monthField.val();
			break;
		case "day":
			fieldVal = me.$dayField.val();
			break;
		case "year":
			fieldVal = me.$yearField.val();
			break;
		default:
			break;
		}
		return fieldVal;
	};
	
	if(me.biDirectionalDOB && me.dobStrDirection == "rtl"){
		me.userDOB = getDOBFieldValues(me.dobDateStructure[2]) +'/'+ getDOBFieldValues(me.dobDateStructure[1]) +'/'+ getDOBFieldValues(me.dobDateStructure[0]);
	}
	else{
		me.userDOB = getDOBFieldValues(me.dobDateStructure[0]) +'/'+ getDOBFieldValues(me.dobDateStructure[1]) +'/'+ getDOBFieldValues(me.dobDateStructure[2]);
	}
};

// Validate the user's weight entry.
registerObj.prototype.validateWeight = function coreRegisterObjValidateWeight(e) {
	var me = this,  weightValue = me.$newWeight.val();

	if ( "" == weightValue ) {
		showModal(IDS_LANGUAGE.register["enterWeight"], 3000);
		me.userWeight = null;
	} else if ( 65 >= parseInt(weightValue, 10)) {
		showModal(IDS_LANGUAGE.register["enterMinimumWeight"], 3000);
		me.userWeight = null;
	} else {
		me.userWeight = (weightValue * 1);
	}

	if (null != me.userWeight && "" != me.userWeight){
		me.slidingBox.scrollNext();
		if ( "function" == typeof me.incrementSteps )
			me.incrementSteps();
		me.populateRegistration();
	}
};

registerObj.prototype.populateRegistration = function ()
{  
	
    $('#summaryUserId').html(String(this.userId));
    $('#summaryEmail').html(this.userEmailAddress);
    $('#summaryWeight').html(this.userWeight);
    $('#summaryDOB').html(this.userDOB);
	var gender = (this.userGender == 'M') ?   IDS_LANGUAGE["Male"] : IDS_LANGUAGE["Female"]; 
	
    $('#summaryGender').html(gender);
}

registerObj.prototype.loginUser = function coreRegisterObjLoginUser() {

    //  Set shared user values
    athleteObj.set_age(this.age);
    athleteObj.set_is_male(this.userGender);
    athleteObj.set_weight(this.userWeight);
    athleteObj.set_punit(this.preferredUnit);
    athleteObj.set_user_id(String(this.userId));
    athleteObj.set_is_aboard(1);

    var ageStr = "age=" + this.age;
    var weightStr = "weight=" + this.userWeight;
    var punitStr = "punit=" + this.preferredUnit;
    var idStr = "id=" + String(this.userId);
    var uuidStr = "uuid=" + athleteObj.get_session_id();

    var nameStr;
    if (this.userName != null) {
        nameStr = "name=" + this.userName;
    } else {
        nameStr = "name=" + String(this.userId);
    }

    var genderStr = "gender=";
    if (this.userGender == "M") {
        genderStr += 'm';
    } else {
        genderStr += 'f';
    }

    // If there's a nextView, tell OEM not to hide us upon signing in.
    var argList = ["op=user", "resp=netpulse", ageStr, weightStr, genderStr, nameStr, idStr, uuidStr];
    if (viewManager.nextView) {
        argList.push("action=nohide");
    }
    if (controlObj.isInternationalEnabled()) {
        argList.push(punitStr);
    }
    nsSend(argList.join(","));
};


registerObj.prototype.submitRegistration = function coreRegisterObjSubmitRegistration() {
    try {
		var _this = this;
		var locale = $('#mainView').attr('locale');
		
		if (locale == "pl" || locale =="hu" || locale=="zhs" || locale=="ko" || locale=="fi" || locale=="ca" || locale=="ar" || locale=="eu" || locale=="en"){
			locale = "en_US";
		}else if(locale=="zht"){
			locale = "zh";
		}
		
		var preferredUnit;
		// Passing a default preferred unit to new VT registrants based on the country the machine is in. This can then be changed on the VT website on a per-user basis. 
		if (machineObj.isOutsideUS()){
			preferredUnit = "M";
		}else{
			preferredUnit = "I";
		}
				
		var urlString = (machineObj.getMachineDemoNetwork()) ? "demo/n5iregister.xml" : machineObj.getSecuredServerLocation()
			+ "n5iregister.jsp";

		
		

		if(isFb == true){
			userDOB.toString().replace(/\//g, "");
			this.userDOB = userDOB.replace(/\//g, "");
			this.userEmailAddress = userEmailAddress.toString().replace('@','%');
			this.userGender = userGender.toString();		
		}else if (isFb == false){
			this.userDOB = this.userDOB.replace(/\//g, "");
			this.userEmailAddress = encodeURIComponent(this.userEmailAddress);
		}

			var query = "?machine_id=" + configObj.getMid() + "&id=" + this.userId + "&enableMail=true" + "&email="+ this.userEmailAddress + "&passcode=" + this.userPasscode + "&DOB=" + this.userDOB + "&gender="+ this.userGender + "&weight=" + this.userWeight + "&oem_tos=9" + "&lang=" + locale + "&punit=" + preferredUnit;
		

        if (this.oem != null) {
            query += "&oem_tos=";
            query += this.oem;
        }


        var urlq = urlString + "" + query;

        var successCallback = function successCallback(responseXML) {
        	var file = "<datastore user_id='"+athleteObj.get_user_id()+"' machine_id='"+configObj.getMid()+"' type='netpulse' ><store name='fbuid' value='"+fbUserId+"' /><store name='showfbpic' value='true' /></datastore>";
		writeToFile('/netpulse/upload/datastore.xml', file);
            _this.stopWaiting = true;
            _this.registrationCallback(responseXML);
        };

        var errorCallback = function errorCallback(data, textStatus, errorThrown) {
        	var errorString = "";
        	if(textStatus == "timeout"){
				_this.stopWaiting = true;
				errorString = IDS_LANGUAGE.login["NetworkCommunicationError"];
				showModal(errorString, 3000);
        	}else{
        		_this.stopWaiting = true;
				_this.userId = null;
        		errorString = IDS_LANGUAGE.register["regproblem"] + data.responseText;
        		showModal(errorString, 3000);
        		_this.regCallBackNetworkError();
        	}
        };
        dirtyHarry(urlq, successCallback, errorCallback,null,10000,"GET","xml",false,3);
    } catch(e) { popError(e); }
};

registerObj.prototype.regCallBackNetworkError = function (){
	var _this = this;
	return _this;
}

registerObj.prototype.registrationCallback = function coreRegisterObjRegistrationCallback(responseXML)
{
    var _this = this;

    var code = responseXML.getElementsByTagName('response')[0].getAttribute("code");
	if (code != "0") {
		//  Don't set the user id to ANYTHING. Because 0 (zero) is considered a guest
		
		var desc = responseXML.getElementsByTagName('response')[0].getAttribute("desc");
		if (code == "1") {
			if ($('#conditionsTerms')) {
				$('#conditionsTerms').hide();
			}
			
			// Code == 1 indicates either "Invalid Argument(s)" or 
			// "A user with the specified login (...login...) or email address (...email...) already exists.", 
			// which can happen if a second AJAX call to n5iregister occurs before the registration is 
			// completed.  To distinguish between the two, try logging in using the same user/password
			var src = machineObj.getSecuredServerLocation() + "n5ilogin.jsp?machine_id=" + configObj.getMid() + "&id=" + _this.userId + "&pic=-1"  + "&uuid=" + athleteObj.get_session_id() + "&passcode=" + this.userPasscode;
			
			dirtyHarry(src, function(data) {
				// Still need to check the response code and make sure login was successful
				if (data.getElementsByTagName('response')[0].getAttribute("code") == "0") {
					writeLog("info", "Login successful! NPUUID: " + athleteObj.get_session_id());

					// TODO: I imagine it would be a good idea to switch over to using this
					// user object exclusively rather than the window object to store user data
					user.userIsLoggedIn = true;
					user.id = String(_this.userId);
					user.email = _this.userEmailAddress;
					user.gender = _this.userGender;
					user.dob = _this.userDOB;
					user.weight = _this.userWeight;
					user.age = String(calculateAge(convertRegistrationDOBtoDate(_this.userDOB)));
					
					user.firstName = null;
					user.lastName = null;
					
					window.userIsLoggedIn = true;
					window.regUser = String(_this.userId);
					window.regEmail = _this.userEmailAddress;
					window.regGender = _this.userGender;
					window.regWeight = _this.userWeight;
					_this.age = String(calculateAge(convertRegistrationDOBtoDate(_this.userDOB)));
					
					window.regFirst = user.firstName;
					window.regLast = user.lastName;
				
					// save the users data to shared memory
					athleteObj.set_user_id(window.regUser);
					athleteObj.set_age(calculateAge(convertRegistrationDOBtoDate(_this.userDOB)));
					
					
					athleteObj.set_weight(window.regWeight);
					athleteObj.set_punit(_this.preferredUnit);
					athleteObj.set_is_male(('M' == window.regGender) ? SZ_DEFINE_MALE : SZ_DEFINE_FEMALE);
				
					athleteObj.set_email(_this.userEmailAddress);
				
					secondaryID_daysRemaining = null;
			    	// if the user needs to connect a secondary id number, set flag to prompt for it.
					$(data).find("membershipId").each(function(){
						user.secondaryDaysRemaining = $(this).attr("days");
						secondaryID_daysRemaining = $(this).attr("days");
					});
				    _this.displayWelcomeMsg();
					_this.slidingBox.scrollNext();
					adMan.setUpTargetedAds(responseXML); 
					setTimeout(function(){ 
						_this.loginUser(); }
					, _this.registrationRespDelay);
				} else {
					showModal(IDS_LANGUAGE.register["registrationProblemError"] + code + ": " + desc, 3000);
				}
			}, function() {
				showModal(IDS_LANGUAGE.register["registrationProblemError"] + code + ": " + desc, 3000);
			});
		}
		else 
			showModal(IDS_LANGUAGE.register["registrationProblemError"] + code + ": " + desc, 3000);
	
	//viewManager.show('registration');
	}
	else {
		console.log(this.userId+this.userEmailAddress+this.userGender+this.userPasscode+this.userDOB+this.userWeight);
		//  Pass registration values to global logged-in-user values
		user.userIsLoggedIn = true;
		user.id = String(this.userId);
		user.email = this.userEmailAddress;
		user.gender = this.userGender;
        user.passcode = this.userPasscode;
		user.dob = this.userDOB;
		user.weight = this.userWeight;
		user.age = String(calculateAge(convertRegistrationDOBtoDate(this.userDOB)));
		
		
		user.firstName = null;
		user.lastName = null;
		
		window.userIsLoggedIn = true;
		window.regUser = String(this.userId);
		window.regEmail = this.userEmailAddress;
        window.regPasscode = this.userPasscode;
		window.regGender = this.userGender;
		window.regDOB = this.userDOB;
		window.regWeight = this.userWeight;
		this.age = String(calculateAge(convertRegistrationDOBtoDate(this.userDOB)));
		
		
		window.regFirst = user.firstName;
		window.regLast = user.lastName;
		
		// save the users data to shared memory
		athleteObj.set_user_id(window.regUser);
		athleteObj.set_age(this.age);
		athleteObj.set_weight(window.regWeight);
		athleteObj.set_is_male(('M' == window.regGender) ? SZ_DEFINE_MALE : SZ_DEFINE_FEMALE);
		
		athleteObj.set_email(this.userEmailAddress);
		
		secondaryID_daysRemaining = null;
		//  if the user needs to connect a secondary id number, set flag to prompt for it.
		$(responseXML).find("membershipId").each(function(){
			user.secondaryDaysRemaining = $(this).attr("days");
			secondaryID_daysRemaining = $(this).attr("days");
		});
		window.userIsLoggedIn = true;
		this.displayWelcomeMsg();
		this.slidingBox.scrollNext();
		var _this = this;
		adMan.setUpTargetedAds(responseXML); 
		setTimeout(function(){
			_this.loginUser();
		}, _this.registrationRespDelay);
	}

    try {
        // this will not work in IE (Who cares about IE!)
        var xmlString = (new XMLSerializer()).serializeToString(responseXML);
        nsSendXML(xmlString);
    }
    catch (e) {
        popError(e);
    }
};

//Non-Scroll Bar TOS
registerObj.prototype.termsOfService = function(scrolls) {
    var me = this;
    var imageWidthUp = 200; var imageWidthDown = -200;
    var scrollDowns = 0; var scrollUps = 0;

    me.$mainContainer.find('#conditions_prev').bind("mousedown." +me.name, function() {
        
        if (scrollDowns < scrolls) {
            scrollDowns++;
            scrollUps--;
            $('#privacycontent').animate({marginTop:"-="+imageWidthUp}, 500);
        }else{
            return;
        }    
    });
    me.$mainContainer.find('#conditions_next').bind("mousedown." +me.name, function() {

        if(scrollUps == 0){
            return;
        }  
                   
        if (scrollUps < scrolls) {
            scrollUps++;
            scrollDowns--;
            $('#privacycontent').animate({marginTop:"-="+imageWidthDown}, 500);
        }else{
            return;
        }

    });
    me.$termsOfServiceIcon.bind("mousedown", function(e) {
		showModal(IDS_LANGUAGE.register["mustAccept"], 3000);      
    });
    me.$termsCloseButton.bind("mousedown", function(e) {
        showModal(IDS_LANGUAGE.register["mustAccept"], 3000);
    });
    me.$termsAcceptButton.bind("mousedown", function(e) {
        $('#conditionsTerms').hide();
        $('#nextButton').show();
        $('#backButton').show();
    });
    me.$TOSLink.bind("mousedown", function(e) {
        $('#conditionsTerms').show();
        $('#nextButton').hide();
        $('#backButton').hide();
    });
}


function convertRegistrationDOBtoDate(strRegDOB)
{
    if (8 == strRegDOB.length)
    {
        return strRegDOB[0]+strRegDOB[1]+"-"+strRegDOB[2]+strRegDOB[3]+"-"+strRegDOB[4]+strRegDOB[5]+strRegDOB[6]+strRegDOB[7];
    }
}

// assumes MM/DD/YYYY or MM-DD-YYYY (actually, any delimeter will suffice)
function calculateAge(strInput)
{
    var age;

    // Past date info
    var pday = parseInt(strInput.substring(3, 5));
    var pmonth = parseInt(strInput.substring(0, 2)) - 1;
    var pyear = parseInt(strInput.substring(6,10));

    // Today info
    today = new Date();
    year = today.getFullYear() ;
    month = today.getMonth();
    day = today.getDate();

    if ( month < pmonth )
    {
        age = year - pyear - 1;
    }
    else if ( month > pmonth )
    {
        age = year - pyear;
    }
    else if ( month == pmonth )
    {
        if ( day < pday )
        {
            age = year - pyear - 1;
        }
        else if ( day > pday )
        {
            age = year - pyear;
        }
        else if ( day == pday )
        {
            age = year - pyear;
        }
    }

    return(age);
}

registerObj.prototype.showXIDlogo = function(idslanguage){

	var showLogo = "<span><img src='images/xid_logo.png' /></span>";

	return sprintf(idslanguage, showLogo);
}

// Show 'waiting...' pop-up message on final registration step.
registerObj.prototype.showWaitMessage = function coreRegisterObjShowWaitMessage() {
    var me = this,
        $modalMsg = $("#errorMsg"),
        pleaseWaitMsg = IDS_LANGUAGE.install.pleaseWaitMsg;
    pleaseWaitMsg = pleaseWaitMsg.replace(/\./g, "");
    showModal(pleaseWaitMsg, 3*10000);

    // Append '.' to pleaseWaitMsg.
    function pleaseWaitLoop() {
    	if (!me.stopWaiting) {
            var pleaseWaitLoopTimer = me.setInterval(function pleaseWaitLoopTimeout() {
                if (!me.stopWaiting) {
                	switch($modalMsg.html().split(".").length){
                		case 1:
                		case 4:
                			$modalMsg.html(pleaseWaitMsg + ".");
                			break;
                		case 2:
                			$modalMsg.html(pleaseWaitMsg + "..");
                			break;
                		case 3:
                			$modalMsg.html(pleaseWaitMsg + "...");
                			break;
                	}
                } else {
                    me.clearInterval(pleaseWaitLoopTimer);
                }
            }, 1000);
        } else {
            me.clearInterval(pleaseWaitLoopTimer);
        }
    }

	pleaseWaitLoop();
};

//Fill in text for this view.
registerObj.prototype.htmlInternationalString = function coreRegisterObjHtmlInternationalString() {
	var me = this;
	$('#createUserid').html(this.showXIDlogo(IDS_LANGUAGE.register["createUserid"]));
	$('#registrationmsg').html(IDS_LANGUAGE.register["enterphoneNoforRegistration"]);
	$('#userid').html(IDS_LANGUAGE.login["userId"]);
	$('#enter').html(IDS_LANGUAGE.register["enter"]);
	$('#registrationSteps2To6').html(IDS_LANGUAGE.register["registrationSteps2To6"]);
	$('#e-mail').html(IDS_LANGUAGE.register["e-mail"]);
	$('#clear').html(IDS_LANGUAGE["Clear"]);
	$('#regSteps3to6String h2').html(IDS_LANGUAGE.register["regSteps3to6Passcode"]);
    (this.userPasscodeCheck === null) ? $("#userPasscodeLabel").html(IDS_LANGUAGE.register["newPasscodeLabel"]) : $("#userPasscodeLabel").html(IDS_LANGUAGE.register["confirmPasscodeLabel"]);
	$('#regSteps4to6').html(IDS_LANGUAGE.register["regSteps4to6"]);
	$('#gender').html(IDS_LANGUAGE["Gender"]);
	$('#male').html(IDS_LANGUAGE["Male"]);
	$('#female').html(IDS_LANGUAGE["Female"]);
	$('#maleButton').html(IDS_LANGUAGE["Male"]);
	$('#femaleButton').html(IDS_LANGUAGE["Female"]);
	$('#dobLabel #DOB').html(IDS_LANGUAGE.register["DOB"]);
	$('#dobLabel #DOBString').html(IDS_LANGUAGE.register["DOB"]);
	$('#regSteps5to6').html(IDS_LANGUAGE.register["regSteps5to6"]);
	$('#weightString').html(IDS_LANGUAGE.register["weight"]); 
	$('#regSteps6to6').html(IDS_LANGUAGE.register["regSteps6to6"]);
	$('#clickBacktocorrectEnteries').html(IDS_LANGUAGE.register["clickBacktocorrectEnteries"]);
	$('#congratulationMsg').html(IDS_LANGUAGE.register["congratulationMsg"]);
	$('#Email').html(IDS_LANGUAGE.register["Email"]);
	$('#500Lbs').html(IDS_LANGUAGE.register["500Lbs"]);
	$('#passcodeString').html(IDS_LANGUAGE.register["passcodeString"] + ":");
	$('#useridString').html(this.showXIDlogo(IDS_LANGUAGE.register["useridString"]));
	$('#emailString1').html(IDS_LANGUAGE.register["emailString1"]);
	$('#genderString1').html(IDS_LANGUAGE.register["genderString1"]);
	$('#DOBString1').html(IDS_LANGUAGE.register["DOBString1"]);
	if($('#dateStructure').length){
		if(athleteObj.get_locale() == "ar" && me.dobStrDirection == "ltr"){
			$('#dateStructure').html(IDS_LANGUAGE.register[me.dobDateStructure[2]] + '/' + IDS_LANGUAGE.register[me.dobDateStructure[1]] + '/' + IDS_LANGUAGE.register[me.dobDateStructure[0]]);
		}
		else{
			$('#dateStructure').html(IDS_LANGUAGE.register[me.dobDateStructure[0]] + '/' + IDS_LANGUAGE.register[me.dobDateStructure[1]] + '/' + IDS_LANGUAGE.register[me.dobDateStructure[2]]);
		}
	}
	$('#weightString1').html(IDS_LANGUAGE.register["weightString1"]);
	$('#denyString').html(IDS_LANGUAGE.login["deny"]);
	$('#acceptString').html(IDS_LANGUAGE.login["accept"]);
	$('#privacypolicyString').html(IDS_LANGUAGE["privacypolicy"]);
	$('#privacycontent').html(IDS_LANGUAGE["privacy_content"]);
	$('#tgterms').html(IDS_LANGUAGE["TGTerms&Conditions"]);
	$('#terms_and_conditions_content').html(IDS_LANGUAGE.register["consolidatedTOS_content"]);
	$('#summaryTOS').html(IDS_LANGUAGE.register["summaryTOS"]);
	$('#TOSLink').html(IDS_LANGUAGE.register["TOSLink"]);
};


