//
//  Virtual Active View Object (core)
//
function virtualActiveObj(name, type, vm) {
	this.name = name;
	this.type = type;
	this.vm = vm;
	this.itemsPerPage = 6;
	this.volume = machineObj.getVolumeLevel();
	this.slidingExit = function slidingExit() { viewManager.show('mainMenu'); };
}

// inherit base app prototype
virtualActiveObj.prototype = new app;

// Init() - if mediaXML is null (not found), disable this page.
virtualActiveObj.prototype.init = function() {
	if (mediaXML == null)
		this.disabled = true;
};

// Show()
virtualActiveObj.prototype.show = function() {
	var me = this;

	try {
		me.getData();

		me.bindHTMLElements();
		
		me.bindSkinSpecificElements();

		me.buildLevelsArray();

		me.buildSlideBox();

		$("#videoBackground").hide();
		
		return true;

	} catch (e) { popError(e); return false; }
};

//
virtualActiveObj.prototype.sortData = function sortVaData(a, b) {
	// sort by title string ascending
	var tR = 0;
	try {
		var tA = a.title.toLowerCase(), tB = b.title.toLowerCase();
		if (tA < tB) { tR = (-1); } else if (tA > tB) { tR = 1; }
	} catch(e) {}
	return(tR);
};

//
virtualActiveObj.prototype.getData = function() {
	var me = this;

	me.data = [];
	me.data.items = mediaXML.virtualActive;

	me.data.items.sort(me.sortData);

	return (me.data);
};

//
virtualActiveObj.prototype.bindSkinSpecificElements = function() {
	//var me = this;  

};

//
virtualActiveObj.prototype.bindHTMLElements = function show() {
	var me = this;

	me.$container = $("#virtualActiveApp");
	me.$title = me.$container.find("h1");
	me.$videoContainer = me.$container.find("#videoContainer");
	me.$viewPort = me.$container.find("#viewPort");
	me.$vidBrowser = me.$container.find("#vidBrowser");
	me.$backButton = me.$container.find("#backButton");
	me.$nextButton = me.$container.find("#nextButton");
	me.$backToBrowsingButton = me.$videoContainer.find("#backToBrowsing");
	me.$nextVideoButton = me.$videoContainer.find("#nextVideo");
	me.$prevVideoButton = me.$videoContainer.find("#prevVideo");

	/* Volume Ctrl */
	me.$volUpButton = me.$container.find("#VolUpButton");
	me.$volDnButton = me.$container.find("#VolDnButton");
};

//
virtualActiveObj.prototype.buildSlideBox = function() {
	var me = this;

	me.slideBox = new slidingBox(me.data, me.$viewPort, me.$vidBrowser,
			me.$backButton, me.$nextButton, 1, 200, this.slidingExit, $("#cueContainer"));
	
};
//
// Set up levels array for slidingBox
//
virtualActiveObj.prototype.buildLevelsArray = function() {
	var me = this;

	me.data.levels = new Array();

	me.data.levels[0] = {
		drawItem : function(data) {
			me.$title.html(IDS_LANGUAGE['virtualActive']);
			return ("<div class='menu_button'><div style='background-image:url(" + data.thumbnail + ")' class='item'></div><h2>" + data.title + "</h2></div>");
		},
		attachEvents : function(slideBox, $box) {
			me.updateScrollButtonLabels(slideBox);

			$box.find("li").each(function() {
				var val = new Number($(this).find(".item_id").val());

				if (val >= 0) {
					$(this).bind("click." + me.name, function() {
						me.updateScrollButtonLabels(slideBox, true);
						var val = new Number($(this).find(".item_id").val());
						me.play();
					});
				}
			});
		},
		itemsPerPage : me.itemsPerPage,
		scrollBack : function(e) {
			me.scrollBack(e);
		},
		scrollNext : function(e) {
			me.scrollNext(e);
		}
	};

};

//
// If a video is playing when the user hits the scroll back button, stop the
// video
// and DONT scroll back.
//
virtualActiveObj.prototype.scrollBack = function(e) {
	var me = this;

	if (me.videoPlaying) {
		me.stopVideo();
		return false;
	}

	me.slideBox.scrollBack();
	me.updateScrollButtonLabels(me.slideBox);
};

//
virtualActiveObj.prototype.scrollNext = function(e) {
	var me = this;

	if (me.videoPlaying) {
		me.stopVideo();
		return false;
	}

	me.slideBox.scrollNext();
	me.updateScrollButtonLabels(me.slideBox);
};

//
virtualActiveObj.prototype.updateScrollButtonLabels = function(slideBox, playing) {
	if (playing)
		return;

	var me = this;
	var htmlStr = "";
	var $p = me.$backButton.find("p").css("opacity", "0");

	switch (slideBox.currentLevel) {
	case 0:
		htmlStr = (slideBox.currentLeft >= 0) ? "Menu" : "Back";
		break;

	case 1:
		htmlStr = (slideBox.currentLeft >= 0) ? "Channels" : "Back";
		break;

	case 2:
		htmlStr = (slideBox.currentLeft >= 0) ? slideBox.data.items[slideBox.chosenItems[0]].title : "Back";
		break;

	default:
		break;
	}
	
	setTimeout(function() {
		$p.html(htmlStr).css("opacity", "1");
	}, 150);
};

//
virtualActiveObj.prototype.playChannel = function() {
	var me = this;
	me.slideBox.chosenItems[1] = 0;

	me.play();
};

//
virtualActiveObj.prototype.play = function() {
	var me = this;

	stopVideo(this.$videoContainer);
	var currentShow = me.slideBox.data.items[me.slideBox.chosenItems[0]];
	var currentEpisode = currentShow;

	me.$title.html("On Demand Video - " + currentShow.title + " - " + currentEpisode.title);

	var playerString = '<object type="video/mpeg" id="videoPlayer" data="'
			+ currentEpisode.location
			+ '"><param name="allowScriptAccess" value="always"><param name="wmode" value="transparent"><param name="data_type" value="ondemand"></object>';

	if (me.playTimeout)
		clearTimeout(me.playTimeout);

	me.playTimeout = setTimeout(function() {
		playVideo(me.$videoContainer, playerString);
	}, 500);

	me.videoPlaying = true;
	$("header").removeClass().addClass("playingVideo");
};

//
virtualActiveObj.prototype.mediaError = function() {
	this.nextVideo();
};

//
virtualActiveObj.prototype.stopVideo = function() {
	var me = this;

	me.killVideo();

	if (me.errorTimeout)
		clearTimeout(me.errorTimeout);
};

virtualActiveObj.prototype.killVideo = function() {
	if (!this.$videoContainer)
		return;

	stopVideo(this.$videoContainer);

	this.videoPlaying = false;
};

virtualActiveObj.prototype.nextVideo = function() {
	var me = this;
	var currentShow = me.slideBox.data.items[me.slideBox.chosenItems[0]];

	me.slideBox.chosenItems[0] = (parseInt(me.slideBox.chosenItems[0]) >= me.slideBox.data.items.length - 1) ? 0 : parseInt(me.slideBox.chosenItems[0]) + 1;
	me.play();
};


virtualActiveObj.prototype.prevVideo = function() {
	var me = this;
	var currentShow = me.slideBox.data.items[me.slideBox.chosenItems[0]];

	me.slideBox.chosenItems[0] = (parseInt(me.slideBox.chosenItems[0]) == 0) ? me.slideBox.data.items.length - 1 : parseInt(me.slideBox.chosenItems[0]) - 1;
	me.play();
};

virtualActiveObj.prototype.hide = function() {
	this.stopVideo();
	$("#videoBackground").hide();
};
