/*=====================================================================
	WatchObj: VLC and TvTime Players (CORE) | views/watch/js.js
=====================================================================*/

//@match http://www.youtube.com/
//@match file:///www/netpulse/matrix7xi/index.html

function onMediaPlayerFullscreen(fullscreen) {
	if (fullscreen)
		$("#fullscreenBackground").show();
	else
		$("#fullscreenBackground").hide();
}

function watchObj(name, type, vm) {
	this.name = name;
	this.type = type;
	this.vm = vm;
	
	this.volume = machineObj.getVolumeLevel();
	this.startTime = 0;
	this.endTime = 0;
	this.videoPlaying = false;
	this.disabled = false;
	// Should we disable the back/next buttons during an ad?
	this.disableAdNavigation = false;
	
	// Initialize player to an instance of the base player class. This way, we
	// don't have to constantly check if player is null
	this.player = new player();
	
	// Since you can now add videos to your custom playlist from the watch view, we need
	// to save the previous view before going to sign in. We don't want the back button
	// to take a user to the login page.
	this.originView = null;
	this.previousView = null;
	this.listChanged = false;

    this.adRotation = new AdRotation();
}

// Persistent object to allow defining behavior before the view is shown
watchObj.target = {
	/* 
	 * Parameters for displaying content.
	 * 
	 * parentView:     String - the name of the view calling this view
	 * channel:        Array  - mediaItems to display
	 *                 OR
	 *                 String - player object to create (i.e. 'externalVideo')
	 * episode:	       integer - index of mediaItem in channel array to display
	 * loop:           boolean - enabling looping past the last or prior to first item in channel array (default: true)
	 * showTitle:      boolean - false disables the display
	 *                 OR
	 *                 function - customize the title (i.e. return channel title + episode name ...
	 * closedCaptions: // TODO: Allow client to determine? or define by the object being played (i.e. MP4 as determined by VLC)
	 * breadCrumbToHtml: function or String - generates the HTML to render the breadCrumbs.  If not specified, defaults to viewManager.breadCrumbToHtml()
	 * breadCrumbBindEvents: function - binds events to the elements in the breadCrumbs.  If not specified, defaults to viewManager.breadCrumbBindEvents()
	 */  	
};
watchObj.EXTERNAL_SOURCE = '_external_';

watchObj.settings = []; // "History" of the last target settings used indexed by parentView, allowing for 

// Inherit streamingObj
watchObj.prototype = new app;

watchObj.prototype.init = function() {
	// Set the volume default
	this.volume = ((typeof(user.volume) == 'undefined') ? machineObj.getVolumeLevel() : user.volume);
	
};

watchObj.prototype.setPlayer = function() {
	var parent = watchObj.target.parentView;
	var name = (parent && parent.name) ? parent.name : '';
	switch (name) {
	case 'tv':
		this.player = new tvtimePlayer(this);
		break;
	default:
		if ('ipod' == parent || 'ipod' == name) {
			// the ipod view can be accessed from most other views, but the parent view
			// will always be ipod. This is a hack to show the ipod view without having to
			// set watchObj.target.channel = watchObj.EXTERNAL_SOURCE
			this.player = new ipodPlayer(this);
		} else {
			this.player = new vlcPlayer(this);
		}
		break;
	}
};

watchObj.prototype.preShowHook = function coreWatchObjPreShowHook() {
	var me = this;
	return me;
};

watchObj.prototype.postShowHook = function coreWatchObjPostShowHook() {
	var me = this;
	return me;
};

// Helper function to find last playing index,
// using '.playAt' or '.saveAt'.
function findIndexByKeyValue(obj, key, value) {
    for (var i = 0, len = obj.length; i < len; i++) {
        if (obj[i][key] == value) {
            return i;
        }
    }
    return null;
}

watchObj.prototype.show = function() {
	try {
		this.preShowHook();
		
		// Hack to make sure the back button takes you to the correct view. The parentView 
		// property of the watchObj.target should be set to the view that set up the watchObj, 
		// so that's where want to go should returnToSender be called.
		var parent = watchObj.target.parentView;
		var viewName = (parent && typeof parent === "string") ? parent : parent.name;
		
		// Since we never want to return to the playlist view, just redirect to music.
		viewName = (viewName == "playlist") ? "music" : viewName;
		
		if (this.vm.isViewAvailable(viewName)) {
		    this.originView = viewName;
		}
		
		// Define player 
		this.setPlayer();
		console.log("Setting player to be " + this.player.name);

		// Shuffle the playlist if necessary
		if (watchObj.target.channel && watchObj.target.channel.shuffle) {
			this.shufflePlaylist();
		}

		this.bindHTMLElements();
		this.bindSkinSpecificElements();
		this.$controls.removeClass("boxAdEnabled");

		// Jump to last playing index if necessary.
		if (watchObj.target.playAt || watchObj.target.saveAt) {
			var id = ((watchObj.target.playAt) ? watchObj.target.playAt : watchObj.target.saveAt);
			watchObj.target.episode = findIndexByKeyValue(watchObj.target.channel.items, 'id', id);
			// Save if '.saveAt' is set.
			if (watchObj.target.saveAt) {
				this.togglePlaylistFavorite();
			}
			watchObj.target.playAt = watchObj.target.saveAt = null;
		}

		this.volumeImage = this.$volumeText.css("background");

		// "skin" the view/controls panel based on the player
		this.$container.addClass(this.player.name);
		
		this.init();
		this.attachEvents();
		this.htmlInternationalString();
		
		switch (this.player.mediaType) {
			case "musicVideos":
				this.$editPlaylistButton.hide();
				this.$togglePlaylistButton.show();
				this.updateFavoriteButton(this.getCurrentVideoId());
				break;
			case "playlist":
				this.$editPlaylistButton.show();
				this.$togglePlaylistButton.show();
				this.updateFavoriteButton(this.getCurrentVideoId());
				break;
			default:
				this.$editPlaylistButton.hide();
				this.$togglePlaylistButton.hide();
		}	
		
		this.play();
		this.postShowHook();
		this.showAds();
		
	} catch (e) {
		console.log(e);
		popError(e);
		return false;
	}
};

watchObj.prototype.bindHTMLElements = function() {
	this.$container = $("#watchView");
	this.$header = this.$container.find("#header");
	this.$titleHeader = this.$header.find(".subheader");
	this.$title = this.$header.find(".content h1");
	this.$nextTitleHeader = this.$container.find("#upNextHeader .subheader");
	this.$nextTitle = this.$container.find("#upNextHeader .content h2");
	this.$videoContainer = this.$container.find("#videoContainer");
	this.$fullScreenIt = this.$container.find('#full_screen_button');

	this.$controls = this.$container.find("#controls");
	this.$ccButton = this.$controls.find("#ccButton");
	this.$favoritesMenu = this.$controls.find("#favoritesMenu");
	this.$togglePlaylistButton = this.$favoritesMenu.find("#togglePlaylistButton");
	this.$editPlaylistButton = this.$favoritesMenu.find("#editPlaylistButton");

	/* Prev/Next Video (or Channel Up/Down for TV) */
	this.$prevButton = this.$controls.find("#backButton");
	this.$channelText = this.$controls.find("#channelText");
	this.$nextButton = this.$controls.find("#nextButton");

	/* Volume Ctrl */
	this.$volUpButton = this.$controls.find("#VolUpButton");
	this.$volumeText = this.$controls.find("#volume #volumeText");
	this.$volDnButton = this.$controls.find("#VolDnButton");
	
	/* Channel input */
    this.$channelInputKeypad = this.$controls.find("#channelKeypadContainer ul#channelNumberKeyboard");
    this.$channelInputField = this.$controls.find("#channelKeypadContainer input#directChannelInputField");
    
    /*Previous Channel Control*/
    this.$prevChannelButton = this.$controls.find("#previousChannelButton");
    
    /* Tap for FullScreen */
	this.$tapToView = this.$container.find("#fullCopy");
	

	this.$favoritesMessage = this.$container.find("div#favoritesMessage");
};

watchObj.prototype.bindSkinSpecificElements = function() {};

watchObj.prototype.attachEvents = function() {
	var me = this;

	me.$fullScreenIt.bind("mousedown." + this.name, function() {
		me.$videoContainer.addClass('fullscreen');
	});
	
	if (me.$volUpButton && me.$volUpButton.length > 0) {
		me.$volUpButton.bind("mousedown." + me.name, function() {
			me.updateVolumeIndicator();
		if(machineObj.getSlaveState() == 3){
			nsSend2("op=button","id=volup");
		}
			if (!me.$volUpButton.hasClass("disabled"))
				me.volumeUp();
		});
	}
	if (me.$volDnButton && me.$volDnButton.length > 0) {
		this.updateVolumeIndicator();
		me.$volDnButton.bind("mousedown." + me.name, function() {

		if(machineObj.getSlaveState() == 3){
			nsSend2("op=button","id=voldn");
		}
		
		if (!me.$volDnButton.hasClass("disabled"))
				me.volumeDown();
		});
	}


	if (me.$ccButton && me.$ccButton.length > 0) {
		me.$ccButton.bind("mousedown." + me.name, function() {
			if (!me.$ccButton.hasClass("disabled")) {
				me.player.ccToggle();
				me.$ccButton.toggleClass("ccEnabled");
			}
		});
	}
	if (me.$prevChannelButton && me.$prevChannelButton.length > 0){
		me.$prevChannelButton.bind("mousedown." +this.name, function(){ if(!me.$prevChannelButton.hasClass("disabled")) me.player.backToLastChannel(); });
	}
	
	me.$editPlaylistButton.bind("mousedown." + this.name, function() {
		viewManager.show('playlist');
	});

	me.$togglePlaylistButton.unbind().bind('mousedown.' + me.name, function(event) {
		event.stopImmediatePropagation();
		/* If not logged in */
		if ('' == athleteObj.get_user_id()) {
			me.$videoContainer.addClass('minimize');
			$("#modalBox .okBtn").html(IDS_LANGUAGE["login/regString"]);
			$("#modalBox .cancelBtn").html(IDS_LANGUAGE["Cancel"]);
			me.vm.displayModal(IDS_LANGUAGE["createPlaylistString"] + IDS_LANGUAGE["PlaylistMsg"], "prompt", 
				function okEvent() {
					watchObj.target.saveAt = me.getCurrentEpisodeInfo().id;
					me.vm.closeModal();
					me.vm.nextView = me.name;
					me.vm.show("login");
				}, 
				function cancelEvent() {
					me.vm.closeModal();
					me.$videoContainer.removeClass('minimize');
				} 
			);
		} else {
			me.togglePlaylistFavorite();
		}
	});
	
	me.player.attachEvents();
};

watchObj.prototype.returnToSender = function() {
	if (this.originView) {
		var view = this.originView;
		this.originView = null;
		viewManager.show(view);
	} else {
		viewManager.showPreviousView();
	}
};

watchObj.prototype.shufflePlaylist = function()
{
    var temp, random;
    var len = watchObj.target.channel.items.length; 
      for(var i =0; i < len; i+=2)
      {
          random = Math.round(Math.random()*(len - 1)); //0 to len - 1
          temp = watchObj.target.channel.items[i];
          watchObj.target.channel.items[i] = watchObj.target.channel.items[ random ];
          watchObj.target.channel.items[random] = temp;
      }
};

watchObj.prototype.play = function coreWatchObjPlay() {
	var me = this;
	var playQueue = (watchObj.target.channel.items || []);
	
	me.stopVideo();
	if (me.errorTimeout) {
		clearTimeout(me.errorTimeout);
	}
	
	// External players won't have a play queue
	if (this.player.name != "external" && playQueue.length == 0) {
		me.returnToSender();
		return;
	}
	
	$("#videoBackground").show();
	
	me.adRotation.checkVideoInterval();
    	
	if (me.showVideoAd()) {
        return;
    }
	
	// Since we know at this point that the playQueue is not empty (or that the player is an externalPlayer), 
	// just check to see if it contains a single item.
	if (playQueue.length == 1) {
		me.$prevButton.addClass("disabled");
		me.$nextButton.addClass("disabled");
	} else {
		me.$prevButton.removeClass("disabled");
		me.$nextButton.removeClass("disabled");
	}
	
	me.$favoritesMenu.removeClass("hidden");
	me.updateFavoriteButton(me.getCurrentVideoId());
	me.player.displayTitle();
    
    // Get the playerString here, so we can check if the content is on the GW or not
    var playerString = me.player.getPlayerString();

    // Check if the gateway is available, only if content requires GW
    // If not, display error message and skip to the next video.
    if (playerString.indexOf("rtsp://") > 0 && !systemObj.isGatewayAlive()) {
        setTimeout(function() { me.$videoContainer.css("visibility", "visible"); }, 200);
        this.mediaError();
        return;
    }

	// set the previous channel button to disabled initially since there is no previous channel initially
	if (user.lastChannelIndex == undefined || user.lastChannelIndex == "") {
		me.$prevChannelButton.addClass("disabled");
	}
	
	// Show/hide the cc button if not applicable
	if (me.player.isCcEnabled())
		me.$ccButton.removeClass("disabled");
	else 
		me.$ccButton.addClass("disabled");


    // Hide tap to view full-screen text for CBS.
    if (playerString.indexOf('CBSContent') > 0) {
        this.$tapToView.hide();
        this.$fullScreenIt.hide();
    } else {
        this.$tapToView.show();
        this.$fullScreenIt.show();
    }

	if (me.playTimeout)
		clearTimeout(me.playTimeout);
    
	me.playTimeout = setTimeout(function() {
		// Play video.
		me.player.initVolume();
		me.updateVolumeIndicator(me.volume);
		if (playerString) {
			playVideo(me.$videoContainer, playerString);
			me.startTime = (new Date()).getTime();	
		}
		// Hack to start video player.
		try {
			if (this.playerTimeout) { clearTimeout(this.playerTimeout); }
			// Alter player size.
			me.$videoPlayer = me.$videoContainer.find('object#videoPlayer').css({'height':'99%'});
			// Reset player size.
			this.playerTimeout = setTimeout(function(){me.$videoPlayer.css({'height':'100%'});},25);
		} catch(e) { popError(e); }
		// End hack to start video player.
	}, 200);
	
	me.videoPlaying = true;
};

watchObj.prototype.disableVideoControls = function coreWatchObjDisableVideoControls() {
	var me = this;
	
	me.$prevButton.unbind("click." + me.name);
	me.$nextButton.unbind("click." + me.name);
};

watchObj.prototype.enableVideoControls = function coreWatchObjEnableVideoControls() {
	var me = this;
	
	me.$prevButton.bind("click." + me.name, function() {
		if (!me.$prevButton.hasClass("disabled"))
			me.player.prev(); 
	});
	me.$nextButton.bind("click." + me.name, function() {
		if (!me.$nextButton.hasClass("disabled"))
			me.player.next(); 
	});
};

//TODO: --> vlcPlayer??
watchObj.prototype.stopVideo = function() {
	var me = this;
	me.killVideo();
	
	if (me.errorTimeout)
		clearTimeout(me.errorTimeout);
};

//TODO: --> vlcPlayer??
watchObj.prototype.killVideo = function() {
	if (!this.$videoContainer)
		return;
	this.saveImpression();
	// If we are watching the playlist and the current video is not favorited, remove
	// it from the play queue -- make sure to do this AFTER saving the impression.
	var playQueue = (watchObj.target.channel && watchObj.target.channel.items) ? watchObj.target.channel.items : [];
	if (playQueue.length != 0) {
		var episode = this.getCurrentEpisodeInfo();
		if (episode.channelType == "playlist" && !userCustomPlaylist.contains(episode.id)) { 
			playQueue.splice(episode.channelIndex, 1); 
		}
	}
		
	stopVideo(this.$videoContainer);
	this.videoPlaying = false;
};

watchObj.prototype.nextVideo = function() {
	return(this.player.next());
};

//TODO: --> vlcPlayer??
watchObj.prototype.mediaError = function() {
	var me = this;

	if (me.errorTimeout)
		clearTimeout(me.errorTimeout);
	
	setTimeout(function(){
		me.killVideo();},1500);
	
	me.$videoContainer.html('<span id="noVideo">'+IDS_LANGUAGE.watch["videoNotAvailable"]+'</span>');
	
	me.errorTimeout = setTimeout(function()  {
		try {
			me.$videoContainer.empty();
			me.nextVideo();
			
		} catch(e) {
			popError(e);
		}
	}, 3000);
};

/* MEDIA TYPE -------------------------------------------------------*/

watchObj.prototype.getMediaType = function coreWatchObjGetMediaType() {
	var me = this,
		player = me.player,
		mediaType = (player && player.mediaType) ? player.mediaType
			: (watchObj.target && watchObj.target.parentView && watchObj.target.parentView.name) ? watchObj.target.parentView.name
					: '';
	return mediaType.toLowerCase().replace('videos','');
};

/* MEDIA TYPE -------------------------------------------------------*/

/* ADVERTISEMENTS ---------------------------------------------------*/

watchObj.prototype.showAds = function coreWatchObjShowAds() {
    var me = this, mtype = me.getMediaType();
    // Load content from adManager
    adMan.showAd(mtype + '_banner');
    me.clearTimeout(me.showBoxTimer);
    if ("tv" == mtype) {
        me.showBoxTimer = me.setTimeout(function () { adMan.showAd(mtype + '_box'); }, 8000);
    } else {
        adMan.showAd(mtype + '_box');
    }
};
watchObj.prototype.hideAds = function coreWatchObjHideAds() {
	// Hide Ads.
	adMan.hideAd(this.getMediaType() + '_banner');
    this.clearTimeout(this.showBoxTimer);
	adMan.hideAd(this.getMediaType() + '_box');
};

function watchObjShowVideoAd() {
    var me = this, adName = me.getMediaType() + "_preroll_video";

    if (me.adRotation.allowAd()) {
        adMan.resetPeriodCount(adName);
        me.adShowing = adMan.showAd(adName);
        if (me.adShowing) {
            me.$header.removeClass().addClass("playingVideo");
            // Should we disable the back/next buttons during an ad?
            if (me.disableAdNavigation) {
                me.$prevButton.addClass("disabled");
                me.$nextButton.addClass("disabled");
            }
            me.$favoritesMenu.addClass("hidden");
            me.$title.html('');
            if (me.toEnableChannelControls)
                me.clearTimeout(me.toEnableChannelControls);
            me.toEnableChannelControls = me.setTimeout(function runEnableChannelControls() {
                if ('function' == typeof me.enableChannelControls)
                    me.enableChannelControls();
            }, 1000);
            me.adRotation.reset();
        } else {
            me.$header.removeClass("playingVideo");
        }
        return (me.adShowing);
    }
};

watchObj.prototype.showVideoAd = watchObjShowVideoAd;

/* ADVERTISEMENTS ---------------------------------------------------*/

/*-------------------------------------------------------------------*/

watchObj.prototype.saveImpression = function() {
	var thisAd = null, playTime = 0, mediaType = this.player.mediaType;

	if(mediaType == "cbs" || mediaType == "cbs-v2" || mediaType == "youtube-playlist"){
		var time = Math.round(((new Date().getTime()) - this.startTime)/1000);
		playTime = (time > 100000000) ? 0 : time;
	}
	else
		playTime = guiObj.getVideoTimeElapsedInSeconds();

	this.startTime = 0;
	if(playTime <= 0)
		return;

	switch (mediaType) {
		case "onDemand":
			thisAd = adMan.ads["ondemand_preroll_video"];
			break;
		case "playlist":
		case "music":
		case "musicVideos":
			thisAd = adMan.ads["music_preroll_video"];
			break;
	}
	
	if (thisAd && thisAd.videoBool) {
		thisAd.addVideoImpression(playTime);
		guiObj.resetVideoTimeElapsedInSeconds();
		return;
	}
	
	var videoId = this.getCurrentVideoId();
	if (videoId >= 0) {
		var impression = new mediaImpression(videoId, playTime);
		impressions.addImpression(impression);
	}
	
	guiObj.resetVideoTimeElapsedInSeconds();
};

/**
 * Returns the content ID of the currently playing video or -1 if 
 * the video does not have an ID associated with it.
 */
watchObj.prototype.getCurrentVideoId = function() {
	switch (this.player.name) {
		case "tvtime":
			// Live TV is has content id of 1 in media.xml
			return 1;
			
		case "vlc":
			var currentChannel = watchObj.target.channel;
			var currentEpisode = watchObj.target.episode;
			return parseInt(currentChannel.items[currentEpisode].id);
		
		case "ipod":
		case "external":
		case "player":
		default:
			break;
	}
	
	return -1;
};

watchObj.prototype.hide = function() {
	$("#videoBackground").hide();
	this.vm.closeModal();
	this.stopVideo();
	if (this.player && this.player.name == "tvtime") {
		watchObj.target.episode = this.player.currentChannelIdx;
		user.lastChannelIndex = this.player.currentChannelIdx;
	}
	
	if (this.player && this.player.name == "ipod") {
		// send message to pause ipod
		sendPodControlMsg("id_control_pause", String(this.player.trackIndex));
		if (!this.player.isVideo) {
			disableIPodAudio();	
		}
		setVolume("ipod", "0");
	}
	
	// Save current target settings for subsequent access from the same parent
	watchObj.settings[watchObj.target.parentView] = watchObj.target;
	
	this.hideAds();
};

//watchObj.prototype.toggleFullScreen = function(event) {
//	var me = event.data.watchObj;
//	if (me.$videoContainer.hasClass("fullscreen")) {
//		me.$videoContainer.removeClass("fullscreen");
//		me.$zoomButton.removeClass("fullscreen");
//	} else {
//		me.$videoContainer.addClass("fullscreen");
//		me.$zoomButton.addClass("fullscreen");
//	}
//};

watchObj.prototype.updateVolumeIndicator = function() {
	var _this = this;
	this.$volumeText.html(this.volume).css("background", "none");
	
	clearTimeout(this.volumeIndicatorTimeout);
	this.volumeIndicatorTimeout = setTimeout(function(){
		_this.$volumeText.html("").css("background", _this.volumeImage);
	}, 1000);
	
	if (this.volume > 0) {
		this.$volDnButton.removeClass("disabled");
	} else {
		this.$volDnButton.addClass("disabled");
	}
	if (this.volume < 100) {
		this.$volUpButton.removeClass("disabled");
	} else {
		this.$volUpButton.addClass("disabled");
	}
};

watchObj.prototype.volumeUp = function() {
	if (parseInt(this.volume) < 100) {
		this.volume = parseInt(this.volume) + 5;
		this.updateVolumeIndicator(this.volume);
		user.volume = this.volume;
		
		switch (watchObj.target.parentView.name) {
			case 'tv':
				setVolume("tv", String(this.volume));
				break;
			default:
				if (watchObj.target.parentView == "ipod") {
					setVolume("ipod", String(this.volume));
				} else {
					setVolume("ondemand", String(this.volume));
				}
				break;
		} 
		
		if (isMuted() == "1")
			setTimeout("unmuteVol()", 200);
	}
};

watchObj.prototype.volumeDown = function() {
	if (parseInt(this.volume) > 0) {
		this.volume = parseInt(this.volume) - 5;
		this.updateVolumeIndicator(this.volume);
		user.volume = this.volume;
		
		switch (watchObj.target.parentView.name) {
			case 'tv':
				setVolume("tv", String(this.volume));
				break;
			default:
				if (watchObj.target.parentView == "ipod") {
					setVolume("ipod", String(this.volume));
				} else {
					setVolume("ondemand", String(this.volume));
				}
				break;
		} 
		
		if (isMuted() == "1")
			setTimeout("unmuteVol()", 200);
	}
};

watchObj.prototype.getVolume = function() {
	return this.volume;
};

watchObj.prototype.setVolume = function(v) {
	this.volume = v;
};

watchObj.prototype.htmlInternationalString = function coreWatchObjHtmlInternationalString() {
	this.$prevChannelButton.find("span").html(IDS_LANGUAGE["previousChannelButton"]);
	this.$editPlaylistButton.html(IDS_LANGUAGE["editPlaylist"]);
	this.$videoContainer.find("#noVideo").html(IDS_LANGUAGE.watch["videoNotAvailable"]);
	$('#modalBox > #modalContent > #modalMsg h1').html(IDS_LANGUAGE["createPlaylistString"]);
	$('#modalBox > #modalContent > #modalMsg p').html(IDS_LANGUAGE["PlaylistMsg"]);
	$('#modalBox > #modalContent > #modalButtons > button.button.okBtn').html(IDS_LANGUAGE["login/regString"]);
	$('#modalBox > #modalContent > #modalButtons > button.button.cancelBtn').html(IDS_LANGUAGE["Cancel"]);
	
	if (typeof this.player != "undefined" && this.player != null) {
		this.player.htmlInternationalString();
		this.player.displayTitle();
	}
};

/*-------------------------------------------------------------------*/

watchObj.prototype.getCurrentEpisodeInfo = function coreWatchObjGetCurrentEpisodeInfo() {
	var me = this,
	wt = watchObj.target,
	wc = wt.channel,
	wy = wc.type,
	wi = wc.items,
	wl = wi.length,
	ci = wt.episode,
	ep = (((wl > ci) && (wl > 1)) ? wi[ci] : wi[0]),
	cy = (wy) ? wy : ((wt.parentView.name) ? wt.parentView.name : ep.type),
	an = (ep && ep.artist) ? ep.artist : 'Artist Unknown',
	tn = (ep && ep.title) ? ep.title : (ep && ep.track) ? ep.track : 'Title Unknown',
	cn = (wc && wc.title) ? wc.title : 'Channel Unknown';
	me.currentEpisodeInfo = {
			id:ep.id,
			channelIndex:ci,
			channelName:cn,
			channelType:cy,
			trackName:tn,
			artistName:an,
			obj:ep,
	};
	return me.currentEpisodeInfo;
};

watchObj.prototype.getTitle = function coreWatchObjGetTitle() {
	// Function to return the watch view title.
	var st = '', episode = this.getCurrentEpisodeInfo();

	switch (episode.channelType) {
		case "onDemand":
			st = IDS_LANGUAGE.watch["nowPlaying"] + ': <strong>' + episode.channelName + '</strong> - ' + episode.trackName;
			break;
		case "virtualActive":
			st = IDS_LANGUAGE.watch["nowPlaying"] + ': <strong>' +IDS_LANGUAGE.mainMenu["virtualActive"] + '</strong> - ' + episode.trackName;
			break;
		case "playlist":
		case "music":
		case "musicVideos":
			st = IDS_LANGUAGE.watch["nowPlaying"] + ': <strong>' + episode.artistName + '</strong> - ' + episode.trackName;
			break;
		case "tv":
			st = IDS_LANGUAGE.tv['myChannels'] + ': ' + this.player.getChannelName();
			break;
		case "ipod":
			st = IDS_LANGUAGE.watch["nowPlaying"] + ': <strong>' + episode.artistName + '</strong> - ' + episode.trackName;
			break;

		default:
			break;
		}

	return(st);
};

watchObj.prototype.togglePlaylistFavorite = function coreWatchObjTogglePlaylistFavorite() {
	var me = this, episode = me.getCurrentEpisodeInfo();

	if (athleteObj.get_user_id() == '')
		return;

	if (userCustomPlaylist.contains(episode.id)) {
		userCustomPlaylist.remove(episode.id);
		listChanged = true;
	} else {
		userCustomPlaylist.add(episode.obj);
		listChanged = true;
	}
	
	me.updateFavoriteButton(episode.id);
	me.updateFavoriteMessage(episode.id);
	return me;
};

watchObj.prototype.updateFavoriteButton = function coreWatchObjUpdateFavoriteButton(id) {
	var me = this;
	if (id) {
		if (userCustomPlaylist.contains(id)) {
			me.$togglePlaylistButton.addClass("active");
			me.$togglePlaylistButton.find("label").html(IDS_LANGUAGE.watch["removeFromPlaylist"]);
		} else {
			me.$togglePlaylistButton.removeClass("active");
			me.$togglePlaylistButton.find("label").html(IDS_LANGUAGE.watch["addToPlaylist"]);
		}
	}
	me.updateFavoriteMessage(null);
	return me;
};

watchObj.prototype.updateFavoriteMessage = function coreWatchObjUpdateFavoriteMessage(id) {
	var me = this, msg = null;
	if (id) {
		// Default updated message.
		msg = IDS_LANGUAGE.playlist.updated;
		if (userCustomPlaylist.contains(id))
			;// msg = 'Added to Playlist';
		else if (0 >= userCustomPlaylist.items.length)
			msg = IDS_LANGUAGE.playlist.emptied;
		else
			msg = IDS_LANGUAGE.playlist.removed;

		me.$favoritesMessage.css('opacity', 0).html(msg).fadeTo('fast', 1, function() {
			me.clearTimeout(me.favoritesMessageSTO);
			me.favoritesMessageSTO = me.setTimeout(function() {
				me.$favoritesMessage.fadeTo('slow', 0);
			}, 2000);
		});
	}
	return me;
};

function player(parent) {
	this.parent = parent;
	this.name = "player"; // Should overwrite this in subclasses;
	
	// Tells us what type of content is currently playing. Since this is the base
	// class, it's impossible to determine here. Subclasses should override this value.
	this.mediaType = "";
}
player.prototype.isCcEnabled = function() { return false; };
// Override in sub classes
player.prototype.getPlayerString = function() {};
player.prototype.ccToggle = function() {};
player.prototype.initVolume = function() {
	setVolume("ondemand", String(this.parent.volume));
};
player.prototype.displayTitle = function corePlayerDisplayTitle() {
    if (!(watchObj && watchObj.target && this.parent && this.parent.$title)) {
        return;
    }

	//Add titles of what is currently playing
	if (this.parent.$title && watchObj.target.channel != watchObj.EXTERNAL_SOURCE) {
		var title = '';
		if ((watchObj.target.episode >= 0) && watchObj.target.channel.items
				&& watchObj.target.channel.items[watchObj.target.episode]) {
			title = watchObj.target.channel.items[watchObj.target.episode].title;
		} else if (watchObj.target.channel.title) {
			title =  watchObj.target.channel.title;
		}
		
		switch (typeof(watchObj.target.showTitle)) {
		case 'boolean':
			if (!watchObj.target.showTitle) {
				title = '';
			}
			break;
		case 'function':
			title = watchObj.target.showTitle();
			break;
		default:
			// Default is to show titles, so no additional processing
			break;
		}
		if (typeof(title) != "undefined" && typeof(this.parent.$title.html) != "undefined" && title != this.parent.$title.html()) {
			this.parent.$title.html(title);
		}
	}
	
	//Add titles of what plays next
	if (this.parent.$nextTitle && watchObj.target.channel != watchObj.EXTERNAL_SOURCE) {
		var currentChannel = watchObj.target.channel;
		var currentEpisode = parseInt(watchObj.target.episode);
		this.parent.$nextTitleHeader = $("#upNextHeader");
		
		// If we are at the end of the current channel list, loop to the first 
		var chanNext = (currentEpisode>= currentChannel.items.length - 1) ? 0 : currentEpisode + 1;
		
		var nextTitle = watchObj.target.channel.items[chanNext].title;
			
		
		switch (typeof(watchObj.target.showTitle)) {
		case 'boolean':
			if (!watchObj.target.showTitle) {
				nextTitle = "";
			}
			break;
		case 'function':
		default:
			// Default is to show titles, so no additional processing
			break;
		}
		if (watchObj.target.episode == 0 && currentChannel.items.length == 1){
			this.parent.$nextTitleHeader.addClass("disabled");
		}
		else if (typeof(nextTitle) != "undefined")
			this.parent.$nextTitleHeader.removeClass("disabled");
			this.parent.$nextTitle.html(nextTitle);
	}
};

player.prototype.htmlInternationalString = function corePlayerHtmlInternationalString() {
    if (this.parent) {
        try {
            this.parent.$titleHeader.html(IDS_LANGUAGE.watch["nowPlaying"]);
            this.parent.$nextTitleHeader.html(IDS_LANGUAGE.watch["upNext"]);
        } catch(e) {
            popError(e);
        }
    }
};

/* VLC-specific behavior */
function vlcPlayer(parent) {
	this.parent = parent;
	this.name = "vlc";
	
	if (watchObj.target.channel) {
		var episode = watchObj.target.channel.items[0];
		var etype = episode.type.toUpperCase();
	
		if (etype =="CBS" || etype == "CBS-V2" || etype == "YOUTUBE-PLAYLIST") {
			this.mediaType = etype.toLowerCase();
		} else {
			this.mediaType = watchObj.target.channel.type;
		}
	}
};
vlcPlayer.prototype = new player;
vlcPlayer.prototype.getPlayerString = function vlcPlayerGetPlayerString() {
	var playerstring="", episode, wlen = watchObj.target.channel.items.length;
	if (wlen > watchObj.target.episode && wlen > 1) {
		episode = watchObj.target.channel.items[watchObj.target.episode];
	} else {
		episode = watchObj.target.channel.items[0];
	}
    var elocation = "";
	var etype = episode.type.toUpperCase();
	if (etype =="CBS" || etype == "CBS-V2") {
		switch (etype) {
			case "CBS": { elocation = "http://www.cbs.com/e/" + episode.location + "/cbs/1/"; break; }
			case "CBS-V2": { elocation = episode.location; break; }
		}
		playerstring = "<object id='videoPlayer' class='CBSContent'>" +
				"<param name='movie' value='" + elocation + "'></param>" +
				"<param name='allowFullScreen' value='false'></param><param name='allowScriptAccess' value='always'></param>" +
				"<param name='autoplay' value='true'></param>" +
				"<embed src='" + elocation + "' autoplay='true' allowfullscreen='false' allowScriptAccess='always' " +
					"type='application/x-shockwave-flash' flashvars='autoPlayVid=true'></embed>" +
			"</object>";	
	} else {

        elocation = episode.location;
        if (etype == 'GATEWAY') {
            elocation = "rtsp://" + systemObj.getGatewayIPAddress() + "/" + episode.location;
        }

		playerstring = '<object type="video/mpeg" vout="yes" id="videoPlayer" data="' + elocation + '">' +
			'<param name="allowScriptAccess" value="always">' +
			'<param name="startInFullscreen" value="' + ($('#fullscreenBackground').css("display") != "none") +'">' +
			'<param name="wmode" value="transparent">' + 
			'<param name="is_pauseable" value="'+ watchObj.target.shuffle +'" />' +
			'<param name="data_type" value="ondemand" />' +
			'<param name="fullscreen_support" value="'+ ((this.parent.disableVLCFullscreen) ? "no" : "yes") +'" />' +
		'</object>';
	}

	if(etype == "YOUTUBE-PLAYLIST"){

		playerstring = "<div id='player'></div>";
		$('#videoBackground	').hide();
		$('#playerOverlay').show();

		buildYouTubePlayer(episode.location);

		//check for network errors
		window.clearTimeout();
		window.setTimeout(function(){
			if($("#ytplayer").contents().find("body").length) { 
    			return; 
			}else{ 
			    player.destroy(); 
			    $('#playerContainer').append('<div id="youtubeError">'+IDS_LANGUAGE['youTubeUnavailable']+'</div>'); 
			    $('#youtubeError').css('margin-top', '30%'); 
			}
		}, 3000);		
	}//end Youtube if statement

	return(playerstring);

};

vlcPlayer.prototype.attachEvents = function() {
	var parent = this.parent;
	var me = this;
	if (parent.$nextButton && parent.$nextButton.length > 0) {
		parent.$nextButton.bind("click." + parent.name, function() {
			if (!parent.$nextButton.hasClass("disabled"))
				me.next();
		});
	}

	if (parent.$prevButton && parent.$prevButton.length > 0) {
		parent.$prevButton.bind("click." + parent.name, function() {
			if (!parent.$prevButton.hasClass("disabled"))
				me.prev(); 
		});
	}
};
vlcPlayer.prototype.next = function() {
	var parent = this.parent;
	var currentChannel = watchObj.target.channel;
	var currentEpisode = parseInt(watchObj.target.episode);

	if(watchObj.target.channel.items[0].type.toUpperCase() == "YOUTUBE-PLAYLIST"){
		player.nextVideo();
	
	}else{
	// Stop the video before changing the episode so we can properly record the impression
	parent.stopVideo();
	
	// If we are at the end of the current channel list, loop to the first 
	watchObj.target.episode = (currentEpisode >= currentChannel.items.length - 1) ? 0 : currentEpisode + 1;
	
	// Disable next and prev buttons for a short time. In Windows, switching videos too rapidly will
	// cause vlc to lock up, even with the version 2.0.5
	parent.disableVideoControls();
	parent.play();
	setTimeout(function() { parent.enableVideoControls(); }, 800);

    }
};
vlcPlayer.prototype.prev = function() {
	var parent = this.parent;
	var currentChannel = watchObj.target.channel;
	var currentEpisode = parseInt(watchObj.target.episode);

	if(watchObj.target.channel.items[0].type.toUpperCase() == "YOUTUBE-PLAYLIST"){
		player.previousVideo();
	
	}else{

	// Stop the video before changing the episode so we can properly record the impression
	parent.stopVideo();

	// If we are at the end of the current channel list.
	watchObj.target.episode = (currentEpisode == 0) ? (currentChannel.items.length - 1) : currentEpisode - 1;

	// Disable next and prev buttons for a short time. In Windows, switching videos too rapidly will
	// cause vlc to lock up, even with the version 2.0.5
	parent.disableVideoControls();
	parent.play();
	setTimeout(function() { parent.enableVideoControls(); }, 800);
	}
};

/**
 * External player is a simplified tvtime using the external input, so it does not 
 * allow changing of channels, etc.
 */
function externalPlayer(parent) {
	this.parent = parent;
	this.name = "external";
	this.mediaType = "external";
};

externalPlayer.prototype = new player;
externalPlayer.prototype.getPlayerString = function() {
	return '<object id="videoPlayer" type="video/mpeg" data="v4l2://"><param name="data_type" value="s-video" /></object>';
};
externalPlayer.prototype.attachEvents = function() {
	var parent = this.parent;
	if (parent.$closeButton && parent.$closeButton.length > 0) {
		parent.$closeButton.bind("click." + parent.name, function() {
			if (!parent.$closeButton.hasClass("disabled")) {
				if (typeof(watchObj.beforeIpod) != "undefined") {
					watchObj.target = watchObj.beforeIpod;
					delete watchObj.beforeIpod;
				} else {
					watchObj.target = {};
				}
				if (watchObj.target.parentView && watchObj.target.parentView.name == "virtualActive")
					viewManager.show("virtualActive");
				else
					viewManager.showPreviousView();
			}
		});
	}
};
/* tvtime-specific behavior */
function tvtimePlayer(parent) {
	this.parent = parent;
	this.name = "tvtime";
	this.changeChannelTimer = null;
	this.changeChannelTimerMS = 250;
	this.updateChannelTimer = null;
	this.updateChannelTimerMS = 500;
	this.channelList = watchObj.target.channel.items;
	this.currentChannelIdx = watchObj.target.episode;
	this.playerType = "";
	this.mediaType = "tv";
	
	// TODO:XXX: Set this value from IDS_LANGUAGE.
	this.channelUnavailableText = IDS_LANGUAGE['chanUnavailable'];
	
	// In case we're doing analog/digital, set the channel ASAP so that the qt widget 
    // knows which player to start first. Although the setUpdateTimer eventually does this,
    // the player may already be initialized when the timer fires.
	this.setChannelEx(this.currentChannelIdx);
	
	// Initialize the display to the selected channel
	this.setUpdateTimer();
};
tvtimePlayer.prototype = new externalPlayer;
tvtimePlayer.prototype.getPlayerString = function() {
	return '<object id="videoPlayer" type="video/mpeg" data="v4l2://"><param name="data_type" value="tv" /></object>';
};

tvtimePlayer.prototype.attachEvents = function() {
	var parent = this.parent;
	var me = this;
	parent.$channelInputKeypad.bind("click."+this.name, function(e) {me.channelInputKeypadPressed(e); });
	

	if (parent.$nextButton && parent.$nextButton.length > 0) {
		parent.$nextButton
			.bind("mousedown." + parent.name, function() { if (!parent.$nextButton.hasClass("disabled")) me.tvChannelUiUp(); })
			.bind("mouseup." + parent.name, function() { if (!parent.$nextButton.hasClass("disabled")) clearTimeout(me.changeChannelTimer); })
			.bind("mouseout." + parent.name, function() { if (!parent.$nextButton.hasClass("disabled")) clearTimeout(me.changeChannelTimer); })
			;
	}

	if (parent.$prevButton && parent.$prevButton.length > 0) {
		parent.$prevButton
			.bind("mousedown." + parent.name, function() { if (!parent.$nextButton.hasClass("disabled")) me.tvChannelUiDn(); })
			.bind("mouseup." + parent.name, function() { if (!parent.$nextButton.hasClass("disabled")) clearTimeout(me.changeChannelTimer); })
			.bind("mouseout." + parent.name, function() { if (!parent.$nextButton.hasClass("disabled")) clearTimeout(me.changeChannelTimer); })
			;
	}
};
tvtimePlayer.prototype.isCcEnabled = function() {
	return (ccEnabled() == '1');
};
tvtimePlayer.prototype.ccToggle = function() {
	if (!this.parent.$ccButton.hasClass("disabled")) {
		this.parent.$ccButton.toggleClass("active");
		ccToggle();
	}
};
tvtimePlayer.prototype.initVolume = function() {
	silenceAudio(); // mute all audio to avoid "popping" noises
	setVolume("tv", String(this.parent.volume));
};
//
// Change the channel indicator in the UI.  This doesn't change the actual channel on the tuner.
//
tvtimePlayer.prototype.tvChannelUiUp = function() {
	var me = this;
	
	user.lastChannelIndex = this.currentChannelIdx;

	// Go around in a circle
	this.currentChannelIdx = ((this.currentChannelIdx >= this.channelList.length - 1) ? 0 : parseInt(this.currentChannelIdx) + 1);
	
	// Update the display
	this.parent.$channelText.html(this.channelList[this.currentChannelIdx]);
	
	// Cancel the current timer
	clearTimeout(this.changeChannelTimer);
	
	// Start a new timer to increment again, as long as the user holds the button down.
	this.changeChannelTimer = setTimeout( function() { me.tvChannelUiUp(); }, this.changeChannelTimerMS);
	
	// Reset the timer to send the channel message to tvtime.
	this.setUpdateTimer();
	
	//Once the channel indicator is clicked, enable prevChannelButton
	if (this.parent.$prevChannelButton.hasClass("disabled")){
		this.parent.$prevChannelButton.removeClass("disabled");
	};
};
tvtimePlayer.prototype.tvChannelUiDn = function() {
	var me = this;
	
	user.lastChannelIndex = this.currentChannelIdx;
	
	// Go around in a circle
	this.currentChannelIdx = (this.currentChannelIdx <= 0) ? this.channelList.length - 1 : parseInt(this.currentChannelIdx) - 1;
	
	// Update the display
	this.parent.$channelText.html(this.channelList[this.currentChannelIdx]);
	
	// Cancel the current timer
	clearTimeout(this.changeChannelTimer);
	
	// Start a new timer to increment again, as long as the user holds the button down.
	this.changeChannelTimer = setTimeout( function() { me.tvChannelUiDn(); }, this.changeChannelTimerMS);
	
	// Reset the timer to send the channel message to tvtime.
	this.setUpdateTimer();
	
	//Once the channel indicator is clicked, enable prevChannelButton
	if (this.parent.$prevChannelButton.hasClass("disabled")){
		this.parent.$prevChannelButton.removeClass("disabled");
	};
};

tvtimePlayer.prototype.backToLastChannel = function()
{
	var prevLast = user.lastChannelIndex;
	user.lastChannelIndex = this.currentChannelIdx;
	this.currentChannelIdx = prevLast;
	
	// Update the display
	this.parent.$channelText.html(this.channelList[this.currentChannelIdx]);
	
	//Reset the timer to send the channel message to tvtime
	this.setUpdateTimer();	
};

tvtimePlayer.prototype.channelInputKeypadPressed = function(e) {
	var val = this.parent.$channelInputField.val();

	if (e.target.nodeName.toLowerCase() != "li")
		return;

	var $target = $(e.target);

	// Clear input contents
	if ($target.is(".clear")) {
		this.parent.$channelInputField.val("");
		return;
	}

	// Go to entered channel and clear contents
	else if ($target.is(".enter")) {
		if (this.channelUnavailableText != val) {
			this.directSetChannel(val);
		}

		// Recheck field value.
		val = this.parent.$channelInputField.val();

		if (this.channelUnavailableText == val) {
			// If 'unavailable', clear the field after 3s.
			var _this = this;
			this.unavailableTimeout = setTimeout(function() {
				// Clear input field.
				_this.parent.$channelInputField.val('');
			}, 3000);
		} else {
			// If not set to 'unavailable', clear the field immediately.
			this.parent.$channelInputField.val('');
		}
		return;
	} else {
		// Clear 'unavailable', if shown. Allow input.
		if (this.channelUnavailableText == val) {
			if (this.unavailableTimeout) {
				clearTimeout(this.unavailableTimeout);
			}

			// Reset val variable, and clear field.
			val = '';
			this.parent.$channelInputField.val(val);
		}

		// Max length of three
		if (val.length >= 3)
			return;

		// Don't allow start with zero
		if (val.length == 0 && $target.html() == "0")
			return;

		this.parent.$channelInputField.val(val + $target.html());
	}
};

tvtimePlayer.prototype.directSetChannel = function(val) {
	// this.currentChannelIdx = (this.currentChannelIdx >=
	// this.channelList.length - 1) ? 0 : parseInt(this.currentChannelIdx) + 1;

	var set = false;
	var lastPrev = this.currentChannelIdx;
	for ( var i = 0; i < this.channelList.length; i++ ) {
		if (this.channelList[i].channel == val) {
			set = true;
			this.currentChannelIdx = i;
			break;
		}
	}

	if (!set) {
		// If channel not found, clear display then update with current channel.
		this.parent.$channelInputField.val(this.channelUnavailableText);

		// Update the display
		this.parent.$channelText.html(this.channelList[this.currentChannelIdx]);

		// Reset the timer to send the channel message to tvtime.
		this.setUpdateTimer();
	} else {
		user.lastChannelIndex = lastPrev;

		// Update the display
		this.parent.$channelText.html(this.channelList[this.currentChannelIdx]);

		// Reset the timer to send the channel message to tvtime.
		this.setUpdateTimer();

		// Once the channel indicator is clicked, enable prevChannelButton
		if (this.parent.$prevChannelButton.hasClass("disabled")) {
			this.parent.$prevChannelButton.removeClass("disabled");
		};
	}
};

// 
// Reset the timer to send the channel message to tvtime
tvtimePlayer.prototype.setUpdateTimer = function() {
	var me = this;
	clearTimeout(this.updateChannelTimer);
	this.updateChannelTimer = setTimeout( function() { me.updateViewerChannel(); }, this.updatechannelTimerMS);
};
//
// Change the channel on the TV viewer to match what's currently shown in the UI.
//
tvtimePlayer.prototype.updateViewerChannel = function() {
	// Cancel the timer.
	clearTimeout(this.updateChannelTimer);
	
	// Update the viewer
	this.setChannelEx(this.currentChannelIdx);
};
tvtimePlayer.prototype.setChannelEx = function(channelIndex) {
	try {
		this.currentChannelIdx = channelIndex;
		setChannel(String(this.channelList[channelIndex].originalPosition));
		this.parent.$channelText.html(this.getChannelName());
        
        // Show/hide the cc button if not applicable
		var tunerType = get_television_tuner_type();
		if(tunerType.indexOf('digital') >=0 && (tunerType.indexOf('analog') >=0 || tunerType.indexOf('digital') < 0)) {
	        if ('1' == ccEnabled()) {
	            this.parent.$ccButton.removeClass("disabled");
	        } else {
	            this.parent.$ccButton.addClass("disabled");
	        }
		} else {
			this.parent.$ccButton.hide();
			this.parent.$prevChannelButton.addClass('hideCC');
		}
	} catch (e) {
		popError(e);
	}
};

tvtimePlayer.prototype.getChannelName = function tvtimePlayerGetChannelName() {
	var channel = this.channelList[this.currentChannelIdx],
		channelName = ((channel.name) ? channel.name : channel.channel);
	return(channelName);
};

function toggleTvFullscreen() {
	if (watchObj.toggleTvFullscreenTimeout) {
		clearTimeout(watchObj.toggleTvFullscreenTimeout);
	}
	
	// Set on timeout to avoid multiple calls from single tap
	var $videoContainer = $("#videoContainer");
	var isFullscreen = false;
	watchObj.toggleTvFullscreenTimeout = setTimeout(function() {
		writeLog('debug', 'nplogger: toggleTvFullscreen()');
	
		if ($videoContainer.hasClass("fullscreen")) {
			$("#videoBackground").removeClass("fullscreen");
			$videoContainer.removeClass("fullscreen");
                        isFullscreen = false;
		}
		else {
			$("#videoBackground").addClass("fullscreen");
			$videoContainer.addClass("fullscreen");
			isFullscreen = true;
		}

		// Until the fullscreen problem with flash is fixed, comment this
		//if ($videoContainer.find('#videoPlayer').hasClass('CBSContent')) {
		//    guiObj.showCBSOverlay(true, $videoContainer.offset().left, $videoContainer.offset().top, $videoContainer.width(), $videoContainer.height());
		//}
		
		if (typeof(guiObj) != 'undefined') {
			guiObj.toggleTvFullscreen(isFullscreen);
		}

	}, 100);
}

/**
 * This ipod player is an extremely simplified version of the tvtime player. It's similar to the 
 * external player, in that it plays video from an external source (ie. an Apple device), but it also
 * allows you to control the volume and see the title of the currently playing track. 
 */
function ipodPlayer(parent) {
	this.parent = parent;
	this.name = "ipod";
	this.mediaType = "ipod";
	
	var trackInfo = watchObj.target.channel.items[0];
	
	this.trackIndex = trackInfo.trackIndex;
	this.track = trackInfo.track;
	this.artist = trackInfo.artist;
	this.album = trackInfo.album;
	this.duration = trackInfo.duration;
	this.isVideo = trackInfo.isVideo;
	
	this.position = 0;
}

ipodPlayer.prototype = new player;

ipodPlayer.prototype.displayTitle = function() {
	var w = watchObj.target, c = w.channel, e = c.items[w.episode];
	var title = (e.artist != "") ? ("<strong>" + e.artist + "</strong> - " + e.track) : e.track;
	title = IDS_LANGUAGE.watch["nowPlaying"] + ": " + title;
	
	if (title != this.parent.$title.html())
		this.parent.$title.html(title);
};

ipodPlayer.prototype.getPlayerString = function() {
	// If the currently playing track isn't a video, return an empty string.
	var playerString = "";
	if (this.isVideo) {
		playerString = '<object id="videoPlayer" type="video/mpeg" data="v4l2://"><param name="data_type" value="composite" /></object>';
	}
	return playerString;
};

ipodPlayer.prototype.initVolume = function() {
	if (this.isVideo) {
		silenceAudio(); // mute all audio to avoid "popping" noises
	} else {
		// This will tell the mediaplayer to increment the AlsaStream reference count. Also, we need
		// to make sure input is set to composite.
		setTunerInput("1"); 
		enableIPodAudio();
	}
	setVolume("ipod", String(this.parent.volume));
};

ipodPlayer.prototype.attachEvents = function() {
	// no extra events to attach
};

function onIPodTrackInfoChangedEvent(trackIndex, trackTitle, artist, album, isVideo, duration) {
	writeLog('debug', 'onIPodTrackIndexChangedEvent('+trackIndex+', "'+trackTitle+'", "'+artist+'", "'+album+'", '+isVideo+', '+duration+')');
	
	var trackInfo = {
		'trackIndex': trackIndex,
		'track': trackTitle,
		'artist': artist,
		'album': album,
		'isVideo': isVideo,
		'duration': duration,
	};
	
	// If the ipod player is already running, just update the view / restart the player
	if (viewManager.currentView.name == "watch" && watchObj.target.parentView == "ipod") {
		viewManager.activeObject.player.trackIndex = trackIndex;
		viewManager.activeObject.player.track = trackTitle;
		viewManager.activeObject.player.artist = artist;
		viewManager.activeObject.player.album = album;
		viewManager.activeObject.player.isVideo = isVideo;
		viewManager.activeObject.player.duration = duration;
		
		watchObj.target.channel = {'items': [trackInfo] };
		viewManager.activeObject.play();
	} 
	else {
		// Set up the watch object here, but don't switch to the watch view. 
		// We'll wait for a play status event
		watchObj.target = {
			'parentView': 'ipod',
			'channel': { 'items': [trackInfo] },
			'episode': 0
		};
	}
}

function onIPodTrackPositionChangedEvent(trackPosition) {
	//writeLog('debug', 'onIPodTrackPositionChangedEvent('+trackPosition+')');
	// Don't do anything for now
}

function onIPodPlayStatusChangedEvent(playStatus) {
	writeLog('debug', 'onIPodPlayStatusChangedEvent("'+playStatus+'")');
	
	// These are the views where we don't allow the ipodPlayer to popup
	var dontShowIPod = viewManager.currentView.name == "attract" || viewManager.currentView.name == "endOfWorkout" ||
						viewManager.currentView.name == "registration" || viewManager.currentView.name == "login";
	
	if (viewManager.currentView.name == "watch" && watchObj.target.parentView == "ipod") {
		if (playStatus == "playback stopped" && watchObj.target.channel.items[0].isVideo) {
			// in case the player was in fullscreen when playback stopped
			if ($("#videoContainer").hasClass("fullscreen")) {
				toggleTvFullscreen();
			}
			viewManager.activeObject.stopVideo();
		}
	}
	else if (playStatus == "playing" && !dontShowIPod) {
		// If for some reason the watchObj was not filled out, try and use values from previous
		// session. If that fails, just give default values
		if (watchObj.target.parentView != "ipod") {
			var trackInfo;
			var prevSettings = watchObj.settings["ipod"];
			if (prevSettings) {
				trackInfo = prevSettings.channel.items[0];
			} else {
				trackInfo = {
					'track': "",
					'artist': "",
					'album': "",
					'isVideo': false,
					'duration': 0
				};
			}
			
			watchObj.target = {
				'parentView': 'ipod',
				'channel': { 'items': [trackInfo] },
				'episode': 0
			};
		}
			
		writeLog('debug', 'Switching to iPod view: start');
		viewManager.show("watch");
		writeLog('debug', 'Switching to iPod view: end');
	} 
}

function onIPodDetached() {
	writeLog('debug', 'onIPodDetached()');
	
	// Shut it down!
	if (viewManager.currentView.name == "watch" && watchObj.target.parentView == "ipod") {
		if(!machineObj.isNetworked())
			viewManager.show("tv");
		else
			viewManager.show("landingPage");
	} 
	
	viewManager.closeModal();
	if (viewManager.currentView.name == "watch" && viewManager.activeObject.videoPlaying) {
		pauseResumeObj.showVLCObjects();
	}
}

function onIPodAttached() {
	writeLog('debug', 'onIPodAttached()');
	var dontShowIPod = viewManager.currentView.name == "attract" || viewManager.currentView.name == "endOfWorkout" ||
						viewManager.currentView.name == "registration" || viewManager.currentView.name == "login";
	
	if (!dontShowIPod) {
		if (viewManager.currentView.name == "watch" && viewManager.activeObject.videoPlaying) {
			pauseResumeObj.hideVLCObjects();
		}
		var msg = "Device authenticating...";
		viewManager.displayModal(msg, "alert", function() {
			if (viewManager.currentView.name == "watch" && viewManager.activeObject.videoPlaying) {
				pauseResumeObj.showVLCObjects();
			}
		}, null, true, 15000);
	}
}

function onIPodAuthenticated() {
	writeLog('debug', 'onIPodAuthenticated()');
	var dontShowIPod = viewManager.currentView.name == "attract" || viewManager.currentView.name == "endOfWorkout" ||
		viewManager.currentView.name == "registration" || viewManager.currentView.name == "login";
	
	if (!dontShowIPod) {
		if (viewManager.currentView.name == "watch" && viewManager.activeObject.videoPlaying) {
			pauseResumeObj.hideVLCObjects();
		}
		var msg = "Authentication complete!<br />Press play to begin streaming your content.";
		viewManager.displayModal(msg, "alert", function() {
			if (viewManager.currentView.name == "watch" && viewManager.activeObject.videoPlaying) {
				pauseResumeObj.showVLCObjects();
			}
		}, null, true);
	}
}

function onIPodError() {
	writeLog('debug', 'onIPodError()');
	var dontShowIPod = viewManager.currentView.name == "attract" || viewManager.currentView.name == "endOfWorkout" ||
						viewManager.currentView.name == "registration" || viewManager.currentView.name == "login";
	
	if (!dontShowIPod) {
		if (viewManager.currentView.name == "watch" && viewManager.activeObject.videoPlaying) {
			pauseResumeObj.hideVLCObjects();
		}
		var msg = "An error has occured.  Disconnect your iPod, wait 30 seconds and then reconnect it to continue.";
		viewManager.displayModal(msg, "alert", function() {
			if (viewManager.currentView.name == "watch" && viewManager.activeObject.videoPlaying) {
				pauseResumeObj.showVLCObjects();
			}
		}, null, true);
	}
}

function onIPodNotSupported() {
	writeLog('debug', 'onIPodNotSupported()');
	var dontShowIPod = ((viewManager.currentView.name == "attract" || viewManager.currentView.name == "endOfWorkout" || viewManager.currentView.name == "registration" || viewManager.currentView.name == "login") ? true : false);
	
	viewManager.closeModal();
	if (!dontShowIPod) {
		if (viewManager.currentView.name == "watch" && viewManager.activeObject.videoPlaying) {
			pauseResumeObj.hideVLCObjects();
		}
		var msg = "Sorry, your Apple device is not currently supported.";
		viewManager.displayModal(msg, "alert", function () {
			if (viewManager.currentView.name == "watch" && viewManager.activeObject.videoPlaying) {
				pauseResumeObj.showVLCObjects();
			}
		}, null, true);
	}
};

/*-------------------------------------------------------------------*/
//@ sourceURL=views/watch/js.js
